@@ -38,7 +38,7 @@ import net.sf.jasperreports.engine.base.JRBaseObjectFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePie3DPlot.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBasePie3DPlot.java 3948 2010-09-01 12:07:07Z shertage $
  */
 public class JRBasePie3DPlot extends JRBaseChartPlot implements JRPie3DPlot
 {
@@ -56,13 +56,16 @@ public class JRBasePie3DPlot extends JRBaseChartPlot implements JRPie3DPlot
 	public static final String PROPERTY_LABEL_FORMAT = "labelFormat";
 	public static final String PROPERTY_LEGEND_LABEL_FORMAT = "legendLabelFormat";
 	public static final String PROPERTY_ITEM_LABEL = "itemLabel";
+	public static final String PROPERTY_SHOW_LABELS = "showLabels";
 	
-	protected Double depthFactorDouble = null;
-	protected Boolean circular = null;
-	protected String labelFormat = null;
-	protected String legendLabelFormat = null;
+	protected Double depthFactorDouble;
+	protected Boolean circular;
+	protected String labelFormat;
+	protected String legendLabelFormat;
 	
-	protected JRItemLabel itemLabel = null;
+	protected JRItemLabel itemLabel;
+	protected Boolean showLabels;
+
 	/**
 	 *
 	 */
@@ -92,6 +95,7 @@ public class JRBasePie3DPlot extends JRBaseChartPlot implements JRPie3DPlot
 		labelFormat = pie3DPlot.getLabelFormat();
 		legendLabelFormat = pie3DPlot.getLegendLabelFormat();
 		itemLabel = new JRBaseItemLabel(pie3DPlot.getItemLabel(), factory);
+		showLabels = pie3DPlot.getShowLabels();
 	}
 
 	
@@ -221,6 +225,22 @@ public class JRBasePie3DPlot extends JRBaseChartPlot implements JRPie3DPlot
 		getEventSupport().firePropertyChange(PROPERTY_ITEM_LABEL, old, this.itemLabel);
 	}
 
+	/**
+	 *
+	 */
+	public Boolean getShowLabels(){
+		return showLabels;
+	}
+
+	/**
+	 *
+	 */
+	public void setShowLabels( Boolean showLabels ){
+		Boolean old = this.showLabels;
+		this.showLabels = showLabels;
+		getEventSupport().firePropertyChange(PROPERTY_SHOW_LABELS, old, this.showLabels);
+	}
+
 	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
@@ -232,7 +252,7 @@ public class JRBasePie3DPlot extends JRBaseChartPlot implements JRPie3DPlot
 	/**
 	 * @deprecated
 	 */
-	private boolean isCircular = false;
+	private boolean isCircular;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
