@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
 
 /**
  * @author Flavius Sana (flavius_sana@users.sourceforge.net)
- * @version $Id: JRBaseTimeSeriesDataset.java 3734 2010-04-12 14:24:34Z lucianc $
+ * @version $Id: JRBaseTimeSeriesDataset.java 3932 2010-08-04 12:17:40Z teodord $
  */
 public class JRBaseTimeSeriesDataset extends JRBaseChartDataset implements JRTimeSeriesDataset, JRChangeEventsSupport {
 	
@@ -47,7 +47,7 @@ public class JRBaseTimeSeriesDataset extends JRBaseChartDataset implements JRTim
 	
 	public static final String PROPERTY_TIME_PERIOD = "timePeriod";
 	
-	private JRTimeSeries[] timeSeries = null;
+	private JRTimeSeries[] timeSeries;
 	private Class timePeriod;
 	
 	protected JRBaseTimeSeriesDataset( JRTimeSeriesDataset dataset ){
