@@ -35,7 +35,7 @@ import net.sf.jasperreports.engine.design.JRVerifier;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseXyDataset.java 3734 2010-04-12 14:24:34Z lucianc $
+ * @version $Id: JRBaseXyDataset.java 3938 2010-08-19 14:59:36Z teodord $
  */
 public class JRBaseXyDataset extends JRBaseChartDataset implements JRXyDataset
 {
@@ -46,7 +46,7 @@ public class JRBaseXyDataset extends JRBaseChartDataset implements JRXyDataset
 	 */
 	private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
-	protected JRXySeries[] xySeries = null;
+	protected JRXySeries[] xySeries;
 
 	
 	/**
