@@ -51,7 +51,7 @@ import net.sf.jasperreports.engine.util.JRStringUtil;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net), Peter Severin (peter_p_s@users.sourceforge.net)
- * @version $Id: JRGroovyGenerator.java 3632 2010-03-26 15:58:16Z teodord $
+ * @version $Id: JRGroovyGenerator.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRGroovyGenerator
 {
@@ -61,9 +61,9 @@ public class JRGroovyGenerator
 	 */
 	private static final int EXPR_MAX_COUNT_PER_METHOD = 100;
 
-	private static Map fieldPrefixMap = null;
-	private static Map variablePrefixMap = null;
-	private static Map methodSuffixMap = null;
+	private static Map fieldPrefixMap;
+	private static Map variablePrefixMap;
+	private static Map methodSuffixMap;
 
 	static
 	{
