@@ -45,7 +45,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * report design.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCellContents.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRDesignCellContents.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRDesignCellContents extends JRDesignElementGroup implements JRCellContents
 {
@@ -278,7 +278,7 @@ public class JRDesignCellContents extends JRDesignElementGroup implements JRCell
 	/**
 	 * @deprecated
 	 */
-	private JRBox box = null;
+	private JRBox box;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
