@@ -25,6 +25,8 @@ package net.sf.jasperreports.crosstabs.design;
 
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
+import java.io.IOException;
+import java.io.ObjectInputStream;
 import java.io.Serializable;
 import java.net.URLStreamHandlerFactory;
 import java.util.ArrayList;
@@ -59,6 +61,9 @@ import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.design.JRDesignElement;
 import net.sf.jasperreports.engine.design.JRDesignVariable;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -70,7 +75,7 @@ import org.apache.commons.collections.SequencedHashMap;
  * Design-time {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} implementation.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRDesignCrosstab.java 3032 2009-08-27 11:32:28Z teodord $
+ * @version $Id: JRDesignCrosstab.java 4017 2010-10-27 12:10:17Z teodord $
  */
 public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 {
@@ -116,7 +121,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	protected int columnBreakOffset = DEFAULT_COLUMN_BREAK_OFFSET;
 	protected boolean repeatColumnHeaders = true;
 	protected boolean repeatRowHeaders = true;
-	protected byte runDirection;
+	protected RunDirectionEnum runDirectionValue;
 	protected List cellsList;
 	protected Map cellsMap;
 	protected JRDesignCrosstabCell[][] crossCells;
@@ -207,7 +212,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			JRDesignVariable variable = new JRDesignVariable();
 			variable.setName((String) BUILT_IN_VARIABLES[i]);
 			variable.setValueClass((Class) BUILT_IN_VARIABLES[++i]);
-			variable.setCalculation(JRVariable.CALCULATION_SYSTEM);
+			variable.setCalculation(CalculationEnum.SYSTEM);
 			variable.setSystemDefined(true);
 			addVariable(variable);
 		}
@@ -314,7 +319,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			throw new JRException("A group or measure having the same name already exists in the crosstab.");
 		}
 		
-		rowGroupsMap.put(groupName, new Integer(rowGroups.size()));
+		rowGroupsMap.put(groupName, Integer.valueOf(rowGroups.size()));
 		rowGroups.add(group);
 		
 		addRowGroupVars(group);
@@ -362,7 +367,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			throw new JRException("A group or measure having the same name already exists in the crosstab.");
 		}
 		
-		columnGroupsMap.put(groupName, new Integer(columnGroups.size()));
+		columnGroupsMap.put(groupName, Integer.valueOf(columnGroups.size()));
 		columnGroups.add(group);
 		
 		addColGroupVars(group);
@@ -409,7 +414,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		measure.addPropertyChangeListener(JRDesignCrosstabMeasure.PROPERTY_VALUE_CLASS, measureClassChangeListener);
 		
-		measuresMap.put(measureName, new Integer(measures.size()));
+		measuresMap.put(measureName, Integer.valueOf(measures.size()));
 		measures.add(measure);
 		
 		addMeasureVars(measure);
@@ -444,7 +449,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	protected void addTotalVar(JRCrosstabMeasure measure, JRCrosstabRowGroup rowGroup, JRCrosstabColumnGroup colGroup)
 	{
 		JRDesignVariable var = new JRDesignVariable();
-		var.setCalculation(JRVariable.CALCULATION_SYSTEM);
+		var.setCalculation(CalculationEnum.SYSTEM);
 		var.setSystemDefined(true);
 		var.setName(getTotalVariableName(measure, rowGroup, colGroup));
 		var.setValueClassName(measure.getValueClassName());
@@ -496,7 +501,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			for (ListIterator it = rowGroups.listIterator(idx.intValue()); it.hasNext();)
 			{
 				JRCrosstabRowGroup group = (JRCrosstabRowGroup) it.next();
-				rowGroupsMap.put(group.getName(), new Integer(it.previousIndex()));
+				rowGroupsMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
 			for (Iterator it = cellsList.iterator(); it.hasNext();)
@@ -567,7 +572,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			for (ListIterator it = columnGroups.listIterator(idx.intValue()); it.hasNext();)
 			{
 				JRCrosstabColumnGroup group = (JRCrosstabColumnGroup) it.next();
-				columnGroupsMap.put(group.getName(), new Integer(it.previousIndex()));
+				columnGroupsMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
 			for (Iterator it = cellsList.iterator(); it.hasNext();)
@@ -639,7 +644,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			for (ListIterator it = measures.listIterator(idx.intValue()); it.hasNext();)
 			{
 				JRCrosstabMeasure group = (JRCrosstabMeasure) it.next();
-				measuresMap.put(group.getName(), new Integer(it.previousIndex()));
+				measuresMap.put(group.getName(), Integer.valueOf(it.previousIndex()));
 			}
 			
 			removeMeasureVars(removed);
@@ -1056,7 +1061,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			JRDesignCellContents contents = (JRDesignCellContents) crosstabCell.getContents();
 			
 			String rowTotalGroup = crosstabCell.getRowTotalGroup();
-			int rowGroupIndex = rowTotalGroup == null ? rowGroupIndex = rowGroups.size() : ((Integer) rowGroupsMap.get(rowTotalGroup)).intValue();
+			int rowGroupIndex = rowTotalGroup == null ? rowGroups.size() : ((Integer) rowGroupsMap.get(rowTotalGroup)).intValue();
 			
 			Integer cellWidth = crosstabCell.getWidth();
 			if (cellWidth != null)
@@ -1065,7 +1070,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 			}
 
 			String columnTotalGroup = crosstabCell.getColumnTotalGroup();
-			int columnGroupIndex = columnTotalGroup == null ? columnGroupIndex = columnGroups.size() : ((Integer) columnGroupsMap.get(columnTotalGroup)).intValue();
+			int columnGroupIndex = columnTotalGroup == null ? columnGroups.size() : ((Integer) columnGroupsMap.get(columnTotalGroup)).intValue();
 			Integer cellHeight = crosstabCell.getHeight();
 			if (cellHeight != null)
 			{
@@ -1324,9 +1329,9 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 	
 	
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	public JRCellContents getHeaderCell()
@@ -1397,18 +1402,41 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return (JRDesignVariable) variablesList.get(varName);
 	}
 	
+	/**
+	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
+	 */
 	public byte getRunDirection()
 	{
-		return runDirection;
+		return getRunDirectionValue() == null ? null : getRunDirectionValue().getValue();
 	}
+
 	
+	/**
+	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
+	 */
 	public void setRunDirection(byte runDirection)
 	{
-		byte old = this.runDirection;
-		this.runDirection = runDirection;
-		getEventSupport().firePropertyChange(JRBaseCrosstab.PROPERTY_RUN_DIRECTION, old, this.runDirection);
+		setRunDirection(RunDirectionEnum.getByValue(runDirection));
 	}
-	
+
+	/**
+	 *
+	 */
+	public RunDirectionEnum getRunDirectionValue()
+	{
+		return this.runDirectionValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setRunDirection(RunDirectionEnum runDirectionValue)
+	{
+		RunDirectionEnum old = this.runDirectionValue;
+		this.runDirectionValue = runDirectionValue;
+		getEventSupport().firePropertyChange(JRBaseCrosstab.PROPERTY_RUN_DIRECTION, old, this.runDirectionValue);
+	}
+
 	protected void setCellOrigin(JRCellContents cell, JRCrosstabOrigin origin)
 	{
 		if (cell instanceof JRDesignCellContents)
@@ -1477,7 +1505,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 				JRDesignCrosstabRowGroup groupClone = 
 					(JRDesignCrosstabRowGroup) group.clone(clone);
 				clone.rowGroups.add(groupClone);
-				clone.rowGroupsMap.put(groupClone.getName(), new Integer(i));
+				clone.rowGroupsMap.put(groupClone.getName(), Integer.valueOf(i));
 
 				adjustCrosstabReference(clone, (JRDesignCellContents) groupClone.getTotalHeader());
 				adjustCrosstabReference(clone, (JRDesignCellContents) groupClone.getHeader());
@@ -1500,7 +1528,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 				JRDesignCrosstabColumnGroup groupClone = 
 					(JRDesignCrosstabColumnGroup) group.clone(clone);
 				clone.columnGroups.add(groupClone);
-				clone.columnGroupsMap.put(groupClone.getName(), new Integer(i));
+				clone.columnGroupsMap.put(groupClone.getName(), Integer.valueOf(i));
 				
 				adjustCrosstabReference(clone,(JRDesignCellContents) groupClone.getTotalHeader());
 				adjustCrosstabReference(clone,(JRDesignCellContents) groupClone.getHeader());
@@ -1523,7 +1551,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 				JRDesignCrosstabMeasure clonedMeasure = 
 					(JRDesignCrosstabMeasure) measure.clone();
 				clone.measures.add(clonedMeasure);
-				clone.measuresMap.put(clonedMeasure.getName(), new Integer(i));
+				clone.measuresMap.put(clonedMeasure.getName(), Integer.valueOf(i));
 				
 				if (clonedMeasure.designVariable != null)
 				{
@@ -1649,5 +1677,25 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		setIgnoreWidth(Boolean.valueOf(ignoreWidth));
 	}
+
+	/*
+	 * These fields are only for serialization backward compatibility.
+	 */
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private byte runDirection;
+	
+	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
+	{
+		in.defaultReadObject();
+
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			runDirectionValue = RunDirectionEnum.getByValue(runDirection);
+		}
+	}
+
 	
 }
