@@ -58,16 +58,18 @@ import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRDataUtils;
+import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRLoader;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRResourcesUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRStyledTextParser;
+import net.sf.jasperreports.engine.util.JRProperties.PropertySuffix;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRAbstractExporter.java 3188 2009-11-06 10:01:57Z teodord $
+ * @version $Id: JRAbstractExporter.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public abstract class JRAbstractExporter implements JRExporter
 {
@@ -128,6 +130,8 @@ public abstract class JRAbstractExporter implements JRExporter
 	{
 		String getStringParameter(JRExporterParameter parameter, String property);
 		
+		String[] getStringArrayParameter(JRExporterParameter parameter, String propertyPrefix);
+
 		String getStringParameterOrDefault(JRExporterParameter parameter, String property);
 		
 		boolean getBooleanParameter(JRExporterParameter parameter, String property, boolean defaultValue);
@@ -137,8 +141,6 @@ public abstract class JRAbstractExporter implements JRExporter
 		float getFloatParameter(JRExporterParameter parameter, String property, float defaultValue);
 
 		Character getCharacterParameter(JRExporterParameter parameter, String property);
-		
-		Object getParameters(JRExporterParameter parameter, String property);
 	}
 	
 	protected class ParameterOverrideResolver implements ParameterResolver
@@ -160,6 +162,28 @@ public abstract class JRAbstractExporter implements JRExporter
 			}
 		}
 
+		public String[] getStringArrayParameter(JRExporterParameter parameter, String propertyPrefix)
+		{
+			String[] values = null; 
+			if (parameters.containsKey(parameter))
+			{
+				values = (String[])parameters.get(parameter);
+			}
+			else
+			{
+				List properties = JRProperties.getProperties(jasperPrint.getPropertiesMap(), propertyPrefix);
+				if (properties != null)
+				{
+					values = new String[properties.size()];
+					for(int i = 0; i < values.length; i++)
+					{
+						values[i] = ((PropertySuffix)properties.get(i)).getValue();
+					}
+				}
+			}
+			return values;
+		}
+
 		public String getStringParameterOrDefault(JRExporterParameter parameter, String property)
 		{
 			if (parameters.containsKey(parameter))
@@ -272,20 +296,6 @@ public abstract class JRAbstractExporter implements JRExporter
 						jasperPrint.getPropertiesMap(), property);
 			}
 		}
-		
-		public Object getParameters(JRExporterParameter parameter, 
-				String propertyPrefix)
-		{
-			if (parameters.containsKey(parameter))
-			{
-				return parameters.get(parameter);
-			}
-			else
-			{
-				return JRProperties.getProperties(
-						jasperPrint.getPropertiesMap(), propertyPrefix);
-			}
-		}
 	}
 	
 	protected class ParameterOverriddenResolver implements ParameterResolver
@@ -311,6 +321,29 @@ public abstract class JRAbstractExporter implements JRExporter
 			return value;
 		}
 
+		public String[] getStringArrayParameter(JRExporterParameter parameter, String propertyPrefix)
+		{
+			String[] values = null;
+			JRPropertiesMap hintsMap = jasperPrint.getPropertiesMap();
+			if (hintsMap != null)
+			{
+				List properties = JRProperties.getProperties(hintsMap, propertyPrefix);
+				if (properties != null)
+				{
+					values = new String[properties.size()];
+					for(int i = 0; i < values.length; i++)
+					{
+						values[i] = ((PropertySuffix)properties.get(i)).getValue();
+					}
+				}
+			}
+			else
+			{
+				values = (String[])parameters.get(parameter);
+			}
+			return values;
+		}
+
 		public String getStringParameterOrDefault(JRExporterParameter parameter, String property)
 		{
 			String value;
@@ -446,21 +479,6 @@ public abstract class JRAbstractExporter implements JRExporter
 			return value;
 		}
 		
-		public Object getParameters(JRExporterParameter parameter, String propertyPrefix)
-		{
-			Object value;
-			JRPropertiesMap hintsMap = jasperPrint.getPropertiesMap();
-			if (hintsMap != null)
-			{
-				value = JRProperties.getProperties(hintsMap, propertyPrefix);
-			}
-			else
-			{
-				value = parameters.get(parameter);
-			}
-			return value;
-		}
-
 	}
 	
 	// this would make the applet require logging library
@@ -476,20 +494,20 @@ public abstract class JRAbstractExporter implements JRExporter
 	/**
 	 *
 	 */
-	protected List jasperPrintList = null;
-	protected JasperPrint jasperPrint = null;
+	protected List jasperPrintList;
+	protected JasperPrint jasperPrint;
 	protected boolean isModeBatch = true;
-	protected int startPageIndex = 0;
-	protected int endPageIndex = 0;
-	protected int globalOffsetX = 0;
-	protected int globalOffsetY = 0;
-	protected ClassLoader classLoader = null;
-	protected boolean classLoaderSet = false;
-	protected URLStreamHandlerFactory urlHandlerFactory = null;
-	protected boolean urlHandlerFactorySet = false;
-	protected FileResolver fileResolver = null;
-	protected boolean fileResolverSet = false;
-	protected ExporterFilter filter = null;
+	protected int startPageIndex;
+	protected int endPageIndex;
+	protected int globalOffsetX;
+	protected int globalOffsetY;
+	protected ClassLoader classLoader;
+	protected boolean classLoaderSet;
+	protected URLStreamHandlerFactory urlHandlerFactory;
+	protected boolean urlHandlerFactorySet;
+	protected FileResolver fileResolver;
+	protected boolean fileResolverSet;
+	protected ExporterFilter filter;
 
 	/**
 	 *
@@ -599,6 +617,15 @@ public abstract class JRAbstractExporter implements JRExporter
 	}
 
 	
+	/**
+	 *
+	 */
+	public String[] getStringArrayParameter(JRExporterParameter parameter, String property)
+	{
+		return getParameterResolver().getStringArrayParameter(parameter, property);
+	}
+
+	
 	/**
 	 *
 	 */
@@ -635,16 +662,14 @@ public abstract class JRAbstractExporter implements JRExporter
 	}
 
 	
+	/**
+	 *
+	 */
 	public Character getCharacterParameter(JRExporterParameter parameter, String property)
 	{
 		return getParameterResolver().getCharacterParameter(parameter, property);
 	}
 
-	public Object getParameters(JRExporterParameter parameter, String property)
-	{
-		return getParameterResolver().getParameters(parameter, property);
-	}
-
 	
 	/**
 	 *
@@ -719,6 +744,8 @@ public abstract class JRAbstractExporter implements JRExporter
 			JRResourcesUtil.setThreadFileResolver(fileResolver);
 			fileResolverSet = true;
 		}
+		
+		JRFontUtil.resetThreadMissingFontsCache();
 	}
 		
 
