@@ -88,7 +88,7 @@ import net.sf.jasperreports.engine.component.ComponentsEnvironment;
  * and used at report fill time to evaluate expressions.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRExpressionCollector.java 3203 2009-11-19 17:44:16Z lucianc $
+ * @version $Id: JRExpressionCollector.java 3940 2010-08-20 10:35:15Z teodord $
  */
 public class JRExpressionCollector
 {
@@ -125,7 +125,7 @@ public class JRExpressionCollector
 	protected static class GeneratedIds
 	{
 		private final TreeMap ids = new TreeMap();
-		private int nextId = 0;
+		private int nextId;
 		private List expressions;
 
 		public JRExpression put(Integer id, JRExpression expression)
@@ -137,10 +137,10 @@ public class JRExpressionCollector
 
 		public Integer nextId()
 		{
-			Integer id = new Integer(nextId);
+			Integer id = Integer.valueOf(nextId);
 			while(ids.containsKey(id))
 			{
-				id = new Integer(++nextId);
+				id = Integer.valueOf(++nextId);
 			}
 			return id;
 		}
@@ -156,7 +156,7 @@ public class JRExpressionCollector
 
 		public JRExpression expression(int id)
 		{
-			return (JRExpression) ids.get(new Integer(id));
+			return (JRExpression) ids.get(Integer.valueOf(id));
 		}
 	}
 	private GeneratedIds generatedIds = new GeneratedIds();
@@ -281,11 +281,19 @@ public class JRExpressionCollector
 	 */
 	public JRExpressionCollector getDatasetCollector(String datasetName)
 	{
-		JRExpressionCollector collector = (JRExpressionCollector) datasetCollectors.get(datasetName);
-		if (collector == null)
+		JRExpressionCollector collector;
+		if (parent == null)
 		{
-			collector = new JRExpressionCollector(this, report);
-			datasetCollectors.put(datasetName, collector);
+			collector = (JRExpressionCollector) datasetCollectors.get(datasetName);
+			if (collector == null)
+			{
+				collector = new JRExpressionCollector(this, report);
+				datasetCollectors.put(datasetName, collector);
+			}
+		}
+		else
+		{
+			collector = parent.getDatasetCollector(datasetName);
 		}
 		return collector;
 	}
@@ -300,16 +308,21 @@ public class JRExpressionCollector
 	public JRExpressionCollector getCollector(JRDataset dataset)
 	{
 		JRExpressionCollector collector;
-
-		if (dataset.isMainDataset() || datasetCollectors == null)
+		if (parent == null)
 		{
-			collector = this;
+			if (dataset.isMainDataset() || datasetCollectors == null)
+			{
+				collector = this;
+			}
+			else
+			{
+				collector = getDatasetCollector(dataset.getName());
+			}
 		}
 		else
 		{
-			collector = getDatasetCollector(dataset.getName());
+			collector = parent.getCollector(dataset);
 		}
-
 		return collector;
 	}
 
@@ -322,11 +335,19 @@ public class JRExpressionCollector
 	 */
 	public JRExpressionCollector getCollector(JRCrosstab crosstab)
 	{
-		JRExpressionCollector collector = (JRExpressionCollector) crosstabCollectors.get(crosstab);
-		if (collector == null)
+		JRExpressionCollector collector;
+		if (parent == null)
 		{
-			collector = new JRExpressionCollector(this, report);
-			crosstabCollectors.put(crosstab, collector);
+			collector = (JRExpressionCollector) crosstabCollectors.get(crosstab);
+			if (collector == null)
+			{
+				collector = new JRExpressionCollector(this, report);
+				crosstabCollectors.put(crosstab, collector);
+			}
+		}
+		else
+		{
+			collector = parent.getCollector(crosstab);	
 		}
 		return collector;
 	}
@@ -440,9 +461,11 @@ public class JRExpressionCollector
 	}
 
 	/**
-	 *
+	 * Collects expressions used in a style definition.
+	 * 
+	 * @param style the style to collect expressions from
 	 */
-	private void collect(JRStyle style)
+	public void collect(JRStyle style)
 	{
 		if (style != null && collectedStyles.add(style))
 		{
@@ -1191,7 +1214,7 @@ public class JRExpressionCollector
 
 	private void createCrosstabId(JRCrosstab crosstab)
 	{
-		crosstabIds.put(crosstab, new Integer(crosstabIds.size()));
+		crosstabIds.put(crosstab, Integer.valueOf(crosstabIds.size()));
 	}
 
 
