@@ -46,7 +46,7 @@ import org.jfree.chart.plot.PlotOrientation;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseChartPlot.java 3716 2010-04-08 19:57:14Z teodord $
+ * @version $Id: JRBaseChartPlot.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public abstract class JRBaseChartPlot implements JRChartPlot, Serializable, JRChangeEventsSupport
 {
@@ -69,13 +69,13 @@ public abstract class JRBaseChartPlot implements JRChartPlot, Serializable, JRCh
 	
 	public static final String PROPERTY_SERIES_COLORS = "seriesColors";
 	
-	protected JRChart chart = null;
-	protected Color backcolor = null;
+	protected JRChart chart;
+	protected Color backcolor;
 	protected PlotOrientation orientation = PlotOrientation.VERTICAL;
-	protected Float backgroundAlphaFloat = null;
-	protected Float foregroundAlphaFloat = null;
-	protected Double labelRotationDouble = null;
-	protected SortedSet  seriesColors = null;
+	protected Float backgroundAlphaFloat;
+	protected Float foregroundAlphaFloat;
+	protected Double labelRotationDouble;
+	protected SortedSet  seriesColors;
 
 
 	/**
@@ -326,7 +326,7 @@ public abstract class JRBaseChartPlot implements JRChartPlot, Serializable, JRCh
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 		
 		protected int seriesOrder = -1;
-		protected Color color = null;
+		protected Color color;
 		
 		public JRBaseSeriesColor(int seriesOrder, Color color)
 		{
