@@ -48,7 +48,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * Base read-only implementation of {@link net.sf.jasperreports.engine.JRFrame JRFrame}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseFrame.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseFrame.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRBaseFrame extends JRBaseElement implements JRFrame
 {
@@ -56,7 +56,7 @@ public class JRBaseFrame extends JRBaseElement implements JRFrame
 	
 	protected List children;
 
-	protected JRLineBox lineBox = null;
+	protected JRLineBox lineBox;
 
 
 	public JRBaseFrame(JRFrame frame, JRBaseObjectFactory factory)
@@ -582,63 +582,63 @@ public class JRBaseFrame extends JRBaseElement implements JRFrame
 	/**
 	 * @deprecated
 	 */
-	private Byte border = null;
+	private Byte border;
 	/**
 	 * @deprecated
 	 */
-	private Byte topBorder = null;
+	private Byte topBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte leftBorder = null;
+	private Byte leftBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte bottomBorder = null;
+	private Byte bottomBorder;
 	/**
 	 * @deprecated
 	 */
-	private Byte rightBorder = null;
+	private Byte rightBorder;
 	/**
 	 * @deprecated
 	 */
-	private Color borderColor = null;
+	private Color borderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color topBorderColor = null;
+	private Color topBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color leftBorderColor = null;
+	private Color leftBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color bottomBorderColor = null;
+	private Color bottomBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Color rightBorderColor = null;
+	private Color rightBorderColor;
 	/**
 	 * @deprecated
 	 */
-	private Integer padding = null;
+	private Integer padding;
 	/**
 	 * @deprecated
 	 */
-	private Integer topPadding = null;
+	private Integer topPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer leftPadding = null;
+	private Integer leftPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer bottomPadding = null;
+	private Integer bottomPadding;
 	/**
 	 * @deprecated
 	 */
-	private Integer rightPadding = null;
+	private Integer rightPadding;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
