@@ -153,7 +153,7 @@ import net.sf.jasperreports.engine.JRVariable;
  * Factory of objects used in compiled reports.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseObjectFactory.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseObjectFactory.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRBaseObjectFactory extends JRAbstractObjectFactory
 {
@@ -162,7 +162,7 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
-	private JRDefaultStyleProvider defaultStyleProvider = null;
+	private JRDefaultStyleProvider defaultStyleProvider;
 
 	/**
 	 * Expression collector used to retrieve generated expression IDs.
@@ -191,6 +191,15 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 		this.expressionCollector = expressionCollector;
 	}
 
+	protected JRBaseObjectFactory(JRExpressionCollector expressionCollector)
+	{
+		this.expressionCollector = expressionCollector;
+	}
+	
+	public void setDefaultStyleProvider(JRDefaultStyleProvider defaultStyleProvider)
+	{
+		this.defaultStyleProvider = defaultStyleProvider;
+	}
 
 	/**
 	 *
@@ -204,6 +213,7 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 	/**
 	 *
 	 */
+	@SuppressWarnings("deprecation")
 	public JRReportFont getReportFont(JRReportFont font)
 	{
 		JRBaseReportFont baseFont = null;
@@ -1326,7 +1336,7 @@ public class JRBaseObjectFactory extends JRAbstractObjectFactory
 
 		if (multiAxisPlot != null)
 		{
-			baseMultiAxisPlot = (JRBaseMultiAxisPlot)get(baseMultiAxisPlot);
+			baseMultiAxisPlot = (JRBaseMultiAxisPlot)get(multiAxisPlot);
 			if (baseMultiAxisPlot == null)
 			{
 				baseMultiAxisPlot = new JRBaseMultiAxisPlot(multiAxisPlot, this);
