@@ -31,16 +31,21 @@ import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
-import net.sf.jasperreports.engine.JRElement;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
-import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameter;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
+import net.sf.jasperreports.engine.PrintElementVisitor;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -49,7 +54,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBasePrintImage.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBasePrintImage.java 3991 2010-10-12 20:10:55Z lucianc $
  */
 public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPrintImage
 {
@@ -63,20 +68,20 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	/**
 	 *
 	 */
-	protected JRRenderable renderer = null;
-	protected Byte scaleImage = null;
+	protected JRRenderable renderer;
+	protected ScaleImageEnum scaleImageValue;
 	protected Boolean isUsingCache = Boolean.TRUE;
-	protected Byte horizontalAlignment = null;
-	protected Byte verticalAlignment = null;
-	protected boolean isLazy = false;
-	protected byte onErrorType = JRImage.ON_ERROR_TYPE_ERROR;
-	protected JRLineBox lineBox = null;
-	protected String anchorName = null;
+	protected HorizontalAlignEnum horizontalAlignmentValue;
+	protected VerticalAlignEnum verticalAlignmentValue;
+	protected boolean isLazy;
+	protected OnErrorTypeEnum onErrorTypeValue = OnErrorTypeEnum.ERROR;
+	protected JRLineBox lineBox;
+	protected String anchorName;
 	protected String linkType;
 	protected String linkTarget;
-	protected String hyperlinkReference = null;
-	protected String hyperlinkAnchor = null;
-	protected Integer hyperlinkPage = null;
+	protected String hyperlinkReference;
+	protected String hyperlinkAnchor;
+	protected Integer hyperlinkPage;
 	protected String hyperlinkTooltip;
 	protected JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -101,9 +106,9 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, JRElement.MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 		
 	/**
@@ -123,35 +128,59 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
 	 */
 	public byte getScaleImage()
 	{
-		return JRStyleResolver.getScaleImage(this);
+		return getScaleImageValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
 	 */
 	public Byte getOwnScaleImage()
 	{
-		return scaleImage;
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(byte scaleImage)
 	{
-		this.scaleImage = new Byte(scaleImage);
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(Byte scaleImage)
 	{
-		this.scaleImage = scaleImage;
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getScaleImageValue()
+	{
+		return JRStyleResolver.getScaleImageValue(this);
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getOwnScaleImageValue()
+	{
+		return this.scaleImageValue;
+	}
+
+	/**
+	 * 
+	 */
+	public void setScaleImage(ScaleImageEnum scaleImageValue)
+	{
+		this.scaleImageValue = scaleImageValue;
 	}
 
 	/**
@@ -171,67 +200,115 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		this.horizontalAlignment = new Byte(horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		this.horizontalAlignment = horizontalAlignment;
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
 	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return verticalAlignment;
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		this.verticalAlignment = new Byte(verticalAlignment);
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
 	{
-		this.verticalAlignment = verticalAlignment;
+		this.verticalAlignmentValue = verticalAlignmentValue;
 	}
 
 	/**
@@ -251,19 +328,35 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}
 	 */
 	public byte getOnErrorType()
 	{
-		return onErrorType;
+		return getOnErrorTypeValue().getValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}
+	 */
+	public void setOnErrorType(byte onErrorType)
+	{
+		setOnErrorType(OnErrorTypeEnum.getByValue(onErrorType));
 	}
 
 	/**
 	 *
 	 */
-	public void setOnErrorType(byte onErrorType)
+	public OnErrorTypeEnum getOnErrorTypeValue()
 	{
-		this.onErrorType = onErrorType;
+		return this.onErrorTypeValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setOnErrorType(OnErrorTypeEnum onErrorTypeValue)
+	{
+		this.onErrorTypeValue = onErrorTypeValue;
 	}
 
 	/**
@@ -323,33 +416,65 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(getLinkType());
+		return getHyperlinkTypeValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTypeValue(getLinkType());
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
+	 */
 	public void setHyperlinkType(byte hyperlinkType)
 	{
-		setLinkType(JRHyperlinkHelper.getLinkType(hyperlinkType));
+		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
 	}
 
 	/**
 	 *
 	 */
+	public void setHyperlinkType(HyperlinkTypeEnum hyperlinkType)
+	{
+		setLinkType(JRHyperlinkHelper.getLinkType(hyperlinkType));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
+	 */
 	public byte getHyperlinkTarget()
 	{
-		return JRHyperlinkHelper.getHyperlinkTarget(getLinkTarget());
+		return getHyperlinkTargetValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTargetEnum getHyperlinkTargetValue()
+	{
+		return JRHyperlinkHelper.getHyperlinkTargetValue(getLinkTarget());
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
+	 */
 	public void setHyperlinkTarget(byte hyperlinkTarget)
+	{
+		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+	}
+
+	/**
+	 *
+	 */
+	public void setHyperlinkTarget(HyperlinkTargetEnum hyperlinkTarget)
 	{
 		setLinkTarget(JRHyperlinkHelper.getLinkTarget(hyperlinkTarget));
 	}
@@ -407,7 +532,7 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	 */
 	public void setHyperlinkPage(String hyperlinkPage)
 	{
-		this.hyperlinkPage = new Integer(hyperlinkPage);
+		this.hyperlinkPage = Integer.valueOf(hyperlinkPage);
 	}
 
 
@@ -916,25 +1041,6 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 	
 	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
-	
 	public String getHyperlinkTooltip()
 	{
 		return hyperlinkTooltip;
@@ -947,31 +1053,112 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 	}
 
 	
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
-	private Byte border = null;
-	private Byte topBorder = null;
-	private Byte leftBorder = null;
-	private Byte bottomBorder = null;
-	private Byte rightBorder = null;
-	private Color borderColor = null;
-	private Color topBorderColor = null;
-	private Color leftBorderColor = null;
-	private Color bottomBorderColor = null;
-	private Color rightBorderColor = null;
-	private Integer padding = null;
-	private Integer topPadding = null;
-	private Integer leftPadding = null;
-	private Integer bottomPadding = null;
-	private Integer rightPadding = null;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte border;
+	/**
+	 * @deprecated
+	 */
+	private Byte topBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte leftBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte bottomBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte rightBorder;
+	/**
+	 * @deprecated
+	 */
+	private Color borderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color topBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color leftBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color bottomBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color rightBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Integer padding;
+	/**
+	 * @deprecated
+	 */
+	private Integer topPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer leftPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer bottomPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer rightPadding;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
+	/**
+	 * @deprecated
+	 */
+	private Byte scaleImage;
+	/**
+	 * @deprecated
+	 */
+	private byte onErrorType;
+
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			scaleImageValue = ScaleImageEnum.getByValue(scaleImage);
+			onErrorTypeValue = OnErrorTypeEnum.getByValue(onErrorType);
+
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			scaleImage = null;
+		}
+		
 		if (lineBox == null)
 		{
 			lineBox = new JRBaseLineBox(this);
@@ -1010,7 +1197,20 @@ public class JRBasePrintImage extends JRBasePrintGraphicElement implements JRPri
 			rightPadding = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
+		if (linkType == null)
+		{
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
+	}
+
+
+	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
+	{
+		visitor.visit(this, arg);
 	}
 }
