@@ -33,7 +33,7 @@ import net.sf.jasperreports.engine.JRVisitor;
  * This class is used for representing a static text element. Together with its parents, it contains the full
  * functionality needed for handling a static text.
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseStaticText.java 3468 2010-02-23 15:26:53Z shertage $
+ * @version $Id: JRBaseStaticText.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRBaseStaticText extends JRBaseTextElement implements JRStaticText
 {
@@ -48,7 +48,7 @@ public class JRBaseStaticText extends JRBaseTextElement implements JRStaticText
 	/**
 	 *
 	 */
-	protected String text = null;
+	protected String text;
 
 	/**
 	 * Initializes the element properties. 
