@@ -31,6 +31,7 @@ import java.io.Serializable;
 import net.sf.jasperreports.engine.JRAbstractObjectFactory;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRConditionalStyle;
+import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
@@ -39,13 +40,20 @@ import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRStyleSetter;
 import net.sf.jasperreports.engine.design.events.JRChangeEventsSupport;
 import net.sf.jasperreports.engine.design.events.JRPropertyChangeSupport;
+import net.sf.jasperreports.engine.type.FillEnum;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Ionut Nedelcu (ionutned@users.sourceforge.net)
- * @version $Id: JRBaseStyle.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRBaseStyle.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 {
@@ -108,49 +116,49 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	/**
 	 *
 	 */
-	protected JRDefaultStyleProvider defaultStyleProvider = null;
-	protected JRStyle parentStyle = null;
+	protected JRDefaultStyleProvider defaultStyleProvider;
+	protected JRStyle parentStyle;
 	protected String parentStyleNameReference;
 
 	/**
 	 *
 	 */
-	protected String name = null;
-	protected boolean isDefault = false;
+	protected String name;
+	protected boolean isDefault;
 
-	protected Byte positionType = null;
-	protected Byte stretchType = null;
-	protected Byte mode = null;
-	protected Color forecolor = null;
-	protected Color backcolor = null;
+	protected Byte positionType;
+	protected Byte stretchType;
+	protected ModeEnum modeValue;
+	protected Color forecolor;
+	protected Color backcolor;
 
-	protected JRPen linePen = null;
-	protected Byte fill = null;
+	protected JRPen linePen;
+	protected FillEnum fillValue;
 
-	protected Integer radius = null;
+	protected Integer radius;
 
-	protected Byte scaleImage = null;
-	protected Byte horizontalAlignment = null;
-	protected Byte verticalAlignment = null;
+	protected ScaleImageEnum scaleImageValue;
+	protected HorizontalAlignEnum horizontalAlignmentValue;
+	protected VerticalAlignEnum verticalAlignmentValue;
 
-	protected JRLineBox lineBox = null;
+	protected JRLineBox lineBox;
 
-	protected String fontName = null;
-	protected Boolean isBold = null;
-	protected Boolean isItalic = null;
-	protected Boolean isUnderline = null;
-	protected Boolean isStrikeThrough = null;
-	protected Integer fontSize = null;
-	protected String pdfFontName = null;
-	protected String pdfEncoding = null;
-	protected Boolean isPdfEmbedded = null;
+	protected String fontName;
+	protected Boolean isBold;
+	protected Boolean isItalic;
+	protected Boolean isUnderline;
+	protected Boolean isStrikeThrough;
+	protected Integer fontSize;
+	protected String pdfFontName;
+	protected String pdfEncoding;
+	protected Boolean isPdfEmbedded;
 
-	protected Byte rotation = null;
-	protected Byte lineSpacing = null;
-	protected String markup = null;
+	protected RotationEnum rotationValue;
+	protected LineSpacingEnum lineSpacingValue;
+	protected String markup;
 
-	protected String pattern = null;
-	protected Boolean isBlankWhenNull = null;
+	protected String pattern;
+	protected Boolean isBlankWhenNull;
 
 	protected JRConditionalStyle[] conditionalStyles;
 
@@ -197,23 +205,23 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		
 		isDefault = style.isDefault();
 
-		mode = style.getOwnMode();
+		modeValue = style.getOwnModeValue();
 		forecolor = style.getOwnForecolor();
 		backcolor = style.getOwnBackcolor();
 
 		linePen = style.getLinePen().clone(this);
-		fill = style.getOwnFill();
+		fillValue = style.getOwnFillValue();
 
 		radius = style.getOwnRadius();
 
-		scaleImage = style.getOwnScaleImage();
-		horizontalAlignment = style.getOwnHorizontalAlignment();
-		verticalAlignment = style.getOwnVerticalAlignment();
+		scaleImageValue = style.getOwnScaleImageValue();
+		horizontalAlignmentValue = style.getOwnHorizontalAlignmentValue();
+		verticalAlignmentValue = style.getOwnVerticalAlignmentValue();
 
 		lineBox = style.getLineBox().clone(this);
 		
-		rotation = style.getOwnRotation();
-		lineSpacing = style.getOwnLineSpacing();
+		rotationValue = style.getOwnRotationValue();
+		lineSpacingValue = style.getOwnLineSpacingValue();
 		markup = style.getOwnMarkup();
 
 		pattern = style.getOwnPattern();
@@ -365,14 +373,30 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		JRPenUtil.setLinePenFromPen(pen, linePen);
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getFillValue()}
+	 */
 	public Byte getFill()
 	{
-		return JRStyleResolver.getFill(this);
+		return getFillValue() == null ? null : getFillValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnFillValue()}
+	 */
 	public Byte getOwnFill()
 	{
-		return fill;
+		return getOwnFillValue() == null ? null : getOwnFillValue().getValueByte();
+	}
+
+	public FillEnum getFillValue()
+	{
+		return JRStyleResolver.getFillValue(this);
+	}
+
+	public FillEnum getOwnFillValue()
+	{
+		return fillValue;
 	}
 
 	public Integer getRadius()
@@ -385,34 +409,88 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return radius;
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
+	 */
 	public Byte getScaleImage()
 	{
-		return JRStyleResolver.getScaleImage(this);
+		return getScaleImageValue() == null ? null : getScaleImageValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
+	 */
 	public Byte getOwnScaleImage()
 	{
-		return scaleImage;
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
 	}
 
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getScaleImageValue()
+	{
+		return JRStyleResolver.getScaleImageValue(this);
+	}
+
+	/**
+	 * 
+	 */
+	public ScaleImageEnum getOwnScaleImageValue()
+	{
+		return this.scaleImageValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
+	 */
 	public Byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue() == null ? null : getHorizontalAlignmentValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public Byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue() == null ? null : getVerticalAlignmentValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
+	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return verticalAlignment;
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
+	}
+
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
 	}
 
 	/**
@@ -663,24 +741,94 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return lineBox.getOwnRightPadding();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
 	public Byte getRotation()
 	{
-		return JRStyleResolver.getRotation(this);
+		return getRotationValue() == null ? null : getRotationValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
+	 */
 	public Byte getOwnRotation()
 	{
-		return rotation;
+		return getOwnRotationValue() == null? null : getOwnRotationValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(byte rotation)
+	{
+		setRotation(RotationEnum.getByValue(rotation));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(Byte rotation)
+	{
+		setRotation(RotationEnum.getByValue(rotation));
+	}
+
+	/**
+	 *
+	 */
+	public RotationEnum getRotationValue()
+	{
+		return JRStyleResolver.getRotationValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public RotationEnum getOwnRotationValue()
+	{
+		return this.rotationValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setRotation(RotationEnum rotationValue)
+	{
+		Object old = this.rotationValue;
+		this.rotationValue = rotationValue;
+		getEventSupport().firePropertyChange(PROPERTY_ROTATION, old, this.rotationValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
+	 */
 	public Byte getLineSpacing()
 	{
-		return JRStyleResolver.getLineSpacing(this);
+		return getLineSpacingValue() == null ? null : getLineSpacingValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
+	 */
 	public Byte getOwnLineSpacing()
 	{
-		return lineSpacing;
+		return getOwnLineSpacingValue() == null ? null : getOwnLineSpacingValue().getValueByte();
+	}
+
+	/**
+	 *
+	 */
+	public LineSpacingEnum getLineSpacingValue()
+	{
+		return JRStyleResolver.getLineSpacingValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public LineSpacingEnum getOwnLineSpacingValue()
+	{
+		return this.lineSpacingValue;
 	}
 
 	/**
@@ -822,14 +970,36 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		return pattern;
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getModeValue()}.
+	 */
 	public Byte getMode()
 	{
-		return JRStyleResolver.getMode(this);
+		return getModeValue() == null ? null : getModeValue().getValueByte();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnModeValue()}.
+	 */
 	public Byte getOwnMode()
 	{
-		return mode;
+		return getOwnModeValue() == null ? null : getOwnModeValue().getValueByte();
+	}
+
+	/**
+	 *
+	 */
+	public ModeEnum getModeValue()
+	{
+		return JRStyleResolver.getModeValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public ModeEnum getOwnModeValue()
+	{
+		return modeValue;
 	}
 
 	/**
@@ -853,39 +1023,55 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
 	 */
 	public void setMode(byte mode)
 	{
-		setMode(new Byte(mode));
+		setMode(ModeEnum.getByValue(mode));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setMode(ModeEnum)}.
 	 */
 	public void setMode(Byte mode)
 	{
-		Object old = this.mode;
-		this.mode = mode;
-		getEventSupport().firePropertyChange(PROPERTY_MODE, old, this.mode);
+		setMode(ModeEnum.getByValue(mode));
 	}
 
 	/**
 	 *
 	 */
+	public void setMode(ModeEnum modeValue)
+	{
+		Object old = this.modeValue;
+		this.modeValue = modeValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_MODE, old, this.modeValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
+	 */
 	public void setFill(byte fill)
 	{
-		setFill(new Byte(fill));
+		setFill(FillEnum.getByValue(fill));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setFill(FillEnum)}.
+	 */
+	public void setFill(Byte fill)
+	{
+		setFill(FillEnum.getByValue(fill));
 	}
 
 	/**
 	 *
 	 */
-	public void setFill(Byte fill)
+	public void setFill(FillEnum fillValue)
 	{
-		Object old = this.fill;
-		this.fill = fill;
-		getEventSupport().firePropertyChange(PROPERTY_FILL, old, this.fill);
+		Object old = this.fillValue;
+		this.fillValue = fillValue;
+		getEventSupport().firePropertyChange(PROPERTY_FILL, old, this.fillValue);
 	}
 
 	/**
@@ -893,7 +1079,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	 */
 	public void setRadius(int radius)
 	{
-		setRadius(new Integer(radius));
+		setRadius(Integer.valueOf(radius));
 	}
 
 	/**
@@ -907,57 +1093,81 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(byte scaleImage)
 	{
-		setScaleImage(new Byte(scaleImage));
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(Byte scaleImage)
 	{
-		Object old = this.scaleImage;
-		this.scaleImage = scaleImage;
-		getEventSupport().firePropertyChange(PROPERTY_SCALE_IMAGE, old, this.scaleImage);
+		setScaleImage(ScaleImageEnum.getByValue(scaleImage));
 	}
 
 	/**
 	 *
 	 */
+	public void setScaleImage(ScaleImageEnum scaleImageValue)
+	{
+		Object old = this.scaleImageValue;
+		this.scaleImageValue = scaleImageValue;
+		getEventSupport().firePropertyChange(PROPERTY_SCALE_IMAGE, old, this.scaleImageValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		setHorizontalAlignment(new Byte(horizontalAlignment));
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		Object old = this.horizontalAlignment;
-		this.horizontalAlignment = horizontalAlignment;
-		getEventSupport().firePropertyChange(PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		Object old = this.horizontalAlignmentValue;
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+		getEventSupport().firePropertyChange(PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignmentValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		setVerticalAlignment(new Byte(verticalAlignment));
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
 	{
-		Object old = this.verticalAlignment;
-		this.verticalAlignment = verticalAlignment;
-		getEventSupport().firePropertyChange(PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignment);
+		Object old = this.verticalAlignmentValue;
+		this.verticalAlignmentValue = verticalAlignmentValue;
+		getEventSupport().firePropertyChange(PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignmentValue);
 	}
 
 	/**
@@ -1160,24 +1370,6 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 		lineBox.setRightPadding(rightPadding);
 	}
 
-	/**
-	 *
-	 */
-	public void setRotation(byte rotation)
-	{
-		setRotation(new Byte(rotation));
-	}
-
-	/**
-	 *
-	 */
-	public void setRotation(Byte rotation)
-	{
-		Object old = this.rotation;
-		this.rotation = rotation;
-		getEventSupport().firePropertyChange(PROPERTY_ROTATION, old, this.rotation);
-	}
-
 	/**
 	 *
 	 */
@@ -1330,21 +1522,29 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(byte lineSpacing)
 	{
-		setLineSpacing(new Byte(lineSpacing));
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(Byte lineSpacing)
 	{
-		Object old = this.lineSpacing;
-		this.lineSpacing = lineSpacing;
-		getEventSupport().firePropertyChange(PROPERTY_LINE_SPACING, old, this.lineSpacing);
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
+	}
+
+	/**
+	 * 
+	 */
+	public void setLineSpacing(LineSpacingEnum lineSpacingValue)
+	{
+		Object old = this.lineSpacingValue;
+		this.lineSpacingValue = lineSpacingValue;
+		getEventSupport().firePropertyChange(PROPERTY_LINE_SPACING, old, this.lineSpacingValue);
 	}
 
 	/**
@@ -1382,7 +1582,7 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	 */
 	public void setFontSize(int fontSize)
 	{
-		setFontSize(new Integer(fontSize));
+		setFontSize(Integer.valueOf(fontSize));
 	}
 
 	/**
@@ -1441,31 +1641,130 @@ public class JRBaseStyle implements JRStyle, Serializable, JRChangeEventsSupport
 	}
 
 		
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte mode;
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte rotation;
+	/**
+	 * @deprecated
+	 */
+	private Byte lineSpacing;
+	/**
+	 * @deprecated
+	 */
 	private Byte pen;
-	private Byte border = null;
-	private Byte topBorder = null;
-	private Byte leftBorder = null;
-	private Byte bottomBorder = null;
-	private Byte rightBorder = null;
-	private Color borderColor = null;
-	private Color topBorderColor = null;
-	private Color leftBorderColor = null;
-	private Color bottomBorderColor = null;
-	private Color rightBorderColor = null;
-	private Integer padding = null;
-	private Integer topPadding = null;
-	private Integer leftPadding = null;
-	private Integer bottomPadding = null;
-	private Integer rightPadding = null;
-	private Boolean isStyledText = null;
+	/**
+	 * @deprecated
+	 */
+	private Byte border;
+	/**
+	 * @deprecated
+	 */
+	private Byte topBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte leftBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte bottomBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte rightBorder;
+	/**
+	 * @deprecated
+	 */
+	private Color borderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color topBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color leftBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color bottomBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color rightBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Integer padding;
+	/**
+	 * @deprecated
+	 */
+	private Integer topPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer leftPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer bottomPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer rightPadding;
+	/**
+	 * @deprecated
+	 */
+	private Boolean isStyledText;
+	/**
+	 * @deprecated
+	 */
+	private Byte scaleImage;
+	/**
+	 * @deprecated
+	 */
+	private Byte fill;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 		
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			modeValue = ModeEnum.getByValue(mode);
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			rotationValue = RotationEnum.getByValue(rotation);
+			lineSpacingValue = LineSpacingEnum.getByValue(lineSpacing);
+			scaleImageValue = ScaleImageEnum.getByValue(scaleImage);
+			fillValue = FillEnum.getByValue(fill);
+			
+			mode = null;
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			rotation = null;
+			lineSpacing = null;
+			scaleImage = null;
+			fill = null;
+		}
+
 		if (linePen == null)
 		{
 			linePen = new JRBasePen(this);
