@@ -36,7 +36,7 @@ import net.sf.jasperreports.engine.type.CalculationEnum;
  * Base implementation of {@link net.sf.jasperreports.engine.JRSubreportReturnValue JRSubreportReturnValue}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRBaseSubreportReturnValue.java 3715 2010-04-08 18:08:49Z teodord $
+ * @version $Id: JRBaseSubreportReturnValue.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRBaseSubreportReturnValue implements JRSubreportReturnValue, Serializable
 {
@@ -49,12 +49,12 @@ public class JRBaseSubreportReturnValue implements JRSubreportReturnValue, Seria
 	/**
 	 * The name of the subreport variable to be copied.
 	 */
-	protected String subreportVariable = null;
+	protected String subreportVariable;
 
 	/**
 	 * The name of the master variable where the value should be copied.
 	 */
-	protected String toVariable = null;
+	protected String toVariable;
 	
 	/**
 	 * The calculation type.
@@ -64,7 +64,7 @@ public class JRBaseSubreportReturnValue implements JRSubreportReturnValue, Seria
 	/**
 	 * The incrementer factory class name.
 	 */
-	protected String incrementerFactoryClassName = null;
+	protected String incrementerFactoryClassName;
 
 	
 	protected JRBaseSubreportReturnValue()
