@@ -73,7 +73,7 @@ import org.jfree.date.DateUtilities;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ConvertChartContext.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: ConvertChartContext.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class ConvertChartContext implements ChartContext
 {
@@ -146,7 +146,7 @@ public class ConvertChartContext implements ChartContext
 		return null;
 	}
 	
-	private static DefaultCategoryDataset sampleCategoryDataset = null;
+	private static DefaultCategoryDataset sampleCategoryDataset;
 	
 	private CategoryDataset createCategoryDataset()
 	{
@@ -184,7 +184,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleCategoryDataset;
 	}
 	
-	private static PieDataset samplePieDataset = null;
+	private static PieDataset samplePieDataset;
 	
 	private PieDataset createPieDataset()
 	{
@@ -203,7 +203,7 @@ public class ConvertChartContext implements ChartContext
 		return samplePieDataset;
 	}
 	
-	private static XYSeriesCollection sampleXyDataset = null;
+	private static XYSeriesCollection sampleXyDataset;
 	
 	private XYDataset createXyDataset()
 	{
@@ -253,7 +253,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyDataset;
 	}
 	
-	private static TimeSeriesCollection sampleTimeSeriesDataset = null;
+	private static TimeSeriesCollection sampleTimeSeriesDataset;
 	
 	private TimeSeriesCollection createTimeSeriesDataset()
 	{
@@ -281,36 +281,36 @@ public class ConvertChartContext implements ChartContext
 			TimeSeries series = new TimeSeries("First", "Year", "Count", Year.class);
 			try 
 			{
-				series.add(new Year(1976), new Integer(0));
-				series.add(new Year(1977), new Integer(1));
-				series.add(new Year(1978), new Integer(0));
-				series.add(new Year(1979), new Integer(2));
-				series.add(new Year(1980), new Integer(0));
-				series.add(new Year(1981), new Integer(1));
-				series.add(new Year(1982), new Integer(2));
-				series.add(new Year(1983), new Integer(5));
-				series.add(new Year(1984), new Integer(21));
-				series.add(new Year(1985), new Integer(18));
-				series.add(new Year(1986), new Integer(18));
-				series.add(new Year(1987), new Integer(25));
-				series.add(new Year(1988), new Integer(11));
-				series.add(new Year(1989), new Integer(16));
-				series.add(new Year(1990), new Integer(23));
-				series.add(new Year(1991), new Integer(14));
-				series.add(new Year(1992), new Integer(31));
-				series.add(new Year(1993), new Integer(38));
-				series.add(new Year(1994), new Integer(31));
-				series.add(new Year(1995), new Integer(56));
-				series.add(new Year(1996), new Integer(45));
-				series.add(new Year(1997), new Integer(74));
-				series.add(new Year(1998), new Integer(68));
-				series.add(new Year(1999), new Integer(98));
-				series.add(new Year(2000), new Integer(85));
-				series.add(new Year(2001), new Integer(66));
-				series.add(new Year(2002), new Integer(71));
-				series.add(new Year(2003), new Integer(65));
-				series.add(new Year(2004), new Integer(59));
-				series.add(new Year(2005), new Integer(60));
+				series.add(new Year(1976), Integer.valueOf(0));
+				series.add(new Year(1977), Integer.valueOf(1));
+				series.add(new Year(1978), Integer.valueOf(0));
+				series.add(new Year(1979), Integer.valueOf(2));
+				series.add(new Year(1980), Integer.valueOf(0));
+				series.add(new Year(1981), Integer.valueOf(1));
+				series.add(new Year(1982), Integer.valueOf(2));
+				series.add(new Year(1983), Integer.valueOf(5));
+				series.add(new Year(1984), Integer.valueOf(21));
+				series.add(new Year(1985), Integer.valueOf(18));
+				series.add(new Year(1986), Integer.valueOf(18));
+				series.add(new Year(1987), Integer.valueOf(25));
+				series.add(new Year(1988), Integer.valueOf(11));
+				series.add(new Year(1989), Integer.valueOf(16));
+				series.add(new Year(1990), Integer.valueOf(23));
+				series.add(new Year(1991), Integer.valueOf(14));
+				series.add(new Year(1992), Integer.valueOf(31));
+				series.add(new Year(1993), Integer.valueOf(38));
+				series.add(new Year(1994), Integer.valueOf(31));
+				series.add(new Year(1995), Integer.valueOf(56));
+				series.add(new Year(1996), Integer.valueOf(45));
+				series.add(new Year(1997), Integer.valueOf(74));
+				series.add(new Year(1998), Integer.valueOf(68));
+				series.add(new Year(1999), Integer.valueOf(98));
+				series.add(new Year(2000), Integer.valueOf(85));
+				series.add(new Year(2001), Integer.valueOf(66));
+				series.add(new Year(2002), Integer.valueOf(71));
+				series.add(new Year(2003), Integer.valueOf(65));
+				series.add(new Year(2004), Integer.valueOf(59));
+				series.add(new Year(2005), Integer.valueOf(60));
 			}
 			catch (Exception e) 
 			{
@@ -325,7 +325,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleTimeSeriesDataset;
 	}
 	
-	private static DefaultXYZDataset sampleXyzDataset = null;
+	private static DefaultXYZDataset sampleXyzDataset;
 	
 	private XYZDataset createXyzDataset()
 	{
@@ -348,7 +348,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleXyzDataset;
 	}
 
-	private static TaskSeriesCollection sampleGanttDataset = null;
+	private static TaskSeriesCollection sampleGanttDataset;
 	
 	private IntervalCategoryDataset createGanttDataset() 
 	{
@@ -382,11 +382,10 @@ public class ConvertChartContext implements ChartContext
 	{
 		Calendar calendar = Calendar.getInstance();
 		calendar.set(year, month, day);
-		Date result = calendar.getTime();
-		return result;
+		return calendar.getTime();
 	}
 
-	private static DefaultHighLowDataset sampleHighLowDataset = null;
+	private static DefaultHighLowDataset sampleHighLowDataset;
 	
 	private OHLCDataset createHighLowDataset() 
 	{
@@ -737,7 +736,7 @@ public class ConvertChartContext implements ChartContext
 		return sampleHighLowDataset;
 	}
 	
-	private static TimePeriodValuesCollection sampleTimePeriodDataset = null;
+	private static TimePeriodValuesCollection sampleTimePeriodDataset;
 	
 	private XYDataset createTimePeriodDataset()
 	{
