@@ -60,16 +60,16 @@ import net.sf.jasperreports.engine.JRRuntimeException;
  */
 public class JRXlsDataSource implements JRRewindableDataSource
 {
-	private Workbook workbook = null;
+	private Workbook workbook;
 
 	private DateFormat dateFormat = new SimpleDateFormat();
 	private NumberFormat numberFormat = new DecimalFormat();
 	private Map columnNames = new HashMap();
-	private boolean useFirstRowAsHeader = false;
+	private boolean useFirstRowAsHeader;
 	private int recordIndex = -1;
 
-	private InputStream inputStream = null;
-	private boolean closeWorkbook = false;
+	private InputStream inputStream;
+	private boolean closeWorkbook;
 
 
 	/**
