@@ -34,11 +34,15 @@ import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRReportFont;
-import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRTextElement;
 import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.base.JRBaseStyle;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -50,7 +54,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * in <tt>JRTextElement</tt> and setters for text element attributes that can only be modified at design time.
  *
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDesignTextElement.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRDesignTextElement.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public abstract class JRDesignTextElement extends JRDesignElement implements JRTextElement
 {
@@ -65,10 +69,10 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	/**
 	 *
 	 */
-	protected Byte horizontalAlignment;
-	protected Byte verticalAlignment;
-	protected Byte rotation;
-	protected Byte lineSpacing;
+	protected HorizontalAlignEnum horizontalAlignmentValue;
+	protected VerticalAlignEnum verticalAlignmentValue;
+	protected RotationEnum rotationValue;
+	protected LineSpacingEnum lineSpacingValue;
 	protected String markup;
 
 	/**
@@ -76,16 +80,16 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	 */
 	protected JRLineBox lineBox;
 
-	protected JRReportFont reportFont = null;
-	protected String fontName = null;
-	protected Boolean isBold = null;
-	protected Boolean isItalic = null;
-	protected Boolean isUnderline = null;
-	protected Boolean isStrikeThrough = null;
-	protected Integer fontSize = null;
-	protected String pdfFontName = null;
-	protected String pdfEncoding = null;
-	protected Boolean isPdfEmbedded = null;
+	protected JRReportFont reportFont;
+	protected String fontName;
+	protected Boolean isBold;
+	protected Boolean isItalic;
+	protected Boolean isUnderline;
+	protected Boolean isStrikeThrough;
+	protected Integer fontSize;
+	protected String pdfFontName;
+	protected String pdfEncoding;
+	protected Boolean isPdfEmbedded;
 
 
 	/**
@@ -105,9 +109,13 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	protected JRFont getBaseFont()
 	{
 		if (reportFont != null)
+		{
 			return reportFont;
+		}
 		if (defaultStyleProvider != null)
+		{
 			return defaultStyleProvider.getDefaultFont();
+		}
 		return null;
 	}
 
@@ -115,9 +123,9 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 
@@ -126,13 +134,7 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	 */
 	public byte getTextAlignment()
 	{
-		if (horizontalAlignment == null) {
-			JRStyle style = getBaseStyle();
-			if (style != null && style.getHorizontalAlignment() != null)
-				return style.getHorizontalAlignment().byteValue();
-			return HORIZONTAL_ALIGN_LEFT;
-		}
-		return horizontalAlignment.byteValue();
+		return getHorizontalAlignment();
 	}
 
 	/**
@@ -144,127 +146,226 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		setHorizontalAlignment(new Byte(horizontalAlignment));
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		Object old = this.horizontalAlignment;
-		this.horizontalAlignment = horizontalAlignment;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
 
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		Object old = this.horizontalAlignmentValue;
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_HORIZONTAL_ALIGNMENT, old, this.horizontalAlignmentValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
-	}
-
-	public Byte getOwnVerticalAlignment()
-	{
-		return verticalAlignment;
+		return getVerticalAlignmentValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
+	 */
+	public Byte getOwnVerticalAlignment()
+	{
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
+	}
+
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
 	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		setVerticalAlignment(new Byte(verticalAlignment));
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
 	 */
 	public void setVerticalAlignment(Byte verticalAlignment)
 	{
-		Object old = this.verticalAlignment;
-		this.verticalAlignment = verticalAlignment;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignment);
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
 
 	/**
 	 *
 	 */
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
+	{
+		Object old = this.verticalAlignmentValue;
+		this.verticalAlignmentValue = verticalAlignmentValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_VERTICAL_ALIGNMENT, old, this.verticalAlignmentValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
 	public byte getRotation()
 	{
-		return JRStyleResolver.getRotation(this);
-	}
-
-	public Byte getOwnRotation()
-	{
-		return rotation;
+		return getRotationValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
+	 */
+	public Byte getOwnRotation()
+	{
+		return getOwnRotationValue() == null? null : getOwnRotationValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
 	 */
 	public void setRotation(byte rotation)
 	{
-		setRotation(new Byte(rotation));
+		setRotation(RotationEnum.getByValue(rotation));
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
 	 */
 	public void setRotation(Byte rotation)
 	{
-		Object old = this.rotation;
-		this.rotation = rotation;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_ROTATION, old, this.rotation);
+		setRotation(RotationEnum.getByValue(rotation));
 	}
 
 	/**
 	 *
 	 */
+	public RotationEnum getRotationValue()
+	{
+		return JRStyleResolver.getRotationValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public RotationEnum getOwnRotationValue()
+	{
+		return this.rotationValue;
+	}
+
+	/**
+	 *
+	 */
+	public void setRotation(RotationEnum rotationValue)
+	{
+		Object old = this.rotationValue;
+		this.rotationValue = rotationValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_ROTATION, old, this.rotationValue);
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
+	 */
 	public byte getLineSpacing()
 	{
-		return JRStyleResolver.getLineSpacing(this);
-	}
-
-	public Byte getOwnLineSpacing()
-	{
-		return lineSpacing;
+		return getLineSpacingValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
+	 */
+	public Byte getOwnLineSpacing()
+	{
+		return getOwnLineSpacingValue() == null? null : getOwnLineSpacingValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(byte lineSpacing)
 	{
-		setLineSpacing(new Byte(lineSpacing));
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
+	 */
+	public void setLineSpacing(Byte lineSpacing)
+	{
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
 	}
 
 	/**
 	 *
 	 */
-	public void setLineSpacing(Byte lineSpacing)
+	public LineSpacingEnum getLineSpacingValue()
 	{
-		Object old = this.lineSpacing;
-		this.lineSpacing = lineSpacing;
-		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_LINE_SPACING, old, this.lineSpacing);
+		return JRStyleResolver.getLineSpacingValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public LineSpacingEnum getOwnLineSpacingValue()
+	{
+		return this.lineSpacingValue;
+	}
+
+	/**
+	 * 
+	 */
+	public void setLineSpacing(LineSpacingEnum lineSpacingValue)
+	{
+		Object old = this.lineSpacingValue;
+		this.lineSpacingValue = lineSpacingValue;
+		getEventSupport().firePropertyChange(JRBaseStyle.PROPERTY_LINE_SPACING, old, this.lineSpacingValue);
 	}
 
 	/**
@@ -1028,7 +1129,7 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	 */
 	public void setFontSize(int fontSize)
 	{
-		setFontSize(new Integer(fontSize));
+		setFontSize(Integer.valueOf(fontSize));
 	}
 
 	/**
@@ -1178,36 +1279,114 @@ public abstract class JRDesignTextElement extends JRDesignElement implements JRT
 	{
 		JRDesignTextElement clone = (JRDesignTextElement)super.clone();
 		
-		clone.lineBox = (JRLineBox)lineBox.clone(clone);
+		clone.lineBox = lineBox.clone(clone);
 		
 		return clone;
 	}
 
 
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
-	private Byte border = null;
-	private Byte topBorder = null;
-	private Byte leftBorder = null;
-	private Byte bottomBorder = null;
-	private Byte rightBorder = null;
-	private Color borderColor = null;
-	private Color topBorderColor = null;
-	private Color leftBorderColor = null;
-	private Color bottomBorderColor = null;
-	private Color rightBorderColor = null;
-	private Integer padding = null;
-	private Integer topPadding = null;
-	private Integer leftPadding = null;
-	private Integer bottomPadding = null;
-	private Integer rightPadding = null;
-	private Boolean isStyledText = null;
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte rotation;
+	/**
+	 * @deprecated
+	 */
+	private Byte lineSpacing;
+	/**
+	 * @deprecated
+	 */
+	private Byte border;
+	/**
+	 * @deprecated
+	 */
+	private Byte topBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte leftBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte bottomBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte rightBorder;
+	/**
+	 * @deprecated
+	 */
+	private Color borderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color topBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color leftBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color bottomBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color rightBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Integer padding;
+	/**
+	 * @deprecated
+	 */
+	private Integer topPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer leftPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer bottomPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer rightPadding;
+	/**
+	 * @deprecated
+	 */
+	private Boolean isStyledText;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			rotationValue = RotationEnum.getByValue(rotation);
+			lineSpacingValue = LineSpacingEnum.getByValue(lineSpacing);
+
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			rotation = null;
+			lineSpacing = null;
+		}
+		
 		if (lineBox == null)
 		{
 			lineBox = new JRBaseLineBox(this);
