@@ -34,9 +34,6 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 import net.sf.jasperreports.charts.JRCategoryDataset;
 import net.sf.jasperreports.charts.JRCategorySeries;
 import net.sf.jasperreports.charts.JRGanttDataset;
@@ -66,11 +63,13 @@ import net.sf.jasperreports.crosstabs.JRCrosstabRowGroup;
 import net.sf.jasperreports.crosstabs.design.JRDesignCrosstab;
 import net.sf.jasperreports.crosstabs.fill.JRPercentageCalculator;
 import net.sf.jasperreports.crosstabs.fill.JRPercentageCalculatorFactory;
+import net.sf.jasperreports.crosstabs.type.CrosstabPercentageEnum;
 import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRBand;
 import net.sf.jasperreports.engine.JRChart;
 import net.sf.jasperreports.engine.JRChartDataset;
 import net.sf.jasperreports.engine.JRComponentElement;
+import net.sf.jasperreports.engine.JRConditionalStyle;
 import net.sf.jasperreports.engine.JRDataset;
 import net.sf.jasperreports.engine.JRDatasetParameter;
 import net.sf.jasperreports.engine.JRDatasetRun;
@@ -92,6 +91,7 @@ import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRImage;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRParameter;
+import net.sf.jasperreports.engine.JRPropertiesMap;
 import net.sf.jasperreports.engine.JRPropertyExpression;
 import net.sf.jasperreports.engine.JRQuery;
 import net.sf.jasperreports.engine.JRQueryChunk;
@@ -115,11 +115,20 @@ import net.sf.jasperreports.engine.component.ComponentKey;
 import net.sf.jasperreports.engine.component.ComponentsEnvironment;
 import net.sf.jasperreports.engine.fill.JRExtendedIncrementerFactory;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.IncrementTypeEnum;
+import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.type.SortFieldTypeEnum;
+import net.sf.jasperreports.engine.type.SplitTypeEnum;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 
 /**
  * A report verifier.
@@ -129,7 +138,7 @@ import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
  * report compilation.  
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRVerifier.java 3203 2009-11-19 17:44:16Z lucianc $
+ * @version $Id: JRVerifier.java 3956 2010-09-22 08:38:39Z teodord $
  */
 public class JRVerifier
 {
@@ -185,13 +194,43 @@ public class JRVerifier
 	 */
 	public static final String PROPERTY_ALLOW_ELEMENT_OVERLAP = 
 		JRProperties.PROPERTY_PREFIX + "allow.element.overlap";
+	
+	public static final String PROPERTY_ALLOW_ELEMENT_NEGATIVE_WIDTH =
+		JRProperties.PROPERTY_PREFIX + "allow.element.negative.width";
+	
+	/**
+	 * Property that determines whether elements positioned at negative Y offsets 
+	 * on bands, frames and other element containers are allowed in a report.
+	 *
+	 * <p>
+	 * Elements placed at negative Y offsets can cause unexpected problems in
+	 * grid-based exporters where they can overlap elements from previous
+	 * bands/element containers.
+	 * </p>
+	 * 
+	 * <p>
+	 * If the property is set to <code>false</code>, elements in the report are 
+	 * verified to have positive Y offsets.  Otherwise, no check is performed
+	 * on element Y offsets.
+	 * </p>
+	 * 
+	 * <p>
+	 * The property can be set at element, report and global levels.
+	 * By default the property is set to <code>true</code>.
+	 * </p>
+	 * 
+	 * @see JRElement#getY()
+	 * @since 3.7.3
+	 */
+	public static final String PROPERTY_ALLOW_ELEMENT_NEGATIVE_Y =
+		JRProperties.PROPERTY_PREFIX + "allow.element.negative.y";
 
 	/**
 	 *
 	 */
-	private static String[] textFieldClassNames = null;
-	private static String[] imageClassNames = null;
-	private static String[] subreportClassNames = null;
+	private static String[] textFieldClassNames;
+	private static String[] imageClassNames;
+	private static String[] subreportClassNames;
 
 	private static Class[] templateTypes = new Class[] {
 		String.class, java.io.File.class, java.net.URL.class, java.io.InputStream.class,
@@ -200,12 +239,15 @@ public class JRVerifier
 	/**
 	 *
 	 */
-	private JasperDesign jasperDesign = null;
-	private Collection brokenRules = null;
+	private JasperDesign jasperDesign;
+	private Collection brokenRules;
 
 	private JRExpressionCollector expressionCollector;
 
 	private LinkedList currentComponentElementStack = new LinkedList();
+	
+	private boolean allowElementNegativeWidth;
+	private final boolean allowElementNegativeY;
 
 	/**
 	 *
@@ -229,6 +271,10 @@ public class JRVerifier
 		{
 			this.expressionCollector = JRExpressionCollector.collector(jasperDesign);
 		}
+		
+		allowElementNegativeWidth = JRProperties.getBooleanProperty(jasperDesign, PROPERTY_ALLOW_ELEMENT_NEGATIVE_WIDTH, false);
+		allowElementNegativeY = JRProperties.getBooleanProperty(jasperDesign, 
+				PROPERTY_ALLOW_ELEMENT_NEGATIVE_Y, true);
 	}
 
 	public JasperDesign getReportDesign()
@@ -761,6 +807,7 @@ public class JRVerifier
 				dataset.getVariablesMap());
 	}
 
+
 	/**
 	 *
 	 */
@@ -856,6 +903,36 @@ public class JRVerifier
 				{
 					addBrokenRule("Report style name missing.", style);
 				}
+				
+				verifyConditionalStyles(style);
+			}
+		}
+	}
+
+	/**
+	 *
+	 */
+	private void verifyConditionalStyles(JRStyle style)
+	{
+		JRConditionalStyle[] condStyles = style.getConditionalStyles();
+		if (condStyles != null && condStyles.length > 0)
+		{
+			for(int index = 0; index < condStyles.length; index++)
+			{
+				JRConditionalStyle condStyle = condStyles[index];
+
+				if (log.isWarnEnabled())
+				{
+					if (condStyle.getName() != null)
+					{
+						log.warn("Conditional style should not have a name.");
+					}
+
+					if (condStyle.isDefault())
+					{
+						log.warn("Conditional style can't be the default style.");
+					}
+				}
 			}
 		}
 	}
@@ -966,6 +1043,7 @@ public class JRVerifier
 	private void verifySortFields(JRDesignDataset dataset)
 	{
 		JRField[] fields = dataset.getFields();
+		JRVariable[] variables = dataset.getVariables();
 		JRSortField[] sortFields = dataset.getSortFields();
 		if (sortFields != null && sortFields.length > 0)
 		{
@@ -982,16 +1060,34 @@ public class JRVerifier
 				{
 					boolean isFound = false;
 
-					int j = 0;
-					while (!isFound && j < fields.length)
+					if (sortField.getType() == SortFieldTypeEnum.VARIABLE)
 					{
-						isFound = sortFieldName.equals(fields[j].getName());
-						j++;
+						if (variables != null)
+						{
+							int j = 0;
+							while (!isFound && j < variables.length)
+							{
+								isFound = sortFieldName.equals(variables[j].getName());
+								j++;
+							}
+						}
+					}
+					else
+					{
+						if (fields != null)
+						{
+							int j = 0;
+							while (!isFound && j < fields.length)
+							{
+								isFound = sortFieldName.equals(fields[j].getName());
+								j++;
+							}
+						}
 					}
 
 					if (!isFound)
 					{
-						addBrokenRule("Sort field \"" + sortFieldName + "\" not declared.", sortField);
+						addBrokenRule("Sort " + sortField.getType().getName().toLowerCase() + " \'" + sortFieldName + "\' not found in dataset.", sortField);
 					}
 				}
 			}
@@ -1037,8 +1133,8 @@ public class JRVerifier
 								}
 								else
 								{
-									if (variable.getCalculation() != JRVariable.CALCULATION_COUNT && variable.getCalculation() != JRVariable.CALCULATION_DISTINCT_COUNT
-											&& variable.getCalculation() != JRVariable.CALCULATION_SYSTEM && !valueClass.isAssignableFrom(expression.getValueClass()))
+									if (variable.getCalculationValue() != CalculationEnum.COUNT && variable.getCalculationValue() != CalculationEnum.DISTINCT_COUNT
+											&& variable.getCalculationValue() != CalculationEnum.SYSTEM && !valueClass.isAssignableFrom(expression.getValueClass()))
 									{
 										addBrokenRule("The variable expression class is not compatible with the variable's class : " + variable.getName(), expression);
 									}
@@ -1071,8 +1167,8 @@ public class JRVerifier
 					addBrokenRule(e, variable);
 				}
 
-				byte resetType = variable.getResetType();
-				if (resetType == JRVariable.RESET_TYPE_GROUP)
+				ResetTypeEnum resetType = variable.getResetTypeValue();
+				if (resetType == ResetTypeEnum.GROUP)
 				{
 					if (variable.getResetGroup() == null)
 					{
@@ -1089,8 +1185,8 @@ public class JRVerifier
 					}
 				}
 
-				byte incrementType = variable.getIncrementType();
-				if (incrementType == JRVariable.RESET_TYPE_GROUP)
+				IncrementTypeEnum incrementType = variable.getIncrementTypeValue();
+				if (incrementType == IncrementTypeEnum.GROUP)
 				{
 					if (variable.getIncrementGroup() == null)
 					{
@@ -1107,14 +1203,14 @@ public class JRVerifier
 					}
 				}
 
-				if (!isMainDataset)
+				if (!isMainDataset && !variable.isSystemDefined())
 				{
-					if (resetType == JRVariable.RESET_TYPE_COLUMN || resetType == JRVariable.RESET_TYPE_PAGE)
+					if (resetType == ResetTypeEnum.COLUMN || resetType == ResetTypeEnum.PAGE)
 					{
 						addBrokenRule("Variable " + variable.getName() + " of dataset " + dataset.getName() + " cannot have Column or Page reset type.", variable);
 					}
 
-					if (incrementType == JRVariable.RESET_TYPE_COLUMN || incrementType == JRVariable.RESET_TYPE_PAGE)
+					if (incrementType == IncrementTypeEnum.COLUMN || incrementType == IncrementTypeEnum.PAGE)
 					{
 						addBrokenRule("Variable " + variable.getName() + " of dataset " + dataset.getName() + " cannot have Column or Page increment type.", variable);
 					}
@@ -2421,8 +2517,8 @@ public class JRVerifier
 			addBrokenRule("Measure name missing.", measure);
 		}
 
-		byte calculation = measure.getCalculation();
-		if (calculation == JRVariable.CALCULATION_SYSTEM)
+		CalculationEnum calculation = measure.getCalculationValue();
+		if (calculation == CalculationEnum.SYSTEM)
 		{
 			addBrokenRule("Crosstab mesures cannot have system calculation", measure);
 		}
@@ -2456,11 +2552,11 @@ public class JRVerifier
 			{
 				addBrokenRule("Measure value class missing.", measure);
 			}
-			else if (expressionClass != null && calculation != JRVariable.CALCULATION_COUNT && calculation != JRVariable.CALCULATION_DISTINCT_COUNT && !valueClass.isAssignableFrom(expressionClass))
+			else if (expressionClass != null && calculation != CalculationEnum.COUNT && calculation != CalculationEnum.DISTINCT_COUNT && !valueClass.isAssignableFrom(expressionClass))
 			{
 				addBrokenRule("The class of the expression is not compatible with the class of the measure " + measureName + ".", valueExpression);
 			}
-			if (measure.getPercentageOfType() != JRCrosstabMeasure.PERCENTAGE_TYPE_NONE)
+			if (measure.getPercentageType() != CrosstabPercentageEnum.NONE)
 			{
 				Class percentageCalculatorClass = measure.getPercentageCalculatorClass();
 				if (percentageCalculatorClass == null)
@@ -2512,7 +2608,7 @@ public class JRVerifier
 	{
 		verifyReportElement(chart);
 		
-		if (chart.getEvaluationTime() == JRExpression.EVALUATION_TIME_AUTO)
+		if (chart.getEvaluationTimeValue() == EvaluationTimeEnum.AUTO)
 		{
 			addBrokenRule("Charts do not support Auto evaluation time.", chart);
 		}
@@ -2585,7 +2681,7 @@ public class JRVerifier
 					{
 						JRTextField textField = (JRTextField) element;
 
-						if (textField.getEvaluationTime() != JRExpression.EVALUATION_TIME_NOW)
+						if (textField.getEvaluationTimeValue() != EvaluationTimeEnum.NOW)
 						{
 							addBrokenRule("Elements with delayed evaluation time are not supported inside crosstab cells.", textField);
 						}
@@ -2596,7 +2692,7 @@ public class JRVerifier
 					{
 						JRImage image = (JRImage) element;
 
-						if (image.getEvaluationTime() != JRExpression.EVALUATION_TIME_NOW)
+						if (image.getEvaluationTimeValue() != EvaluationTimeEnum.NOW)
 						{
 							addBrokenRule("Elements with delayed evaluation time are not supported inside crosstab cells.", image);
 						}
@@ -2633,21 +2729,21 @@ public class JRVerifier
 
 		if (datasetRun != null)
 		{
-			byte incrementType = dataset.getIncrementType();
-			if (incrementType == JRVariable.RESET_TYPE_PAGE || incrementType == JRVariable.RESET_TYPE_COLUMN)
+			IncrementTypeEnum incrementType = dataset.getIncrementTypeValue();
+			if (incrementType == IncrementTypeEnum.PAGE || incrementType == IncrementTypeEnum.COLUMN)
 			{
 				addBrokenRule("Chart datasets with dataset run cannont have Column or Page increment type.", dataset);
 			}
 
-			byte resetType = dataset.getResetType();
-			if (resetType == JRVariable.RESET_TYPE_PAGE || resetType == JRVariable.RESET_TYPE_COLUMN)
+			ResetTypeEnum resetType = dataset.getResetTypeValue();
+			if (resetType == ResetTypeEnum.PAGE || resetType == ResetTypeEnum.COLUMN)
 			{
 				addBrokenRule("Chart datasets with dataset run cannont have Column or Page reset type.", dataset);
 			}
-			else if (resetType != JRVariable.RESET_TYPE_REPORT)
-			{
-				//doesn't make sense, but let it go
-			}
+//			else if (resetType != ResetTypeEnum.REPORT)
+//			{
+//				//doesn't make sense, but let it go
+//			}
 
 			verifyDatasetRun(datasetRun);
 		}
@@ -3088,12 +3184,45 @@ public class JRVerifier
 	{
 		if (element.getWidth() < 0)
 		{
-			addBrokenRule("Element cannot have negative width.", element);
+			if (allowElementNegativeWidth)
+			{
+				if (log.isWarnEnabled())
+				{
+					log.warn("Element has negative width: " + element.getWidth());
+				}
+			}
+			else
+			{
+				addBrokenRule("Element cannot have negative width.", element);
+			}
+		}
+		
+		if (element.getY() < 0 && !allowElementNegativeY(element))
+		{
+			addBrokenRule("Element negative Y " + element.getY() + " not allowed", 
+					element);
 		}
 
 		verifyProperyExpressions(element.getPropertyExpressions());
 	}
 
+	protected boolean allowElementNegativeY(JRElement element)
+	{
+		// default to report/global property
+		boolean allow = allowElementNegativeY;
+		if (element.hasProperties())
+		{
+			JRPropertiesMap properties = element.getPropertiesMap();
+			if (properties.containsProperty(PROPERTY_ALLOW_ELEMENT_NEGATIVE_Y))
+			{
+				// use element level property
+				allow = JRProperties.asBoolean(properties.getProperty(
+						PROPERTY_ALLOW_ELEMENT_NEGATIVE_Y));
+			}
+		}
+		return allow;
+	}
+	
 	protected void verifyProperyExpressions(
 			JRPropertyExpression[] propertyExpressions)
 	{
@@ -3200,7 +3329,7 @@ public class JRVerifier
 	{
 		verifyReportElement(element);
 
-		if (element.getEvaluationTime() == JRExpression.EVALUATION_TIME_GROUP)
+		if (element.getEvaluationTimeValue() == EvaluationTimeEnum.GROUP)
 		{
 			String groupName = element.getEvaluationGroupName();
 			if (groupName == null)
@@ -3256,7 +3385,7 @@ public class JRVerifier
 			breakHeight = band.getHeight();
 			JRElement[] elements = band.getElements();
 			if (
-				JRBand.SPLIT_TYPE_IMMEDIATE.equals(band.getSplitType())
+				SplitTypeEnum.IMMEDIATE == band.getSplitTypeValue()
 				&& elements != null && elements.length > 0
 				)
 			{
