@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 	
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRExporterGridCell.java 3684 2010-04-06 09:27:45Z shertage $
+ * @version $Id: JRExporterGridCell.java 3940 2010-08-20 10:35:15Z teodord $
  */
 public abstract class JRExporterGridCell
 {
@@ -47,18 +47,18 @@ public abstract class JRExporterGridCell
 	/**
 	 *
 	 */
-	private ElementWrapper wrapper = null; 
+	private ElementWrapper wrapper; 
 	
 	private Color backcolor;
 	private Color forecolor;
 	private JRLineBox box;
 	
-	private int width = 0;
-	private int height = 0;
-	private int colSpan = 0;
-	private int rowSpan = 0;
+	private int width;
+	private int height;
+	private int colSpan;
+	private int rowSpan;
 
-	private JRGridLayout layout = null;
+	private JRGridLayout layout;
 
 
 	/**
