@@ -36,12 +36,12 @@ import net.sf.jasperreports.engine.util.JRProperties;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRHtmlExporterNature.java 3875 2010-07-14 09:58:21Z teodord $
+ * @version $Id: JRHtmlExporterNature.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRHtmlExporterNature implements ExporterNature
 {
 	
-	private ExporterFilter filter = null;
+	private ExporterFilter filter;
 	private final boolean deep;
 	private final boolean ignorePageMargins;
 	
