@@ -52,7 +52,7 @@ import com.lowagie.text.pdf.PdfWriter;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRPdfExporterTagHelper.java 3033 2009-08-27 11:46:22Z teodord $
+ * @version $Id: JRPdfExporterTagHelper.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public class JRPdfExporterTagHelper
 {
@@ -69,19 +69,19 @@ public class JRPdfExporterTagHelper
 	public static final String TAG_END = "end";
 	public static final String TAG_FULL = "full";
 	
-	protected JRPdfExporter exporter = null;
+	protected JRPdfExporter exporter;
 
-	protected PdfContentByte pdfContentByte = null;
-	protected PdfWriter pdfWriter = null;
+	protected PdfContentByte pdfContentByte;
+	protected PdfWriter pdfWriter;
 
-	protected PdfStructureElement allTag = null;
-	protected Stack tagStack = null;
+	protected PdfStructureElement allTag;
+	protected Stack tagStack;
 	protected boolean isTagEmpty = true;
 	protected int crtCrosstabRowY = -1;
-	protected int crosstabFrameDepth = 0;
-	protected boolean isDataCellPrinted = false;
+	protected int crosstabFrameDepth;
+	protected boolean isDataCellPrinted;
 
-	protected boolean isTagged = false;
+	protected boolean isTagged;
 
 	/**
 	 *
@@ -107,7 +107,9 @@ public class JRPdfExporterTagHelper
 		this.pdfWriter = pdfWriter;
 		
 		if (isTagged)
+		{
 			pdfWriter.setTagged();
+		}
 	}
 	
 	/**
@@ -128,8 +130,10 @@ public class JRPdfExporterTagHelper
 						JRPdfExporterParameter.TAG_LANGUAGE,
 						JRPdfExporterParameter.PROPERTY_TAG_LANGUAGE
 						);
-			if (language != null)	
+			if (language != null)
+			{
 				allTag.put(PdfName.LANG, new PdfString(language));
+			}
 			tagStack = new Stack();
 			tagStack.push(allTag);
 		}
@@ -266,10 +270,10 @@ public class JRPdfExporterTagHelper
 						crosstabFrameDepth++;
 						isDataCellPrinted = false;
 					}
-					else
-					{
-						//normal frame outside crosstab
-					}
+//					else
+//					{
+//						//normal frame outside crosstab
+//					}
 				}
 			}
 			else
@@ -322,7 +326,9 @@ public class JRPdfExporterTagHelper
 			PdfStructureElement imageTag = new PdfStructureElement(allTag, PdfName.IMAGE);
 			pdfContentByte.beginMarkedContentSequence(imageTag);
 			if (printImage.getHyperlinkTooltip() != null)
+			{
 				imageTag.put(PdfName.ALT, new PdfString(printImage.getHyperlinkTooltip()));
+			}
 		}
 	}
 
@@ -494,9 +500,13 @@ public class JRPdfExporterTagHelper
 			PdfArray a = new PdfArray();
 			PdfDictionary dict = new PdfDictionary();
 			if (colSpan > 1)
+			{
 				dict.put(new PdfName("ColSpan"), new PdfNumber(colSpan));
+			}
 			if (rowSpan > 1)
+			{
 				dict.put(new PdfName("RowSpan"), new PdfNumber(rowSpan));
+			}
 			dict.put(PdfName.O, new PdfName("Table"));
 			a.add(dict);
 			parentTag.put(PdfName.A, a);
