@@ -40,38 +40,38 @@ import net.sf.jasperreports.engine.util.MaxFontSizeFinder;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TextRenderer.java 3419 2010-02-18 08:16:30Z teodord $
+ * @version $Id: TextRenderer.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public class TextRenderer
 {
 	public static final FontRenderContext LINE_BREAK_FONT_RENDER_CONTEXT = new FontRenderContext(null, true, true);
 
-	private Graphics2D grx = null;
-	private int x = 0;
-	private int y = 0;
-	private int topPadding = 0;
-	private int leftPadding = 0;
-	private float formatWidth = 0;
-	private float verticalOffset = 0;
-	private float lineSpacingFactor = 0;
-	private float leadingOffset = 0;
-	private float textHeight = 0;
-	private float drawPosY = 0;
-	private float drawPosX = 0;
-	private boolean isMaxHeightReached = false;
-	private HorizontalAlignEnum horizontalAlignment = null;
-	private int fontSize = 0;
+	private Graphics2D grx;
+	private int x;
+	private int y;
+	private int topPadding;
+	private int leftPadding;
+	private float formatWidth;
+	private float verticalOffset;
+	private float lineSpacingFactor;
+	private float leadingOffset;
+	private float textHeight;
+	private float drawPosY;
+	private float drawPosX;
+	private boolean isMaxHeightReached;
+	private HorizontalAlignEnum horizontalAlignment;
+	private int fontSize;
 	
 	/**
 	 * 
 	 */
-	private MaxFontSizeFinder maxFontSizeFinder = null;
+	private MaxFontSizeFinder maxFontSizeFinder;
 	
 	/**
 	 * 
 	 */
 	private boolean isMinimizePrinterJobSize = true;
-	private boolean ignoreMissingFont = false;
+	private boolean ignoreMissingFont;
 
 	
 	/**
