@@ -34,7 +34,6 @@ package net.sf.jasperreports.engine.export.draw;
 import java.awt.Graphics2D;
 
 import net.sf.jasperreports.engine.JRCommonText;
-import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRStyledTextAttributeSelector;
 import net.sf.jasperreports.engine.export.TextRenderer;
@@ -44,15 +43,15 @@ import net.sf.jasperreports.engine.util.JRStyledText;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: TextDrawer.java 3653 2010-03-30 16:12:52Z teodord $
+ * @version $Id: TextDrawer.java 3991 2010-10-12 20:10:55Z lucianc $
  */
-public class TextDrawer extends ElementDrawer
+public class TextDrawer extends ElementDrawer<JRPrintText>
 {
 
 	/**
 	 *
 	 */
-	protected TextRenderer textRenderer = null;
+	protected TextRenderer textRenderer;
 
 	
 	/**
@@ -69,10 +68,8 @@ public class TextDrawer extends ElementDrawer
 	/**
 	 *
 	 */
-	public void draw(Graphics2D grx, JRPrintElement element, int offsetX, int offsetY)
+	public void draw(Graphics2D grx, JRPrintText text, int offsetX, int offsetY)
 	{
-		JRPrintText text = (JRPrintText)element;
-
 		JRStyledText styledText = getStyledText(text);
 		
 		if (styledText == null)
