@@ -58,7 +58,6 @@ import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRParameter;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintPage;
-import net.sf.jasperreports.engine.JRReport;
 import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRReportTemplate;
 import net.sf.jasperreports.engine.JRRuntimeException;
@@ -71,6 +70,15 @@ import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.JasperReport;
 import net.sf.jasperreports.engine.base.JRBasePrintPage;
 import net.sf.jasperreports.engine.base.JRVirtualPrintPage;
+import net.sf.jasperreports.engine.type.BandTypeEnum;
+import net.sf.jasperreports.engine.type.CalculationEnum;
+import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
+import net.sf.jasperreports.engine.type.FooterPositionEnum;
+import net.sf.jasperreports.engine.type.OrientationEnum;
+import net.sf.jasperreports.engine.type.PrintOrderEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
+import net.sf.jasperreports.engine.type.WhenNoDataTypeEnum;
+import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 import net.sf.jasperreports.engine.util.DefaultFormatFactory;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
@@ -85,7 +93,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRBaseFiller.java 3209 2009-11-23 15:48:15Z teodord $
+ * @version $Id: JRBaseFiller.java 3953 2010-09-20 13:54:34Z teodord $
  */
 public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualPrintPage.IdentityDataProvider//, JRDefaultFontProvider
 {
@@ -166,7 +174,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	protected JRBaseFiller parentFiller = null;
+	protected JRBaseFiller parentFiller;
 	protected JRFillSubreport parentElement;
 
 	private final JRFillObjectFactory factory;
@@ -176,95 +184,99 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	private boolean isInterrupted = false;
+	private boolean isInterrupted;
 
 	/**
 	 *
 	 */
-	protected String name = null;
+	protected String name;
 
 	protected int columnCount = 1;
 
-	protected byte printOrder = JRReport.PRINT_ORDER_VERTICAL;
+	protected PrintOrderEnum printOrder = PrintOrderEnum.VERTICAL;
 
-	protected int pageWidth = 0;
+	protected RunDirectionEnum columnDirection = RunDirectionEnum.LTR;
 
-	protected int pageHeight = 0;
+	protected int pageWidth;
 
-	protected byte orientation = JRReport.ORIENTATION_PORTRAIT;
+	protected int pageHeight;
 
-	protected byte whenNoDataType = JRReport.WHEN_NO_DATA_TYPE_NO_PAGES;
+	protected OrientationEnum orientation = OrientationEnum.PORTRAIT;
 
-	protected int columnWidth = 0;
+	protected WhenNoDataTypeEnum whenNoDataType = WhenNoDataTypeEnum.NO_PAGES;
 
-	protected int columnSpacing = 0;
+	protected int columnWidth;
 
-	protected int leftMargin = 0;
+	protected int columnSpacing;
 
-	protected int rightMargin = 0;
+	protected int leftMargin;
 
-	protected int topMargin = 0;
+	protected int rightMargin;
 
-	protected int bottomMargin = 0;
+	protected int topMargin;
 
-	protected boolean isTitleNewPage = false;
+	protected int bottomMargin;
 
-	protected boolean isSummaryNewPage = false;
+	protected boolean isTitleNewPage;
 
-	protected boolean isSummaryWithPageHeaderAndFooter = false;
+	protected boolean isSummaryNewPage;
 
-	protected boolean isFloatColumnFooter = false;
+	protected boolean isSummaryWithPageHeaderAndFooter;
+
+	protected boolean isFloatColumnFooter;
 
 	/**
 	 * the resource missing handling type
 	 */
-	protected byte whenResourceMissingType = JRReport.WHEN_RESOURCE_MISSING_TYPE_NULL;
+	protected WhenResourceMissingTypeEnum whenResourceMissingType = WhenResourceMissingTypeEnum.NULL;
 
 	protected JRFillReportTemplate[] reportTemplates;
+	
+	protected List<JRTemplate> templates;
 
-	protected JRReportFont defaultFont = null;
+	protected JRReportFont defaultFont;
 
-	protected JRReportFont[] fonts = null;
+	protected JRReportFont[] fonts;
 
-	protected JRStyle defaultStyle = null;
+	protected JRStyle defaultStyle;
 
-	protected JRStyle[] styles = null;
+	protected JRStyle[] styles;
 
 	/**
 	 * Main report dataset.
 	 */
 	protected JRFillDataset mainDataset;
 
-	protected JRFillGroup[] groups = null;
+	protected JRFillGroup[] groups;
 
-	protected JRFillSection missingFillSection = null;
-	protected JRFillBand missingFillBand = null;
+	protected JRFillSection missingFillSection;
+	protected JRFillBand missingFillBand;
 
-	protected JRFillBand background = null;
+	protected JRFillBand background;
 
-	protected JRFillBand title = null;
+	protected JRFillBand title;
 
-	protected JRFillBand pageHeader = null;
+	protected JRFillBand pageHeader;
 
-	protected JRFillBand columnHeader = null;
+	protected JRFillBand columnHeader;
 
-	protected JRFillSection detailSection = null;
+	protected JRFillSection detailSection;
 
-	protected JRFillBand columnFooter = null;
+	protected JRFillBand columnFooter;
 
-	protected JRFillBand pageFooter = null;
+	protected JRFillBand pageFooter;
 
-	protected JRFillBand lastPageFooter = null;
+	protected JRFillBand lastPageFooter;
 
-	protected JRFillBand summary = null;
+	protected JRFillBand summary;
 
-	protected JRFillBand noData = null;
+	protected JRFillBand noData;
 
-	protected JRVirtualizer virtualizer = null;
+	protected JRVirtualizer virtualizer;
 
-	protected ClassLoader reportClassLoader = null;
+	protected ClassLoader reportClassLoader;
 
-	protected FormatFactory formatFactory = null;
+	protected FormatFactory formatFactory;
 
 	protected URLStreamHandlerFactory urlHandlerFactory;
 
@@ -280,11 +292,11 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	protected JasperPrint jasperPrint = null;
+	protected JasperPrint jasperPrint;
 
-	protected JRPrintPage printPage = null;
+	protected JRPrintPage printPage;
 
-	protected int printPageStretchHeight = 0;
+	protected int printPageStretchHeight;
 
 	/**
 	 * List of {@link JRFillBand JRFillBand} objects containing all bands of the
@@ -327,34 +339,40 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 	private JRSubreportRunner subreportRunner;
 
-	protected SavePoint keepTogetherSavePoint = null;
+	protected SavePoint keepTogetherSavePoint;
 	
 
 	/**
 	 *
 	 */
-	protected boolean isCreatingNewPage = false;
-	protected boolean isNewPage = false;
-	protected boolean isNewColumn = false;
+	protected boolean isCreatingNewPage;
+	protected boolean isNewPage;
+	protected boolean isNewColumn;
 	protected boolean isNewGroup = true;
-	protected boolean isFirstPageBand = false;
-	protected boolean isFirstColumnBand = false;
+	protected boolean isFirstPageBand;
+	protected boolean isFirstColumnBand;
 
-	protected int columnIndex = 0;
+	protected int columnIndex;
 
-	protected int offsetX = 0;
-	protected int offsetY = 0;
-	protected int columnHeaderOffsetY = 0;
-	protected int columnFooterOffsetY = 0;
-	protected int lastPageColumnFooterOffsetY = 0;
+	protected int offsetX;
+	protected int offsetY;
+	protected int columnHeaderOffsetY;
+	protected int columnFooterOffsetY;
+	protected int lastPageColumnFooterOffsetY;
 
-	protected boolean isLastPageFooter = false;
+	protected boolean isLastPageFooter;
 
+	protected JRBaseFiller(JasperReport jasperReport, JREvaluator initEvaluator, JRFillSubreport parentElement) throws JRException
+	{
+		this(jasperReport, (DatasetExpressionEvaluator) initEvaluator, parentElement);
+	}
 
 	/**
 	 *
 	 */
-	protected JRBaseFiller(JasperReport jasperReport, JREvaluator initEvaluator, JRFillSubreport parentElement) throws JRException
+	protected JRBaseFiller(JasperReport jasperReport, 
+			DatasetExpressionEvaluator initEvaluator, 
+			JRFillSubreport parentElement) throws JRException
 	{
 		this.fillerId = Integer.toString(System.identityHashCode(this));
 
@@ -386,11 +404,12 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		/*   */
 		name = jasperReport.getName();
 		columnCount = jasperReport.getColumnCount();
-		printOrder = jasperReport.getPrintOrder();
+		printOrder = jasperReport.getPrintOrderValue();
+		columnDirection = jasperReport.getColumnDirection();
 		pageWidth = jasperReport.getPageWidth();
 		pageHeight = jasperReport.getPageHeight();
-		orientation = jasperReport.getOrientation();
-		whenNoDataType = jasperReport.getWhenNoDataType();
+		orientation = jasperReport.getOrientationValue();
+		whenNoDataType = jasperReport.getWhenNoDataTypeValue();
 		columnWidth = jasperReport.getColumnWidth();
 		columnSpacing = jasperReport.getColumnSpacing();
 		leftMargin = jasperReport.getLeftMargin();
@@ -401,7 +420,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		isSummaryNewPage = jasperReport.isSummaryNewPage();
 		isSummaryWithPageHeaderAndFooter = jasperReport.isSummaryWithPageHeaderAndFooter();
 		isFloatColumnFooter = jasperReport.isFloatColumnFooter();
-		whenResourceMissingType = jasperReport.getWhenResourceMissingType();
+		whenResourceMissingType = jasperReport.getWhenResourceMissingTypeValue();
 
 		jasperPrint = new JasperPrint();
 		
@@ -452,7 +471,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			background.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.BACKGROUND
+					BandTypeEnum.BACKGROUND
 					)
 				);
 		}
@@ -463,7 +482,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			title.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.TITLE
+					BandTypeEnum.TITLE
 					)
 				);
 		}
@@ -474,7 +493,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			pageHeader.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.PAGE_HEADER
+					BandTypeEnum.PAGE_HEADER
 					)
 				);
 		}
@@ -485,7 +504,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			columnHeader.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.COLUMN_HEADER
+					BandTypeEnum.COLUMN_HEADER
 					)
 				);
 		}
@@ -496,7 +515,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			detailSection.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.DETAIL
+					BandTypeEnum.DETAIL
 					)
 				);
 		}
@@ -507,7 +526,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			columnFooter.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.COLUMN_FOOTER
+					BandTypeEnum.COLUMN_FOOTER
 					)
 				);
 		}
@@ -518,7 +537,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			pageFooter.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.PAGE_FOOTER
+					BandTypeEnum.PAGE_FOOTER
 					)
 				);
 		}
@@ -529,7 +548,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			lastPageFooter.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.LAST_PAGE_FOOTER
+					BandTypeEnum.LAST_PAGE_FOOTER
 					)
 				);
 		}
@@ -544,7 +563,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			summary.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.SUMMARY
+					BandTypeEnum.SUMMARY
 					)
 				);
 		}
@@ -555,7 +574,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			noData.setOrigin(
 				new JROrigin(
 					reportName,
-					JROrigin.NO_DATA
+					BandTypeEnum.NO_DATA
 					)
 				);
 		}
@@ -589,7 +608,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	 * 
 	 * @return the map of parameter values
 	 */
-	protected Map getParameterValuesMap()
+	public Map getParameterValuesMap()
 	{
 		return mainDataset.getParameterValuesMap();
 	}
@@ -874,18 +893,22 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 		try
 		{
-			setParameters(parameterValues);
-
-			loadStyles();
-
 			if (parentFiller != null)
 			{
 				parentFiller.registerSubfiller(this);
 			}
 
+			setParameters(parameterValues);
+
+			loadStyles();
+
 			jasperPrint.setName(name);
 			jasperPrint.setPageWidth(pageWidth);
 			jasperPrint.setPageHeight(pageHeight);
+			jasperPrint.setTopMargin(topMargin);
+			jasperPrint.setLeftMargin(leftMargin);
+			jasperPrint.setBottomMargin(bottomMargin);
+			jasperPrint.setRightMargin(rightMargin);
 			jasperPrint.setOrientation(orientation);
 
 			jasperPrint.setDefaultFont(defaultFont);
@@ -953,7 +976,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		}
 	}
 
-	protected void addPrintStyle(JRStyle style) throws JRException
+	public void addPrintStyle(JRStyle style) throws JRException
 	{
 		jasperPrint.addStyle(style, true);
 	}
@@ -1035,34 +1058,45 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		return styleList;
 	}
 
-	protected List collectTemplateStyles() throws JRException
+	protected void collectTemplates() throws JRException
 	{
-		List externalStyles = new ArrayList();
-		HashSet loadedLocations = new HashSet();
+		templates = new ArrayList<JRTemplate>();
 
 		if (reportTemplates != null)
 		{
-			for (int i = 0; i < reportTemplates.length; i++)
+			for (JRFillReportTemplate reportTemplate : reportTemplates)
 			{
-				JRFillReportTemplate reportTemplate = reportTemplates[i];
 				JRTemplate template = reportTemplate.evaluate();
 				if (template != null)
 				{
-					collectStyles(template, externalStyles, loadedLocations);
+					templates.add(template);
 				}
 			}
 		}
 
-		Collection paramTemplates = (Collection) mainDataset.getParameterValue(JRParameter.REPORT_TEMPLATES, true);
+		Collection paramTemplates = (Collection) mainDataset.getParameterValue(
+				JRParameter.REPORT_TEMPLATES, true);
 		if (paramTemplates != null)
 		{
-			for (Iterator it = paramTemplates.iterator(); it.hasNext();)
-			{
-				JRTemplate template = (JRTemplate) it.next();
-				collectStyles(template, externalStyles, loadedLocations);
-			}
+			templates.addAll(paramTemplates);
 		}
+	}
 
+	public List<JRTemplate> getTemplates()
+	{
+		return templates;
+	}
+	
+	protected List collectTemplateStyles() throws JRException
+	{
+		collectTemplates();
+		
+		List externalStyles = new ArrayList();
+		HashSet loadedLocations = new HashSet();
+		for (JRTemplate template : templates)
+		{
+			collectStyles(template, externalStyles, loadedLocations);
+		}
 		return externalStyles;
 	}
 
@@ -1601,7 +1635,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	 * @param calculation
 	 *            the calculation type
 	 */
-	protected void addVariableCalculationReq(String variableName, byte calculation)
+	protected void addVariableCalculationReq(String variableName, CalculationEnum calculation)
 	{
 		mainDataset.addVariableCalculationReq(variableName, calculation);
 	}
@@ -1737,13 +1771,13 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 				Map idMap = new HashMap();
 				for (int i = 0; i < identityData.length; i++)
 				{
-					idMap.put(new Integer(identityData[i].getIdentity()), identityData[i].getObject());
+					idMap.put(Integer.valueOf(identityData[i].getIdentity()), identityData[i].getObject());
 				}
 
 				for (ListIterator i = printPage.getElements().listIterator(); i.hasNext();)
 				{
 					Object element = i.next();
-					Integer id = new Integer(System.identityHashCode(element));
+					Integer id = Integer.valueOf(System.identityHashCode(element));
 
 					Object idObject = idMap.get(id);
 					if (idObject != null)
@@ -1767,8 +1801,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 		public static JRVirtualPrintPage.IdentityDataProvider removeIdentityDataProvider(JRPrintPage printPage)
 		{
-			JRVirtualPrintPage.IdentityDataProvider provider = (JRVirtualPrintPage.IdentityDataProvider) providers.remove(printPage);
-			return provider;
+			return (JRVirtualPrintPage.IdentityDataProvider) providers.remove(printPage);
 		}
 	}
 
@@ -1803,6 +1836,10 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 		return mainDataset.evaluateExpression(expression, evaluation);
 	}
 
+	protected JRFillExpressionEvaluator getExpressionEvaluator()
+	{
+		return calculator;
+	}
 
 	private void createDatasets() throws JRException
 	{
@@ -1833,7 +1870,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	}
 
 
-	protected byte getWhenResourceMissingType()
+	protected WhenResourceMissingTypeEnum getWhenResourceMissingType()
 	{
 		return mainDataset.whenResourceMissingType;
 	}
@@ -1897,13 +1934,13 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 
 	protected void addBoundElement(JRFillElement element, JRPrintElement printElement, 
-			byte evaluationType, String groupName, JRFillBand band)
+			EvaluationTimeEnum evaluationType, String groupName, JRFillBand band)
 	{
 		JRFillGroup group = groupName == null ? null : getGroup(groupName);
 		addBoundElement(element, printElement, evaluationType, group, band);
 	}
 
-	protected void addBoundElement(JRFillElement element, JRPrintElement printElement, byte evaluationType, JRGroup group, JRFillBand band)
+	protected void addBoundElement(JRFillElement element, JRPrintElement printElement, EvaluationTimeEnum evaluationType, JRGroup group, JRFillBand band)
 	{
 		JREvaluationTime evaluationTime = JREvaluationTime.getEvaluationTime(evaluationType, group, band);
 		addBoundElement(element, printElement, evaluationTime);
@@ -1970,7 +2007,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 						JRVirtualPrintPage.ObjectIDPair idPair = new JRVirtualPrintPage.ObjectIDPair(key);
 						identityList.add(idPair);
 
-						id = new Integer(idPair.getIdentity());
+						id = Integer.valueOf(idPair.getIdentity());
 						allElements.put(key, id);
 					}
 					idMap.put(id, entry.getValue());
@@ -2020,7 +2057,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 				for (int i = 0; i < identityData.length; i++)
 				{
 					JRVirtualPrintPage.ObjectIDPair idPair = identityData[i];
-					Integer id = new Integer(idPair.getIdentity());
+					Integer id = Integer.valueOf(idPair.getIdentity());
 
 					Object value = idMap.get(id);
 					if (value != null)
@@ -2085,7 +2122,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	/**
 	 *
 	 */
-	protected SavePoint advanceSavePoint(SavePoint savePoint, SavePoint newSavePoint) throws JRException
+	protected SavePoint advanceSavePoint(SavePoint savePoint, SavePoint newSavePoint)
 	{
 		if (savePoint == null)
 		{
@@ -2108,7 +2145,7 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			{
 				// page/column break occurred, so the move operation 
 				// must be performed on the previous save point
-				moveSavePointContent(savePoint);
+				savePoint.moveSavePointContent();
 				savePoint = newSavePoint;
 			}
 		}
@@ -2117,23 +2154,6 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 	}
 
 
-	/**
-	 *
-	 */
-	protected void moveSavePointContent(SavePoint savePoint)
-	{
-		if (savePoint != null && savePoint.footerPosition != JRGroup.FOOTER_POSITION_NORMAL)//FIXME is footerPosition testing required here?
-		{
-			//no page/column break occurred
-			for(int i = savePoint.startElementIndex; i < savePoint.endElementIndex; i++)
-			{
-				JRPrintElement printElement = (JRPrintElement)savePoint.page.getElements().get(i);
-				printElement.setY(printElement.getY() + savePoint.heightOffset);
-			}
-		}
-	}
-	
-
 	/**
 	 *
 	 */
@@ -2147,12 +2167,11 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 				if (!keepTogetherSavePoint.isNewColumn)
 				{
-					for(int i = keepTogetherSavePoint.startElementIndex; i < keepTogetherSavePoint.endElementIndex; i++)
-					{
-						JRPrintElement printElement = (JRPrintElement)keepTogetherSavePoint.page.getElements().get(i);
-						printElement.setX(printElement.getX() + columnSpacing + columnWidth);
-						printElement.setY(offsetY + printElement.getY() - keepTogetherSavePoint.startOffsetY);
-					}
+					keepTogetherSavePoint.addContent(
+						printPage, 
+						columnSpacing + columnWidth,
+						offsetY - keepTogetherSavePoint.startOffsetY
+						);
 
 					offsetY = offsetY + keepTogetherSavePoint.endOffsetY - keepTogetherSavePoint.startOffsetY;
 				}
@@ -2163,19 +2182,11 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 
 				if (!keepTogetherSavePoint.isNewPage)
 				{
-					for(int i = keepTogetherSavePoint.startElementIndex; i < keepTogetherSavePoint.endElementIndex; i++)
-					{
-						JRPrintElement printElement = (JRPrintElement)keepTogetherSavePoint.page.getElements().get(i);
-						
-						printElement.setX(printElement.getX() + (columnIndex - keepTogetherSavePoint.columnIndex) * (columnSpacing + columnWidth));
-						printElement.setY(offsetY + printElement.getY() - keepTogetherSavePoint.startOffsetY);
-
-						printPage.addElement(printElement);
-					}
-					for(int i = keepTogetherSavePoint.endElementIndex - 1; i >= keepTogetherSavePoint.startElementIndex; i--)
-					{
-						keepTogetherSavePoint.page.getElements().remove(i);
-					}
+					keepTogetherSavePoint.addContent(
+							printPage, 
+							(columnIndex - keepTogetherSavePoint.columnIndex) * (columnSpacing + columnWidth),
+							offsetY - keepTogetherSavePoint.startOffsetY
+							);
 
 					offsetY = offsetY + keepTogetherSavePoint.endOffsetY - keepTogetherSavePoint.startOffsetY;
 				}
@@ -2184,24 +2195,24 @@ public abstract class JRBaseFiller implements JRDefaultStyleProvider, JRVirtualP
 			keepTogetherSavePoint = null;
 		}
 	}
-	
 
 }
 
 
 class SavePoint
 {
-	protected JRPrintPage page = null;
-	protected int columnIndex = 0;
-	protected boolean isNewPage = false;
-	protected boolean isNewColumn = false;
-	protected int startOffsetY = 0;
-	protected int endOffsetY = 0;
-	protected int startElementIndex = 0;
-	protected int endElementIndex = 0;
-	protected int heightOffset = 0;
-	protected int groupIndex = 0;
-	protected byte footerPosition = JRGroup.FOOTER_POSITION_NORMAL;
+	protected JRPrintPage page;
+	protected int columnIndex;
+	protected boolean isNewPage;
+	protected boolean isNewColumn;
+	protected int startOffsetY;
+	protected int endOffsetY;
+	protected int startElementIndex;
+	protected int endElementIndex;
+	protected int heightOffset;
+	protected int groupIndex;
+	protected FooterPositionEnum footerPosition = FooterPositionEnum.NORMAL;
+	protected List elementsToMove = new ArrayList();
 	
 	protected SavePoint(
 		JRPrintPage page,
@@ -2241,5 +2252,48 @@ class SavePoint
 		this.endElementIndex = page.getElements().size();
 	}
 	
+	/**
+	 *
+	 */
+	protected void removeContent()
+	{
+		for(int i = endElementIndex - 1; i >= startElementIndex; i--)
+		{
+			elementsToMove.add(page.getElements().remove(i));
+		}
+	}
+
+	/**
+	 *
+	 */
+	protected void addContent(JRPrintPage printPage, int xdelta, int ydelta)
+	{
+		for(int i = elementsToMove.size() - 1; i >= 0; i--)// elementsToMove were added in reverse order
+		{
+			JRPrintElement printElement = (JRPrintElement)elementsToMove.get(i);
+
+			printElement.setX(printElement.getX() + xdelta);
+			printElement.setY(printElement.getY() + ydelta);
+
+			printPage.addElement(printElement);
+		}
+	}
+
+	/**
+	 *
+	 */
+	protected void moveSavePointContent()
+	{
+		if (footerPosition != FooterPositionEnum.NORMAL)//FIXME is footerPosition testing required here?
+		{
+			//no page/column break occurred
+			for(int i = startElementIndex; i < endElementIndex; i++)
+			{
+				JRPrintElement printElement = (JRPrintElement)page.getElements().get(i);
+				printElement.setY(printElement.getY() + heightOffset);
+			}
+		}
+	}
+
 }
 
