@@ -40,7 +40,7 @@ import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRCalculator.java 3714 2010-04-08 14:48:46Z lucianc $
+ * @version $Id: JRCalculator.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRCalculator implements JRFillExpressionEvaluator
 {
@@ -49,15 +49,15 @@ public class JRCalculator implements JRFillExpressionEvaluator
 	/**
 	 *
 	 */
-	protected Map parsm = null;
-	protected Map fldsm = null;
-	protected Map varsm = null;
-	protected JRFillVariable[] variables = null;
-	protected JRFillGroup[] groups = null;
-	protected JRFillElementDataset[] datasets = null;
+	protected Map parsm;
+	protected Map fldsm;
+	protected Map varsm;
+	protected JRFillVariable[] variables;
+	protected JRFillGroup[] groups;
+	protected JRFillElementDataset[] datasets;
 
-	private JRFillVariable pageNumber = null;
-	private JRFillVariable columnNumber = null;
+	private JRFillVariable pageNumber;
+	private JRFillVariable columnNumber;
 	
 	/**
 	 * The expression evaluator
