@@ -31,7 +31,7 @@ import net.sf.jasperreports.engine.type.ResetTypeEnum;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRDistinctCountIncrementerFactory.java 3506 2010-03-04 14:48:54Z shertage $
+ * @version $Id: JRDistinctCountIncrementerFactory.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRDistinctCountIncrementerFactory implements JRIncrementerFactory
 {
@@ -124,8 +124,8 @@ class JRDistinctCountIncrementer implements JRIncrementer
  */
 class DistinctCountHolder
 {
-	private Set distinctValues = null;
-	private Object lastValue = null;
+	private Set distinctValues;
+	private Object lastValue;
 
 	public DistinctCountHolder()
 	{
