@@ -43,7 +43,7 @@ import net.sf.jasperreports.engine.util.JRFontUtil;
  * The context is created by the master filler and inherited by the subfillers.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillContext.java 3822 2010-05-20 16:59:22Z teodord $
+ * @version $Id: JRFillContext.java 3941 2010-08-20 10:55:10Z teodord $
  * @see net.sf.jasperreports.engine.fill.JRBaseFiller
  */
 public class JRFillContext
@@ -51,10 +51,10 @@ public class JRFillContext
 	private Map loadedImages;
 	private Map loadedSubreports;
 	private Map loadedTemplates;
-	private boolean usingVirtualizer = false;
-	private boolean perPageBoundElements = false;
-	private JRPrintPage printPage = null;
-	private boolean ignorePagination = false;
+	private boolean usingVirtualizer;
+	private boolean perPageBoundElements;
+	private JRPrintPage printPage;
+	private boolean ignorePagination;
 	private JRQueryExecuter queryExecuter;
 
 	private JRVirtualizationContext virtualizationContext;
