@@ -59,6 +59,9 @@ import net.sf.jasperreports.crosstabs.fill.calculation.HeaderCell;
 import net.sf.jasperreports.crosstabs.fill.calculation.MeasureDefinition;
 import net.sf.jasperreports.crosstabs.fill.calculation.BucketDefinition.Bucket;
 import net.sf.jasperreports.crosstabs.fill.calculation.MeasureDefinition.MeasureValue;
+import net.sf.jasperreports.crosstabs.type.CrosstabColumnPositionEnum;
+import net.sf.jasperreports.crosstabs.type.CrosstabPercentageEnum;
+import net.sf.jasperreports.crosstabs.type.CrosstabRowPositionEnum;
 import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
@@ -75,6 +78,8 @@ import net.sf.jasperreports.engine.JRVisitor;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperReport;
 import net.sf.jasperreports.engine.design.JRDesignRectangle;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.util.JRProperties;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
@@ -84,7 +89,7 @@ import org.jfree.data.general.Dataset;
  * Fill-time implementation of a {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab}.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillCrosstab.java 3203 2009-11-19 17:44:16Z lucianc $
+ * @version $Id: JRFillCrosstab.java 4017 2010-10-27 12:10:17Z teodord $
  */
 public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROriginProvider
 {
@@ -132,6 +137,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	private boolean percentage;
 
 	private CrosstabFiller crosstabFiller;
+	private int overflowStartPage;
 	
 	private List fillElements;
 	
@@ -179,9 +185,9 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	private void copyRowGroups(JRCrosstab crosstab, JRFillCrosstabObjectFactory factory)
@@ -192,10 +198,10 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		for (int i = 0; i < groups.length; ++i)
 		{
 			JRFillCrosstabRowGroup group = factory.getCrosstabRowGroup(groups[i]);
-			group.getFillHeader().setVerticalPositionType(groups[i].getPosition());
+			group.getFillHeader().setVerticalPositionType(groups[i].getPositionValue());
 
 			rowGroups[i] = group;
-			rowGroupsMap.put(group.getName(), new Integer(i));
+			rowGroupsMap.put(group.getName(), Integer.valueOf(i));
 		}
 	}
 
@@ -208,7 +214,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		{
 			JRFillCrosstabColumnGroup group = factory.getCrosstabColumnGroup(groups[i]);
 			columnGroups[i] = group;
-			columnGroupsMap.put(group.getName(), new Integer(i));
+			columnGroupsMap.put(group.getName(), Integer.valueOf(i));
 		}
 	}
 
@@ -346,7 +352,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		for (int i = 0; i < measures.length; ++i)
 		{
 			measureList.add(createServiceMeasure(measures[i]));
-			percentage |= measures[i].getPercentageOfType() == JRCrosstabMeasure.PERCENTAGE_TYPE_GRAND_TOTAL;
+			percentage |= measures[i].getPercentageType() == CrosstabPercentageEnum.GRAND_TOTAL;
 		}
 
 		// if a group has order by expression, compute totals as they might be used
@@ -372,17 +378,16 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			comparator = (Comparator) evaluateExpression(comparatorExpression, evaluation);
 		}
 
-		byte totalPosition = group.getTotalPosition();
 		return new BucketDefinition(bucket.getExpression().getValueClass(),
-				bucket.getOrderByExpression(), comparator, bucket.getOrder(), 
-				totalPosition);
+				bucket.getOrderByExpression(), comparator, bucket.getOrderValue(), 
+				group.getTotalPositionValue());
 	}
 
 	private MeasureDefinition createServiceMeasure(JRFillCrosstabMeasure measure)
 	{
 		return new MeasureDefinition(
 				measure.getValueClass(), 
-				measure.getCalculation(), 
+				measure.getCalculationValue(), 
 				measure.getIncrementerFactory()); 
 	}
 
@@ -439,7 +444,9 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				}
 
 				crosstabFiller.initCrosstab();
-			}			
+			}
+			
+			overflowStartPage = 0;
 		}
 	}
 
@@ -480,7 +487,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		{
 			try
 			{
-				bucketingService = createService(JRExpression.EVALUATION_TIME_NOW);
+				bucketingService = createService(JRExpression.EVALUATION_DEFAULT);
 			}
 			catch (JRException e)
 			{
@@ -530,6 +537,26 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 
 		crosstabFiller.fill(availableHeight - getRelativeY());
+
+		if (crosstabFiller.hasFilledRows())
+		{
+			// crosstab content has been filled, rest overflowPage
+			overflowStartPage = 0;
+		}
+		else
+		{
+			int pageCount = filler.getCurrentPageCount();
+			if (overflowStartPage == 0)
+			{
+				// first empty page
+				overflowStartPage = pageCount;
+			}
+			else if (pageCount >= overflowStartPage + 2)
+			{
+				throw new JRRuntimeException("Crosstab has not printed anything on 3 consecutive pages, "
+						+ "likely infinite loop");
+			}
+		}
 		
 		boolean willOverflow = crosstabFiller.willOverflow();
 		setStretchHeight(willOverflow ? availableHeight - getRelativeY() : crosstabFiller.getUsedHeight());
@@ -557,7 +584,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			{
 				// increase the rectangle width
 				printRectangle.setWidth(xLimit);
-				if (getRunDirection() == RUN_DIRECTION_RTL)
+				if (getRunDirectionValue() == RunDirectionEnum.RTL)
 				{
 					// if RTL filling, move the rectangle to the left
 					printRectangle.setX(getX() + getWidth() - xLimit);
@@ -565,7 +592,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 		}
 		
-		if (getRunDirection() == RUN_DIRECTION_RTL)
+		if (getRunDirectionValue() == RunDirectionEnum.RTL)
 		{
 			mirrorPrintElements(fillElements);
 		}
@@ -597,9 +624,9 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		JRDesignRectangle rectangle = new JRDesignRectangle();
 
 		rectangle.setKey(getKey());
-		rectangle.setPositionType(getPositionType());
+		rectangle.setPositionType(getPositionTypeValue());
 		// rectangle.setPrintRepeatedValues(isPrintRepeatedValues());
-		rectangle.setMode(getMode());
+		rectangle.setMode(getModeValue());
 		rectangle.setX(getX());
 		rectangle.setY(getY());
 		rectangle.setWidth(getWidth());
@@ -619,6 +646,8 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 	protected void rewind()
 	{
 		crosstabFiller.initCrosstab();
+		
+		overflowStartPage = 0;
 	}
 
 	protected List getPrintElements()
@@ -925,6 +954,11 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			fillVerticalCrosstab(availableHeight);
 		}
 		
+		protected boolean hasFilledRows()
+		{
+			return !printRows.isEmpty();
+		}
+		
 		protected boolean willOverflow()
 		{
 			return willOverflow;
@@ -1165,7 +1199,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			JRFillCellContents[][] columnHeaderRows = new JRFillCellContents[columnGroups.length][lastColumnIndex - startColumnIndex + 1];
 			
 			rowYs.clear();
-			rowYs.add(new Integer(0));
+			rowYs.add(Integer.valueOf(0));
 			
 			if (printRowHeaders && headerCell != null)
 			{
@@ -1200,7 +1234,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				}
 
 				int rowStretchHeight = stretchColumnHeadersRow(columnHeaderRows[rowIdx]);
-				rowYs.add(new Integer(((Integer) rowYs.get(rowIdx)).intValue() + rowStretchHeight));
+				rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + rowStretchHeight));
 			}
 			
 			List headerRows;
@@ -1229,7 +1263,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			else
 			{
-				rowCountVar.setValue(new Integer(rowCount[rowIdx]));
+				rowCountVar.setValue(Integer.valueOf(rowCount[rowIdx]));
 			}
 			
 			if (colIdx == -1)
@@ -1238,7 +1272,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			else
 			{
-				colCountVar.setValue(new Integer(columnCount[colIdx]));
+				colCountVar.setValue(Integer.valueOf(columnCount[colIdx]));
 			}
 		}
 		
@@ -1284,11 +1318,11 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				setCountVars(-1, columnIdx);
 				setGroupVariables(columnGroups, cell.getBucketValues());
 				
-				contents = contents.getTransformedContents(width, height, group.getPosition(), JRCellContents.POSITION_Y_TOP);
+				contents = contents.getTransformedContents(width, height, group.getPositionValue(), CrosstabRowPositionEnum.TOP);
 				boolean firstOnRow = columnIdx == startColumnIndex && (!printRowHeaders || headerCell == null);
 				contents = contents.getBoxContents(
-						firstOnRow && getRunDirection() == RUN_DIRECTION_LTR,
-						firstOnRow && getRunDirection() == RUN_DIRECTION_RTL,
+						firstOnRow && getRunDirectionValue() == RunDirectionEnum.LTR,
+						firstOnRow && getRunDirectionValue() == RunDirectionEnum.RTL,
 						false);
 				contents = contents.getWorkingClone();
 
@@ -1408,7 +1442,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		protected int fillRows(int xOffset, int availableHeight) throws JRException
 		{
 			rowYs.clear();			
-			rowYs.add(new Integer(0));
+			rowYs.add(Integer.valueOf(0));
 
 			for (rowIdx = 0; rowIdx < cellData.length - startRowIndex; ++rowIdx)
 			{
@@ -1423,7 +1457,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				
 				fillRow();
 				
-				rowYs.add(new Integer(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
+				rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
 			}
 			
 			if (rowIdx < cellData.length - startRowIndex)//overflow
@@ -1518,11 +1552,19 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				for (int j = 0; j < rowGroups.length; j++)
 				{
 					HeaderCell cell = rowHeadersData[j][rowIdx + startRowIndex];
-					
-					boolean overflow = false;
+					int vSpan = 0;
 					if (cell == null)
 					{
-						overflow = prepareClosingRowHeader(j, availableHeight);
+						// if we have a span header
+						if (toCloseRowHeader(j))
+						{
+							cell = spanHeaders[j];
+							vSpan = cell.getLevelSpan();
+							if (spanHeadersStart[j] < startRowIndex)//continuing from the prev page
+							{
+								vSpan += spanHeadersStart[j] - startRowIndex;
+							}
+						}
 					}
 					else
 					{
@@ -1532,14 +1574,30 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 							spanHeadersStart[j] = rowIdx + startRowIndex;
 							continue;
 						}
-
-						overflow = prepareRowHeader(j, cell, 1, availableHeight);
+						
+						vSpan = 1;
 					}
 					
-					if (overflow)
+					if (cell != null)
 					{
-						willOverflow = true;
-						return;
+						boolean overflow = prepareRowHeader(j, cell, vSpan, availableHeight);						
+						if (overflow)
+						{
+							willOverflow = true;
+							return;
+						}
+					}
+				}
+				
+				// successfully prepared a row, reset the span headers
+				for (int j = 0; j < rowGroups.length; j++)
+				{
+					// if we have a span header
+					if (rowHeadersData[j][rowIdx + startRowIndex] == null 
+							&& toCloseRowHeader(j))
+					{
+						// reset it
+						spanHeaders[j] = null;
 					}
 				}
 				
@@ -1571,8 +1629,8 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				
 				boolean firstOnRow = leftEmpty && column == startColumnIndex;
 				contents = contents.getBoxContents(
-						firstOnRow && getRunDirection() == RUN_DIRECTION_LTR,
-						firstOnRow && getRunDirection() == RUN_DIRECTION_RTL,
+						firstOnRow && getRunDirectionValue() == RunDirectionEnum.LTR,
+						firstOnRow && getRunDirectionValue() == RunDirectionEnum.RTL,
 						topEmpty && rowIdx == 0);
 				contents = contents.getWorkingClone();
 				
@@ -1617,7 +1675,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			int rowHeight = spanHeight + preparedRowHeight;
 			
-			boolean stretchContents = group.getPosition() == JRCellContents.POSITION_Y_STRETCH;
+			boolean stretchContents = group.getPositionValue() == CrosstabRowPositionEnum.STRETCH;
 			int contentsHeight = stretchContents ? rowHeight : contents.getHeight();
 			
 			boolean headerOverflow = availableHeight <  headerY + contentsHeight || rowHeight < contents.getHeight();
@@ -1629,7 +1687,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 				if (stretchContents)
 				{
-					contents = contents.getTransformedContents(contents.getWidth(), rowHeight, JRCellContents.POSITION_X_LEFT, JRCellContents.POSITION_Y_STRETCH);
+					contents = contents.getTransformedContents(contents.getWidth(), rowHeight, CrosstabColumnPositionEnum.LEFT, CrosstabRowPositionEnum.STRETCH);
 				}
 				contents = contents.getBoxContents(false, false, rowIdx + 1 == vSpan && (!printColumnHeaders || headerCell == null));
 				contents.getWorkingClone();
@@ -1664,24 +1722,12 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			return headerOverflow;
 		}
 
-		private boolean prepareClosingRowHeader(int rowGroup, int availableHeight) throws JRException
+		protected boolean toCloseRowHeader(int rowGroup)
 		{
-			if (rowGroup < rowGroups.length - 1 && 
+			return rowGroup < rowGroups.length - 1 && 
 					spanHeaders[rowGroup] != null && 
-					spanHeaders[rowGroup].getLevelSpan() + spanHeadersStart[rowGroup] == rowIdx + startRowIndex + 1)
-			{
-				HeaderCell cell = spanHeaders[rowGroup];
-				int vSpan = cell.getLevelSpan();
-				if (spanHeadersStart[rowGroup] < startRowIndex)//continuing from the prev page
-				{
-					vSpan += spanHeadersStart[rowGroup] - startRowIndex;
-				}
-				spanHeaders[rowGroup] = null;
-				
-				return prepareRowHeader(rowGroup, cell, vSpan, availableHeight);
-			}
-			
-			return false;
+					spanHeaders[rowGroup].getLevelSpan() + spanHeadersStart[rowGroup] == 
+						rowIdx + startRowIndex + 1;
 		}
 
 		private void removeExceedingSpanHeaders()
@@ -1785,7 +1831,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			prepareRow(xOffset, availableHeight);
 			fillRow();
 			
-			rowYs.add(new Integer(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
+			rowYs.add(Integer.valueOf(((Integer) rowYs.get(rowIdx)).intValue() + preparedRowHeight));
 			++rowIdx;
 		}
 
@@ -1808,7 +1854,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			JRFillCrosstabRowGroup group = rowGroups[rowGroup];
 			JRFillCellContents contents = cell.isTotal() ? group.getFillTotalHeader() : group.getFillHeader();
 			
-			boolean stretchContents = group.getPosition() == JRCellContents.POSITION_Y_STRETCH;
+			boolean stretchContents = group.getPositionValue() == CrosstabRowPositionEnum.STRETCH;
 			int contentsHeight = stretchContents ? headerHeight : contents.getHeight();
 			
 			boolean headerOverflow = availableHeight < headerY + contentsHeight || headerHeight < contents.getHeight();
@@ -1819,7 +1865,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 
 				if (stretchContents)
 				{
-					contents = contents.getTransformedContents(contents.getWidth(), headerHeight, JRCellContents.POSITION_X_LEFT, JRCellContents.POSITION_Y_STRETCH);
+					contents = contents.getTransformedContents(contents.getWidth(), headerHeight, CrosstabColumnPositionEnum.LEFT, CrosstabRowPositionEnum.STRETCH);
 				}
 				
 				contents = contents.getBoxContents(false, false, rowIdx == vSpan && (!printColumnHeaders || headerCell == null));
@@ -1925,7 +1971,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		protected Object measureValue(MeasureValue[] values, int measureIdx)
 		{
 			Object value;
-			if (measures[measureIdx].getPercentageOfType() == JRCrosstabMeasure.PERCENTAGE_TYPE_GRAND_TOTAL)
+			if (measures[measureIdx].getPercentageType() == CrosstabPercentageEnum.GRAND_TOTAL)
 			{
 				if (values[measureIdx].isInitialized())
 				{
@@ -2034,14 +2080,36 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return variables;
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
+	 */
 	public byte getRunDirection()
 	{
-		return parentCrosstab.getRunDirection();
+		return getRunDirectionValue() == null ? null : getRunDirectionValue().getValue();
 	}
 
+	/**
+	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
+	 */
 	public void setRunDirection(byte direction)
 	{
-		// nothing
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 *
+	 */
+	public RunDirectionEnum getRunDirectionValue()
+	{
+		return parentCrosstab.getRunDirectionValue();
+	}
+
+	/**
+	 *
+	 */
+	public void setRunDirection(RunDirectionEnum runDirection)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	public JROrigin getOrigin()
