@@ -53,7 +53,6 @@ import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperCompileManager;
 import net.sf.jasperreports.engine.JasperReport;
-import net.sf.jasperreports.engine.data.JRSortableDataSource;
 import net.sf.jasperreports.engine.design.JRDesignVariable;
 import net.sf.jasperreports.engine.query.JRQueryExecuter;
 import net.sf.jasperreports.engine.query.JRQueryExecuterFactory;
@@ -72,7 +71,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillDataset.java 3675 2010-04-02 08:58:23Z shertage $
+ * @version $Id: JRFillDataset.java 3960 2010-09-22 11:27:59Z teodord $
  */
 public class JRFillDataset implements JRDataset
 {
@@ -97,40 +96,40 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The dataset query.
 	 */
-	protected JRQuery query = null;
+	protected JRQuery query;
 	
-	private boolean useDatasourceParamValue = false;
-	private boolean useConnectionParamValue = false;
+	private boolean useDatasourceParamValue;
+	private boolean useConnectionParamValue;
 	
 	/**
 	 * The dataset parameters.
 	 */
-	protected JRFillParameter[] parameters = null;
+	protected JRFillParameter[] parameters;
 
 	/**
 	 * The dataset parameters indexed by name.
 	 */
-	protected Map parametersMap = null;
+	protected Map parametersMap;
 
 	/**
 	 * The dataset fields.
 	 */
-	protected JRFillField[] fields = null;
+	protected JRFillField[] fields;
 	
 	/**
 	 * The dataset fields indexed by name.
 	 */
-	protected Map fieldsMap = null;
+	protected Map fieldsMap;
 	
 	/**
 	 * The dataset variables.
 	 */
-	protected JRFillVariable[] variables = null;
+	protected JRFillVariable[] variables;
 	
 	/**
 	 * The dataset variables indexed by name.
 	 */
-	protected Map variablesMap = null;
+	protected Map variablesMap;
 	
 	/**
 	 * Set of {@link VariableCalculationReq VariableCalculationReq} objects.
@@ -151,12 +150,12 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The dataset groups.
 	 */
-	protected JRFillGroup[] groups = null;
+	protected JRFillGroup[] groups;
 
 	/**
 	 * The resource bundle base name.
 	 */
-	protected String resourceBundleBaseName = null;
+	protected String resourceBundleBaseName;
 	
 	/**
 	 * The resource missing handle type.
@@ -166,42 +165,42 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The scriptlet class name.
 	 */
-	protected String scriptletClassName = null;
+	protected String scriptletClassName;
 
 	/**
 	 * The data source. 
 	 */
-	protected JRDataSource dataSource = null;
+	protected JRDataSource dataSource;
 	
 	/**
 	 * The {@link Locale Locale} to be used by the dataset.
 	 */
-	protected Locale locale = null;
+	protected Locale locale;
 	
 	/**
 	 * The loaded resource bundle.
 	 */
-	protected ResourceBundle resourceBundle = null;
+	protected ResourceBundle resourceBundle;
 
 	/**
 	 * The {@link TimeZone TimeZone} to be used by the dataset.
 	 */
-	protected TimeZone timeZone = null;
+	protected TimeZone timeZone;
 	
 	/**
 	 * The cursor used when iterating the data source.
 	 */
-	protected int reportCount = 0;
+	protected int reportCount;
 
 	/**
 	 * The calculator used by the dataset.
 	 */
-	protected JRCalculator calculator = null;
+	protected JRCalculator calculator;
 
 	/**
 	 * The scriptlets used by the dataset.
 	 */
-	protected List scriptlets = null;
+	protected List scriptlets;
 
 	/**
 	 *
@@ -211,7 +210,7 @@ public class JRFillDataset implements JRDataset
 	/**
 	 * The value of the {@link JRParameter#REPORT_MAX_COUNT max count} parameter.
 	 */
-	protected Integer reportMaxCount = null;
+	protected Integer reportMaxCount;
 
 	private JRQueryExecuter queryExecuter;
 
@@ -606,11 +605,10 @@ public class JRFillDataset implements JRDataset
 			dataSource = createQueryDatasource();
 			setParameter(JRParameter.REPORT_DATA_SOURCE, dataSource);
 		}
-		
-		JRSortField[] sortFields = getSortFields();
-		if (sortFields != null && sortFields.length > 0)
+
+		if (DatasetSortUtil.needSorting(this))
 		{
-			dataSource = new JRSortableDataSource(dataSource, fields, sortFields, locale);
+			dataSource = DatasetSortUtil.getSortedDataSource(filler, this, locale);
 			setParameter(JRParameter.REPORT_DATA_SOURCE, dataSource);
 		}
 	}
