@@ -61,7 +61,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillElement.java 3673 2010-04-01 13:14:19Z shertage $
+ * @version $Id: JRFillElement.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public abstract class JRFillElement implements JRElement, JRFillCloneable, JRStyleSetter
 {
@@ -70,27 +70,27 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	/**
 	 *
 	 */
-	protected JRElement parent = null;
+	protected JRElement parent;
 	protected Map templates = new HashMap();
 
 	/**
 	 *
 	 */
-	protected JRBaseFiller filler = null;
-	protected JRFillExpressionEvaluator expressionEvaluator = null;
+	protected JRBaseFiller filler;
+	protected JRFillExpressionEvaluator expressionEvaluator;
 
 	protected JRDefaultStyleProvider defaultStyleProvider;
 	
 	/**
 	 *
 	 */
-	protected JRGroup printWhenGroupChanges = null;
-	protected JRFillElementGroup elementGroup = null;
+	protected JRGroup printWhenGroupChanges;
+	protected JRFillElementGroup elementGroup;
 
 	/**
 	 *
 	 */
-	protected JRFillBand band = null;
+	protected JRFillBand band;
 	
 	protected JROriginProvider originProvider;
 
@@ -100,18 +100,18 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	private boolean isPrintWhenExpressionNull = true;
 	private boolean isPrintWhenTrue = true;
 	private boolean isToPrint = true;
-	private boolean isReprinted = false;
-	private boolean isAlreadyPrinted = false;
+	private boolean isReprinted;
+	private boolean isAlreadyPrinted;
 	private Collection dependantElements = new ArrayList();
-	private int relativeY = 0;
-	private int stretchHeight = 0;
+	private int relativeY;
+	private int stretchHeight;
 
 	private int x;
 	private int y;
 	private int width;
 	private int height;
 	
-	private boolean isValueRepeating = false;
+	private boolean isValueRepeating;
 	
 	protected byte currentEvaluation;
 	
@@ -137,8 +137,8 @@ public abstract class JRFillElement implements JRElement, JRFillCloneable, JRSty
 	/**
 	 *
 	 *
-	private JRElement topElementInGroup = null;
-	private JRElement bottomElementInGroup = null;
+	private JRElement topElementInGroup;
+	private JRElement bottomElementInGroup;
 
 
 	/**
