@@ -44,6 +44,8 @@ import net.sf.jasperreports.engine.JRPrintElementContainer;
 import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.base.JRBaseStyle;
+import net.sf.jasperreports.engine.type.PositionTypeEnum;
+import net.sf.jasperreports.engine.type.StretchTypeEnum;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
 
 /**
@@ -52,23 +54,23 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * This is the base for band, frame and crosstab cell fillers.
  * 
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
- * @version $Id: JRFillElementContainer.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRFillElementContainer.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public abstract class JRFillElementContainer extends JRFillElementGroup
 {
 	protected JRBaseFiller filler;
 	
-	private JRFillElement[] ySortedElements = null;
-	private JRFillElement[] stretchElements = null;
-	private JRFillElement[] bandBottomElements = null;
-	private JRFillElement[] removableElements = null;
+	private JRFillElement[] ySortedElements;
+	private JRFillElement[] stretchElements;
+	private JRFillElement[] bandBottomElements;
+	private JRFillElement[] removableElements;
 	
-	private boolean willOverflow = false;
-	protected boolean isOverflow = false;
+	private boolean willOverflow;
+	protected boolean isOverflow;
 	
-	private int stretchHeight = 0;
-	private int firstY = 0;
-	protected JRFillElement firstYElement = null;
+	private int stretchHeight;
+	private int firstY;
+	protected JRFillElement firstYElement;
 	
 	protected final JRFillExpressionEvaluator expressionEvaluator;
 	
@@ -148,12 +150,12 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 				JRFillElement element = elements[i];
 				sortedElemsList.add(element);
 				
-				if (element.getPositionType() == JRElement.POSITION_TYPE_FIX_RELATIVE_TO_BOTTOM)
+				if (element.getPositionTypeValue() == PositionTypeEnum.FIX_RELATIVE_TO_BOTTOM)
 				{
 					bandBottomElemsList.add(element);
 				}
 
-				if (element.getStretchType() != JRElement.STRETCH_TYPE_NO_STRETCH)
+				if (element.getStretchTypeValue() != StretchTypeEnum.NO_STRETCH)
 				{
 					stretchElemsList.add(element);
 				}
@@ -211,7 +213,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 					int right = Math.max(iElem.getX() + iElem.getWidth(), jElem.getX() + jElem.getWidth());
 					
 					if (
-						((isBreakElem && jElem.getPositionType() == JRElement.POSITION_TYPE_FIX_RELATIVE_TO_TOP) || jElem.getPositionType() == JRElement.POSITION_TYPE_FLOAT) &&
+						((isBreakElem && jElem.getPositionTypeValue() == PositionTypeEnum.FIX_RELATIVE_TO_TOP) || jElem.getPositionTypeValue() == PositionTypeEnum.FLOAT) &&
 						iElem.getY() + iElem.getHeight() <= jElem.getY() &&
 						iElem.getWidth() + jElem.getWidth() > right - left // FIXME band bottom elements should not have dependent elements
 						)
@@ -364,9 +366,10 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 			tmpWillOverflow = true;
 		}
 		
+		// stretchHeight includes firstY, which is subtracted in fillElements
 		if (tmpWillOverflow)
 		{
-			stretchHeight = availableHeight;
+			stretchHeight = availableHeight + firstY;
 		}
 		else
 		{
@@ -413,7 +416,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 			{
 				JRFillElement element = stretchElements[i];
 				
-				element.stretchElement(stretchHeight - getContainerHeight());
+				element.stretchElement(stretchHeight - getContainerHeight());//TODO subtract firstY?
 				
 				element.moveDependantElements();
 			}
@@ -556,7 +559,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 				
 				element.setRelativeY(element.getRelativeY() - firstY);
 
-				if (element.getRelativeY() + element.getStretchHeight() > stretchHeight)
+				if (element.getRelativeY() + element.getStretchHeight() > stretchHeight - firstY)
 				{
 					element.setToPrint(false);
 				}
@@ -724,7 +727,7 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 		
 		if (anyTrue)
 		{
-			String consolidatedStyleName = initialStyle.getName() + code.toString();
+			String consolidatedStyleName = initialStyle.getName() + "|" + code.toString();
 			consolidatedStyle = (JRStyle)filler.getJasperPrint().getStylesMap().get(consolidatedStyleName);
 			if (consolidatedStyle == null)
 			{
@@ -774,15 +777,18 @@ public abstract class JRFillElementContainer extends JRFillElementGroup
 				anyTrue = anyTrue | condition;
 
 				if (condition)
+				{
 					condStylesToApply.add(conditionalStyle);
+				}
 			}
 		}
 
 		condStylesToApply.add(style);
 		
 		if (style.getStyle() != null)
+		{
 			anyTrue = anyTrue | buildConsolidatedStyle(style.getStyle(), evaluation, code, condStylesToApply);
-		
+		}
 		return anyTrue;
 	}
 
