@@ -30,7 +30,6 @@ import java.util.Map;
 
 import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRCommonText;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRFont;
 import net.sf.jasperreports.engine.JRLineBox;
@@ -39,6 +38,12 @@ import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRTextElement;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRFontUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRProperties;
@@ -54,7 +59,7 @@ import net.sf.jasperreports.engine.util.MarkupProcessorFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRFillTextElement.java 3194 2009-11-11 11:11:28Z lucianc $
+ * @version $Id: JRFillTextElement.java 3940 2010-08-20 10:35:15Z teodord $
  */
 public abstract class JRFillTextElement extends JRFillElement implements JRTextElement
 {
@@ -69,16 +74,16 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 *
 	 */
 	private boolean isLeftToRight = true;
-	private JRTextMeasurer textMeasurer = null;
-	private float lineSpacingFactor = 0;
-	private float leadingOffset = 0;
-	private float textHeight = 0;
-	private int textStart = 0;
-	private int textEnd = 0;
+	private JRTextMeasurer textMeasurer;
+	private float lineSpacingFactor;
+	private float leadingOffset;
+	private float textHeight;
+	private int textStart;
+	private int textEnd;
 	private short[] lineBreakOffsets;
 	private String textTruncateSuffix;
-	private String rawText = null;
-	private JRStyledText styledText = null;
+	private String rawText;
+	private JRStyledText styledText;
 	private Map styledTextAttributesMap = new HashMap();
 	
 	protected final JRReportFont reportFont;
@@ -128,9 +133,9 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 *
 	 */
-	public byte getMode()
+	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, JRElement.MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
@@ -138,7 +143,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 */
 	public byte getTextAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignment();
 	}
 
 	/**
@@ -146,114 +151,222 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 */
 	public void setTextAlignment(byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return ((JRTextElement)parent).getOwnHorizontalAlignment();
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+		
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return ((JRTextElement)this.parent).getOwnHorizontalAlignmentValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignment)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue().getValue();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
+	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return ((JRTextElement)parent).getOwnVerticalAlignment();
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+		
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return ((JRTextElement)this.parent).getOwnVerticalAlignmentValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
 	 */
 	public void setVerticalAlignment(Byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
-	public byte getRotation()
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignment)
 	{
-		return JRStyleResolver.getRotation(this);
+		throw new UnsupportedOperationException();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
+	public byte getRotation()
+	{
+		return getRotationValue().getValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
 	public Byte getOwnRotation()
 	{
-		return ((JRTextElement)parent).getOwnRotation();
+		return getOwnRotationValue() == null ? null : getOwnRotationValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(byte rotation)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(Byte rotation)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 *
+	 */
+	public RotationEnum getRotationValue()
+	{
+		return JRStyleResolver.getRotationValue(this);
+	}
+		
+	public RotationEnum getOwnRotationValue()
+	{
+		return ((JRTextElement)this.parent).getOwnRotationValue();
 	}
 
 	/**
 	 *
 	 */
-	public void setRotation(byte rotation)
+	public void setRotation(RotationEnum rotation)
 	{
+		throw new UnsupportedOperationException();
 	}
-		
+
 	/**
-	 *
-	 */
-	public void setRotation(Byte rotation)
-	{
-	}
-		
-	/**
-	 *
+	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
 	 */
 	public byte getLineSpacing()
 	{
 		return JRStyleResolver.getLineSpacing(this);
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
+	 */
 	public Byte getOwnLineSpacing()
 	{
 		return ((JRTextElement)parent).getOwnLineSpacing();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(byte lineSpacing)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(Byte lineSpacing)
 	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * 
+	 */
+	public LineSpacingEnum getLineSpacingValue()
+	{
+		return JRStyleResolver.getLineSpacingValue(this);
+	}
+		
+	/**
+	 * 
+	 */
+	public LineSpacingEnum getOwnLineSpacingValue()
+	{
+		return ((JRTextElement)parent).getOwnLineSpacingValue();
+	}
+
+	/**
+	 * 
+	 */
+	public void setLineSpacing(LineSpacingEnum lineSpacing)
+	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -788,7 +901,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 			//JRFontUtil.getAttributes(styledTextAttributes, this, filler.getLocale());
 			JRFontUtil.getAttributesWithoutAwtFont(styledTextAttributes, this);
 			styledTextAttributes.put(TextAttribute.FOREGROUND, getForecolor());
-			if (getMode() == JRElement.MODE_OPAQUE)
+			if (getModeValue() == ModeEnum.OPAQUE)
 			{
 				styledTextAttributes.put(TextAttribute.BACKGROUND, getBackcolor());
 			}
@@ -831,11 +944,19 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
 	 */
 	protected byte getRunDirection()
 	{
-		return isLeftToRight ? JRPrintText.RUN_DIRECTION_LTR : JRPrintText.RUN_DIRECTION_RTL;
+		return getRunDirectionValue().getValue();
+	}
+		
+	/**
+	 *
+	 */
+	public RunDirectionEnum getRunDirectionValue()
+	{
+		return isLeftToRight ? RunDirectionEnum.LTR : RunDirectionEnum.RTL;
 	}
 		
 	/**
@@ -1014,7 +1135,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		
 		isLeftToRight = measuredText.isLeftToRight();
 		setTextHeight(measuredText.getTextHeight());
-		if (getRotation() == ROTATION_NONE)
+		if (getRotationValue().equals(RotationEnum.NONE))
 		{
 			setStretchHeight((int)getTextHeight() + getLineBox().getTopPadding().intValue() + getLineBox().getBottomPadding().intValue());
 		}
@@ -1442,7 +1563,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 			
 			if (endIndex < fullText.length())
 			{
-				printText.setTextTruncateIndex(new Integer(endIndex));
+				printText.setTextTruncateIndex(Integer.valueOf(endIndex));
 			}
 		}
 		else
