@@ -25,15 +25,16 @@ package net.sf.jasperreports.engine.fill;
 
 import java.util.Iterator;
 
-import net.sf.jasperreports.engine.JRBand;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JRPrintElement;
-import net.sf.jasperreports.engine.JRReport;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperReport;
+import net.sf.jasperreports.engine.type.FooterPositionEnum;
+import net.sf.jasperreports.engine.type.IncrementTypeEnum;
+import net.sf.jasperreports.engine.type.ResetTypeEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
@@ -41,7 +42,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRHorizontalFiller.java 3210 2009-11-23 16:11:16Z teodord $
+ * @version $Id: JRHorizontalFiller.java 3953 2010-09-20 13:54:34Z teodord $
  */
 public class JRHorizontalFiller extends JRBaseFiller
 {
@@ -50,8 +51,8 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 	private int lastDetailOffsetX = -1;
 	private int lastDetailOffsetY = -1;
-	private int currentDetailOffsetY = 0;
-	private int maxDetailOffsetY = 0;
+	private int currentDetailOffsetY;
+	private int maxDetailOffsetY;
 	
 
 	/**
@@ -75,13 +76,25 @@ public class JRHorizontalFiller extends JRBaseFiller
 	/**
 	 *
 	 */
-	protected JRHorizontalFiller(JasperReport jasperReport, JREvaluator evaluator, JRFillSubreport parentElement) throws JRException
+	protected JRHorizontalFiller(JasperReport jasperReport, 
+			DatasetExpressionEvaluator evaluator, 
+			JRFillSubreport parentElement) throws JRException
 	{
 		super(jasperReport, evaluator, parentElement);
 
 		setPageHeight(pageHeight);
 	}
 
+	/**
+	 *
+	 */
+	protected JRHorizontalFiller(JasperReport jasperReport, 
+			JREvaluator evaluator, 
+			JRFillSubreport parentElement) throws JRException
+	{
+		this(jasperReport, (DatasetExpressionEvaluator) evaluator, parentElement);
+	}
+
 
 	/**
 	 *
@@ -92,15 +105,22 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 		columnFooterOffsetY = pageHeight - bottomMargin;
 		if (pageFooter != null)
+		{
 			columnFooterOffsetY -= pageFooter.getHeight();
+		}
 		if (columnFooter != null)
+		{
 			columnFooterOffsetY -= columnFooter.getHeight();
-
+		}
 		lastPageColumnFooterOffsetY = pageHeight - bottomMargin;
 		if (lastPageFooter != null)//FIXMENOW testing with null is awkward since bands can never be null, but rather equal to missingFillBand
+		{
 			lastPageColumnFooterOffsetY -= lastPageFooter.getHeight();
+		}
 		if (columnFooter != null)
+		{
 			lastPageColumnFooterOffsetY -= columnFooter.getHeight();
+		}
 	}
 
 
@@ -131,7 +151,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 			switch (whenNoDataType)
 			{
-				case JRReport.WHEN_NO_DATA_TYPE_ALL_SECTIONS_NO_DETAIL :
+				case ALL_SECTIONS_NO_DETAIL :
 				{
 					if (log.isDebugEnabled())
 					{
@@ -139,7 +159,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					}
 
 					scriptlet.callBeforeReportInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+					calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 					scriptlet.callAfterReportInit();
 
 					printPage = newPage();
@@ -163,7 +183,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 					break;
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_BLANK_PAGE :
+				case BLANK_PAGE :
 				{
 					if (log.isDebugEnabled())
 					{
@@ -174,7 +194,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					addPage(printPage);
 					break;
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_NO_DATA_SECTION:
+				case NO_DATA_SECTION:
 				{
 					if (log.isDebugEnabled())
 					{
@@ -182,7 +202,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					}
 
 					scriptlet.callBeforeReportInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+					calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 					scriptlet.callAfterReportInit();
 
 					printPage = newPage();
@@ -197,7 +217,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					break;
 
 				}
-				case JRReport.WHEN_NO_DATA_TYPE_NO_PAGES :
+				case NO_PAGES :
 				default :
 				{
 					if (log.isDebugEnabled())
@@ -237,7 +257,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 	private void fillReportStart() throws JRException
 	{
 		scriptlet.callBeforeReportInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_REPORT);
+		calculator.initializeVariables(ResetTypeEnum.REPORT, IncrementTypeEnum.REPORT);
 		scriptlet.callAfterReportInit();
 
 		printPage = newPage();
@@ -277,7 +297,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 		resolveGroupBoundElements(JRExpression.EVALUATION_OLD, false);
 		scriptlet.callBeforeGroupInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_GROUP);
+		calculator.initializeVariables(ResetTypeEnum.GROUP, IncrementTypeEnum.GROUP);
 		scriptlet.callAfterGroupInit();
 
 		fillGroupHeaders(false);
@@ -328,7 +348,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -345,7 +365,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -364,7 +384,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -403,7 +423,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(evaluation);
 				resolvePageBoundElements(evaluation);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -487,7 +507,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(evaluation);
 					resolvePageBoundElements(evaluation);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -502,7 +522,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					throw new JRRuntimeException("Infinite loop creating new page due to column header size.");
 				}
 
-				offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+				setOffsetX();
 				offsetY = columnHeaderOffsetY;
 
 				fillFixedBand(columnHeader, evaluation, false);
@@ -573,49 +593,46 @@ public class JRHorizontalFiller extends JRBaseFiller
 				);
 		}
 
-		JRBand[] groupHeaderBands = groupHeaderSection.getBands();
-		if (groupHeaderBands != null)
+		JRFillBand[] groupHeaderBands = groupHeaderSection.getFillBands();
+		for(int i = 0; i < groupHeaderBands.length; i++)
 		{
-			for(int i = 0; i < groupHeaderBands.length; i++)
+			JRFillBand groupHeaderBand = groupHeaderBands[i];
+
+			groupHeaderBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
+
+			if (groupHeaderBand.isToPrint())
 			{
-				JRFillBand groupHeaderBand = (JRFillBand)groupHeaderBands[i];
-
-				groupHeaderBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_DEFAULT);
-
-				if (groupHeaderBand.isToPrint())
+				while (
+					groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
+					group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
+					)
 				{
-					while (
-						groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
-						group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
-						)
-					{
-						fillPageBreak(
-							false,
-							evalPrevPage,
-							JRExpression.EVALUATION_DEFAULT,
-							true
-							);
-					}
+					fillPageBreak(
+						false,
+						evalPrevPage,
+						JRExpression.EVALUATION_DEFAULT,
+						true
+						);
 				}
+			}
 
-				if (i == 0)
-				{
-					setNewGroupInBands(group);
+			if (i == 0)
+			{
+				setNewGroupInBands(group);
 
-					group.setFooterPrinted(false);
-				}
+				group.setFooterPrinted(false);
+			}
 
-				if (groupHeaderBand.isToPrint())
-				{
-					setFirstColumn();
+			if (groupHeaderBand.isToPrint())
+			{
+				setFirstColumn();
 
-					SavePoint newSavePoint = fillColumnBand(groupHeaderBand, JRExpression.EVALUATION_DEFAULT);
-					
-					savePoint = advanceSavePoint(savePoint, newSavePoint);
+				SavePoint newSavePoint = fillColumnBand(groupHeaderBand, JRExpression.EVALUATION_DEFAULT);
+				
+				savePoint = advanceSavePoint(savePoint, newSavePoint);
 
-					isFirstPageBand = false;
-					isFirstColumnBand = true;
-				}
+				isFirstPageBand = false;
+				isFirstColumnBand = true;
 			}
 		}
 
@@ -668,32 +685,29 @@ public class JRHorizontalFiller extends JRBaseFiller
 		{
 			JRFillSection groupHeaderSection = (JRFillSection)group.getGroupHeaderSection();
 
-			JRBand[] groupHeaderBands = groupHeaderSection.getBands();
-			if (groupHeaderBands != null)
+			JRFillBand[] groupHeaderBands = groupHeaderSection.getFillBands();
+			for(int i = 0; i < groupHeaderBands.length; i++)
 			{
-				for(int i = 0; i < groupHeaderBands.length; i++)
+				JRFillBand groupHeaderBand = groupHeaderBands[i];
+
+				groupHeaderBand.evaluatePrintWhenExpression(evaluation);
+
+				if (groupHeaderBand.isToPrint())
 				{
-					JRFillBand groupHeaderBand = (JRFillBand)groupHeaderBands[i];
+					setFirstColumn();
 
-					groupHeaderBand.evaluatePrintWhenExpression(evaluation);
-
-					if (groupHeaderBand.isToPrint())
+					while (
+						groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
+						group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
+						)
 					{
-						setFirstColumn();
-
-						while (
-							groupHeaderBand.getBreakHeight() > columnFooterOffsetY - offsetY ||
-							group.getMinHeightToStartNewPage() > columnFooterOffsetY - offsetY
-							)
-						{
-							fillPageBreak(false, evaluation, evaluation, true);
-						}
-
-						fillColumnBand(groupHeaderBand, evaluation);
-
-						isFirstPageBand = false;
-						isFirstColumnBand = true;
+						fillPageBreak(false, evaluation, evaluation, true);
 					}
+
+					fillColumnBand(groupHeaderBand, evaluation);
+
+					isFirstPageBand = false;
+					isFirstColumnBand = true;
 				}
 			}
 		}
@@ -715,34 +729,31 @@ public class JRHorizontalFiller extends JRBaseFiller
 			calculator.estimateVariables();
 		}
 
-		JRBand[] detailBands = detailSection.getBands();
-		if (detailBands != null)
+		JRFillBand[] detailBands = detailSection.getFillBands();
+		for(int i = 0; i < detailBands.length; i++)
 		{
-			for(int i = 0; i < detailBands.length; i++)
+			JRFillBand detailBand = detailBands[i];
+
+			detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_ESTIMATED);
+
+			if (detailBand.isToPrint())
 			{
-				JRFillBand detailBand = (JRFillBand)detailBands[i];
-
-				detailBand.evaluatePrintWhenExpression(JRExpression.EVALUATION_ESTIMATED);
-
-				if (detailBand.isToPrint())
+				while (
+					(columnIndex == columnCount - 1 || isNewGroup)
+					&& detailBand.getHeight() > columnFooterOffsetY - offsetY
+					)
 				{
-					while (
-						(columnIndex == columnCount - 1 || isNewGroup)
-						&& detailBand.getHeight() > columnFooterOffsetY - offsetY
-						)
-					{
-						byte evalPrevPage = (isNewGroup?JRExpression.EVALUATION_DEFAULT:JRExpression.EVALUATION_OLD);
+					byte evalPrevPage = (isNewGroup?JRExpression.EVALUATION_DEFAULT:JRExpression.EVALUATION_OLD);
 
-						fillPageBreak(
-							false,
-							evalPrevPage,
-							JRExpression.EVALUATION_DEFAULT,
-							true
-							);
-					}
-					
-					break;
+					fillPageBreak(
+						false,
+						evalPrevPage,
+						JRExpression.EVALUATION_DEFAULT,
+						true
+						);
 				}
+				
+				break;
 			}
 		}
 
@@ -759,7 +770,9 @@ public class JRHorizontalFiller extends JRBaseFiller
 			{
 				if (columnIndex == columnCount - 1)
 				{
-					setFirstColumn();
+					columnIndex = 0;
+					setOffsetX();
+					setColumnNumberVariable();
 
 					maxDetailOffsetY = 0;
 					currentDetailOffsetY = offsetY;
@@ -767,7 +780,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				else
 				{
 					columnIndex++;
-					offsetX += columnWidth + columnSpacing;
+					setOffsetX();
 					offsetY = currentDetailOffsetY;
 
 					setColumnNumberVariable();
@@ -775,6 +788,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			}
 			else
 			{
+				setOffsetX();
 				currentDetailOffsetY = offsetY;
 			}
 
@@ -845,26 +859,26 @@ public class JRHorizontalFiller extends JRBaseFiller
 					// its footer position is completely irrelevant
 					if (newSavePoint != null)
 					{
-						switch (group.getFooterPosition())
+						switch (group.getFooterPositionValue())
 						{
-							case JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM:
+							case STACK_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								if (savePoint != null)
 								{
-									savePoint.footerPosition = JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM;
+									savePoint.footerPosition = FooterPositionEnum.STACK_AT_BOTTOM;
 								}
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_FORCE_AT_BOTTOM:
+							case FORCE_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								if (savePoint != null)
 								{
-									moveSavePointContent(savePoint);
+									savePoint.moveSavePointContent();
 									offsetY = columnFooterOffsetY;
 								}
 
@@ -872,13 +886,13 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_COLLATE_AT_BOTTOM:
+							case COLLATE_AT_BOTTOM:
 							{
 								savePoint = advanceSavePoint(savePoint, newSavePoint);
 
 								break;
 							}
-							case JRGroup.FOOTER_POSITION_NORMAL:
+							case NORMAL:
 							default:
 							{
 								if (savePoint != null)
@@ -895,7 +909,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 										// we just move the marker on the existing save point,
 										// but only if was a "StackAtBottom" one
 										
-										if (savePoint.footerPosition == JRGroup.FOOTER_POSITION_STACK_AT_BOTTOM)
+										if (savePoint.footerPosition == FooterPositionEnum.STACK_AT_BOTTOM)
 										{
 											savePoint.saveHeightOffset(newSavePoint.heightOffset);
 										}
@@ -910,7 +924,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 										// page/column break occurred, so the move operation 
 										// must be performed on the previous save point, regardless 
 										// whether it was a "StackAtBottom" or a "CollateAtBottom"
-										moveSavePointContent(savePoint);
+										savePoint.moveSavePointContent();
 										savePoint = null;
 									}
 								}
@@ -937,7 +951,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			
 			if (savePoint != null)
 			{
-				moveSavePointContent(savePoint);
+				savePoint.moveSavePointContent();
 				offsetY = columnFooterOffsetY;
 			}
 		}
@@ -958,34 +972,31 @@ public class JRHorizontalFiller extends JRBaseFiller
 			log.debug("Fill " + fillerId + ": " + group.getName() + " footer");
 		}
 
-		JRBand[] groupFooterBands = groupFooterSection.getBands();
-		if (groupFooterBands != null)
+		JRFillBand[] groupFooterBands = groupFooterSection.getFillBands();
+		for(int i = 0; i < groupFooterBands.length; i++)
 		{
-			for(int i = 0; i < groupFooterBands.length; i++)
+			JRFillBand groupFooterBand = groupFooterBands[i];
+			
+			groupFooterBand.evaluatePrintWhenExpression(evaluation);
+
+			if (groupFooterBand.isToPrint())
 			{
-				JRFillBand groupFooterBand = (JRFillBand)groupFooterBands[i];
-				
-				groupFooterBand.evaluatePrintWhenExpression(evaluation);
+				setFirstColumn();
 
-				if (groupFooterBand.isToPrint())
+				if (
+					groupFooterBand.getBreakHeight() > columnFooterOffsetY - offsetY
+					)
 				{
-					setFirstColumn();
-
-					if (
-						groupFooterBand.getBreakHeight() > columnFooterOffsetY - offsetY
-						)
-					{
-						fillPageBreak(false, evaluation, evaluation, true);
-					}
-
-					SavePoint newSavePoint = fillColumnBand(groupFooterBand, evaluation);
-					newSavePoint.footerPosition = group.getFooterPosition();
-					
-					savePoint = advanceSavePoint(savePoint, newSavePoint);
-
-					isFirstPageBand = false;
-					isFirstColumnBand = true;
+					fillPageBreak(false, evaluation, evaluation, true);
 				}
+
+				SavePoint newSavePoint = fillColumnBand(groupFooterBand, evaluation);
+				newSavePoint.footerPosition = group.getFooterPositionValue();
+				
+				savePoint = advanceSavePoint(savePoint, newSavePoint);
+
+				isFirstPageBand = false;
+				isFirstColumnBand = true;
 			}
 		}
 
@@ -1032,7 +1043,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 		{
 			setColumnNumberVariable();
 
-			offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+			setOffsetX();
 			offsetY = tmpColumnFooterOffsetY;
 
 			columnFooter.evaluatePrintWhenExpression(evaluation);
@@ -1142,7 +1153,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1172,7 +1183,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1222,7 +1233,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1247,7 +1258,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1300,7 +1311,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1355,7 +1366,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1374,7 +1385,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1413,7 +1424,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1432,7 +1443,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1484,7 +1495,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1546,7 +1557,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1631,7 +1642,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1646,7 +1657,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1673,7 +1684,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1696,7 +1707,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 					resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 					resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 					scriptlet.callBeforePageInit();
-					calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+					calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 					scriptlet.callAfterPageInit();
 
 					addPage(false);
@@ -1711,7 +1722,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1746,7 +1757,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 						resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 						resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 						scriptlet.callBeforePageInit();
-						calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+						calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 						scriptlet.callAfterPageInit();
 
 						addPage(false);
@@ -1794,7 +1805,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 			resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 			scriptlet.callBeforePageInit();
-			calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+			calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 			scriptlet.callAfterPageInit();
 
 			addPage(false);
@@ -1822,7 +1833,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -1911,12 +1922,12 @@ public class JRHorizontalFiller extends JRBaseFiller
 
 		if (isResetPageNumber)
 		{
-			calculator.getPageNumber().setValue(new Integer(1));
+			calculator.getPageNumber().setValue(Integer.valueOf(1));
 		}
 		else
 		{
 			calculator.getPageNumber().setValue(
-				new Integer(((Number)calculator.getPageNumber().getValue()).intValue() + 1)
+				Integer.valueOf(((Number)calculator.getPageNumber().getValue()).intValue() + 1)
 				);
 		}
 
@@ -1941,7 +1952,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 	private void setColumnNumberVariable()
 	{
 		JRFillVariable columnNumberVar = calculator.getColumnNumber();
-		columnNumberVar.setValue(new Integer(columnIndex + 1));
+		columnNumberVar.setValue(Integer.valueOf(columnIndex + 1));
 		columnNumberVar.setOldValue(columnNumberVar.getValue());
 	}
 
@@ -1975,7 +1986,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 		resolveColumnBoundElements(evalPrevPage);
 		resolvePageBoundElements(evalPrevPage);
 		scriptlet.callBeforePageInit();
-		calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+		calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 		scriptlet.callAfterPageInit();
 
 		addPage(isResetPageNumber);
@@ -2031,7 +2042,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 			offsetY = columnHeaderOffsetY;
 
 			calculator.getColumnNumber().setValue(
-				new Integer(((Number)calculator.getColumnNumber().getValue()).intValue() + 1)
+				Integer.valueOf(((Number)calculator.getColumnNumber().getValue()).intValue() + 1)
 				);
 			calculator.getColumnNumber().setOldValue(
 				calculator.getColumnNumber().getValue()
@@ -2276,7 +2287,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -2293,7 +2304,7 @@ public class JRHorizontalFiller extends JRBaseFiller
 				resolveColumnBoundElements(JRExpression.EVALUATION_DEFAULT);
 				resolvePageBoundElements(JRExpression.EVALUATION_DEFAULT);
 				scriptlet.callBeforePageInit();
-				calculator.initializeVariables(JRVariable.RESET_TYPE_PAGE);
+				calculator.initializeVariables(ResetTypeEnum.PAGE, IncrementTypeEnum.PAGE);
 				scriptlet.callAfterPageInit();
 
 				addPage(false);
@@ -2307,4 +2318,21 @@ public class JRHorizontalFiller extends JRBaseFiller
 		}
 	}
 
+	
+	/**
+	 *
+	 */
+	private void setOffsetX()
+	{
+		if (columnDirection == RunDirectionEnum.RTL)
+		{
+			offsetX = pageWidth - rightMargin - columnWidth - columnIndex * (columnSpacing + columnWidth);
+		}
+		else
+		{
+			offsetX = leftMargin + columnIndex * (columnSpacing + columnWidth);
+		}
+	}
+
+	
 }
