@@ -44,7 +44,7 @@ import net.sf.jasperreports.engine.util.JRStyleResolver;
  * print element instances.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateGraphicElement.java 3833 2010-05-27 14:16:59Z teodord $
+ * @version $Id: JRTemplateGraphicElement.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public abstract class JRTemplateGraphicElement extends JRTemplateElement implements JRCommonGraphicElement
 {
@@ -58,8 +58,8 @@ public abstract class JRTemplateGraphicElement extends JRTemplateElement impleme
 	/**
 	 *
 	 */
-	protected JRPen linePen = null;
-	private FillEnum fillValue = null;
+	protected JRPen linePen;
+	private FillEnum fillValue;
 
 
 	/**
