@@ -32,6 +32,13 @@ import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRRenderable;
+import net.sf.jasperreports.engine.PrintElementVisitor;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.LineBoxWrapper;
 
@@ -42,7 +49,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintImage.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRTemplatePrintImage.java 3991 2010-10-12 20:10:55Z lucianc $
  */
 public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implements JRPrintImage
 {
@@ -56,11 +63,11 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	/**
 	 *
 	 */
-	private JRRenderable renderer = null;
-	private String anchorName = null;
-	private String hyperlinkReference = null;
-	private String hyperlinkAnchor = null;
-	private Integer hyperlinkPage = null;
+	private JRRenderable renderer;
+	private String anchorName;
+	private String hyperlinkReference;
+	private String hyperlinkAnchor;
+	private Integer hyperlinkPage;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -98,34 +105,59 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getScaleImageValue()}.
 	 */
 	public byte getScaleImage()
 	{
-		return ((JRTemplateImage)this.template).getScaleImage();
+		return getScaleImageValue().getValue();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnScaleImageValue()}.
 	 */
 	public Byte getOwnScaleImage()
 	{
-		return ((JRTemplateImage)this.template).getOwnScaleImage();
+		return getOwnScaleImageValue() == null ? null : getOwnScaleImageValue().getValueByte();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
 	 */
 	public void setScaleImage(byte scaleImage)
 	{
-		//FIXMENOW throw exception on all empty setters to enforce read-only?
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setScaleImage(ScaleImageEnum)}.
+	 */
+	public void setScaleImage(Byte scaleImage)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
 	 *
 	 */
-	public void setScaleImage(Byte scaleImage)
+	public ScaleImageEnum getScaleImageValue()
 	{
+		return ((JRTemplateImage)this.template).getScaleImageValue();
+	}
+
+	/**
+	 *
+	 */
+	public ScaleImageEnum getOwnScaleImageValue()
+	{
+		return ((JRTemplateImage)this.template).getOwnScaleImageValue();
+	}
+
+	/**
+	 *
+	 */
+	public void setScaleImage(ScaleImageEnum scaleImage)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -144,63 +176,115 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return ((JRTemplateImage)this.template).getHorizontalAlignment();
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
 	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return ((JRTemplateImage)this.template).getOwnHorizontalAlignment();
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return ((JRTemplateImage)this.template).getHorizontalAlignmentValue();
+	}
+		
+	/**
+	 *
+	 */
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return ((JRTemplateImage)this.template).getOwnHorizontalAlignmentValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignment)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return ((JRTemplateImage)this.template).getVerticalAlignment();
+		return getVerticalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
 	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return ((JRTemplateImage)this.template).getOwnVerticalAlignment();
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return ((JRTemplateImage)this.template).getVerticalAlignmentValue();
+	}
+		
+	/**
+	 *
+	 */
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return ((JRTemplateImage)this.template).getOwnVerticalAlignmentValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
+	public void setVerticalAlignment(Byte verticalAlignment)
+	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
-	public void setVerticalAlignment(Byte verticalAlignment)
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -219,18 +303,35 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOnErrorTypeValue()}.
 	 */
 	public byte getOnErrorType()
 	{
-		return ((JRTemplateImage)this.template).getOnErrorType();
+		return getOnErrorTypeValue().getValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setOnErrorType(OnErrorTypeEnum)}.
+	 */
+	public void setOnErrorType(byte onErrorType)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
 	 *
 	 */
-	public void setOnErrorType(byte onErrorType)
+	public OnErrorTypeEnum getOnErrorTypeValue()
 	{
+		return ((JRTemplateImage)this.template).getOnErrorTypeValue();
+	}
+		
+	/**
+	 *
+	 */
+	public void setOnErrorType(OnErrorTypeEnum onErrorType)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -274,33 +375,67 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return ((JRTemplateImage)this.template).getHyperlinkType();
+		return getHyperlinkTypeValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return ((JRTemplateImage)this.template).getHyperlinkTypeValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
+	 */
 	public void setHyperlinkType(byte hyperlinkType)
 	{
+		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
 	}
 
 	/**
 	 *
 	 */
+	public void setHyperlinkType(HyperlinkTypeEnum hyperlinkType)
+	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTargetValue()}.
+	 */
 	public byte getHyperlinkTarget()
 	{
-		return ((JRTemplateImage)this.template).getHyperlinkTarget();
+		return getHyperlinkTargetValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTargetEnum getHyperlinkTargetValue()
+	{
+		return ((JRTemplateImage)this.template).getHyperlinkTargetValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
+	 */
 	public void setHyperlinkTarget(byte hyperlinkTarget)
 	{
+		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+	}
+
+	/**
+	 *
+	 */
+	public void setHyperlinkTarget(HyperlinkTargetEnum hyperlinkTarget)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -847,4 +982,9 @@ public class JRTemplatePrintImage extends JRTemplatePrintGraphicElement implemen
 		this.hyperlinkTooltip = hyperlinkTooltip;
 	}
 
+	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
+	{
+		visitor.visit(this, arg);
+	}
+
 }
