@@ -24,6 +24,8 @@
 package net.sf.jasperreports.engine.fill;
 
 import java.awt.Color;
+import java.io.IOException;
+import java.io.ObjectInputStream;
 
 import net.sf.jasperreports.engine.JRAnchor;
 import net.sf.jasperreports.engine.JRBox;
@@ -35,6 +37,14 @@ import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRReportFont;
 import net.sf.jasperreports.engine.JRStyledTextAttributeSelector;
+import net.sf.jasperreports.engine.PrintElementVisitor;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
+import net.sf.jasperreports.engine.type.RunDirectionEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRStyledTextParser;
@@ -47,7 +57,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * store common attributes. 
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplatePrintText.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRTemplatePrintText.java 3991 2010-10-12 20:10:55Z lucianc $
  */
 public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPrintText
 {
@@ -66,14 +76,14 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	private String textTruncateSuffix;
 	private short[] lineBreakOffsets;
 	private transient String truncatedText;
-	private float lineSpacingFactor = 0;
-	private float leadingOffset = 0;
-	private byte runDirection = RUN_DIRECTION_LTR;
-	private float textHeight = 0;
-	private String anchorName = null;
-	private String hyperlinkReference = null;
-	private String hyperlinkAnchor = null;
-	private Integer hyperlinkPage = null;
+	private float lineSpacingFactor;
+	private float leadingOffset;
+	private RunDirectionEnum runDirectionValue;
+	private float textHeight;
+	private String anchorName;
+	private String hyperlinkReference;
+	private String hyperlinkAnchor;
+	private Integer hyperlinkPage;
 	private String hyperlinkTooltip;
 	private JRPrintHyperlinkParameters hyperlinkParameters;
 
@@ -262,105 +272,205 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return ((JRTemplateText)template).getHorizontalAlignment();
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
+	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return ((JRTemplateText)template).getOwnHorizontalAlignment();
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
-
+		
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return ((JRTemplateText)this.template).getHorizontalAlignmentValue();
+	}
+		
+	/**
+	 *
+	 */
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return ((JRTemplateText)this.template).getOwnHorizontalAlignmentValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignment)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return ((JRTemplateText)template).getVerticalAlignment();
+		return getVerticalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
 	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return ((JRTemplateText)template).getOwnVerticalAlignment();
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
-
+		
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return ((JRTemplateText)this.template).getVerticalAlignmentValue();
+	}
+		
+	/**
+	 *
+	 */
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return ((JRTemplateText)this.template).getOwnVerticalAlignmentValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
 	 */
 	public void setVerticalAlignment(Byte verticalAlignment)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
 	 *
 	 */
-	public byte getRotation()
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignment)
 	{
-		return ((JRTemplateText)template).getRotation();
+		throw new UnsupportedOperationException();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
+	public byte getRotation()
+	{
+		return getRotationValue().getValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
+	 */
 	public Byte getOwnRotation()
 	{
-		return ((JRTemplateText)template).getOwnRotation();
+		return getOwnRotationValue() == null ? null : getOwnRotationValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(byte rotation)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(Byte rotation)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 *
+	 */
+	public RotationEnum getRotationValue()
+	{
+		return ((JRTemplateText)this.template).getRotationValue();
+	}
+		
+	/**
+	 *
+	 */
+	public RotationEnum getOwnRotationValue()
+	{
+		return ((JRTemplateText)this.template).getOwnRotationValue();
+	}
+		
+	/**
+	 *
+	 */
+	public void setRotation(RotationEnum rotation)
+	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getRunDirectionValue()}.
+	 */
+	public byte getRunDirection()
+	{
+		return getRunDirectionValue().getValue();
+	}
+
+	
+	/**
+	 * @deprecated Replaced by {@link #setRunDirection(RunDirectionEnum)}.
+	 */
+	public void setRunDirection(byte runDirection)
+	{
+		setRunDirection(RunDirectionEnum.getByValue(runDirection));
 	}
 
 	/**
 	 *
 	 */
-	public void setRotation(byte rotation)
+	public RunDirectionEnum getRunDirectionValue()
 	{
+		return this.runDirectionValue;
 	}
-		
+
 	/**
 	 *
 	 */
-	public void setRotation(Byte rotation)
+	public void setRunDirection(RunDirectionEnum runDirectionValue)
 	{
+		this.runDirectionValue = runDirectionValue;
 	}
-		
-	/**
-	 *
-	 */
-	public byte getRunDirection()
-	{
-		return runDirection;
-	}
-		
-	/**
-	 *
-	 */
-	public void setRunDirection(byte runDirection)
-	{
-		this.runDirection = runDirection;
-	}
-		
 	/**
 	 *
 	 */
@@ -378,30 +488,59 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
 	 */
 	public byte getLineSpacing()
 	{
-		return ((JRTemplateText)template).getLineSpacing();
+		return getLineSpacingValue().getValue();
 	}
 		
+	/**
+	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
+	 */
 	public Byte getOwnLineSpacing()
 	{
-		return ((JRTemplateText)template).getOwnLineSpacing();
+		return getOwnLineSpacingValue() == null ? null : getOwnLineSpacingValue().getValueByte();
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(byte lineSpacing)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(Byte lineSpacing)
 	{
+		throw new UnsupportedOperationException();
+	}
+		
+	/**
+	 * 
+	 */
+	public LineSpacingEnum getLineSpacingValue()
+	{
+		return ((JRTemplateText)template).getLineSpacingValue();
+	}
+		
+	/**
+	 * 
+	 */
+	public LineSpacingEnum getOwnLineSpacingValue()
+	{
+		return ((JRTemplateText)template).getOwnLineSpacingValue();
+	}
+
+	/**
+	 * 
+	 */
+	public void setLineSpacing(LineSpacingEnum lineSpacing)
+	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -422,17 +561,19 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	}
 
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setMarkup(String)}.
 	 */
 	public void setStyledText(boolean isStyledText)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setMarkup(String)}.
 	 */
 	public void setStyledText(Boolean isStyledText)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -453,6 +594,7 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	 */
 	public void setMarkup(String markup)
 	{
+		throw new UnsupportedOperationException();
 	}
 		
 	/**
@@ -511,33 +653,67 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
 	 */
 	public byte getHyperlinkType()
 	{
-		return ((JRTemplateText)template).getHyperlinkType();
+		return getHyperlinkTypeValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
+	{
+		return ((JRTemplateText)this.template).getHyperlinkTypeValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkType(HyperlinkTypeEnum)}.
+	 */
 	public void setHyperlinkType(byte hyperlinkType)
 	{
+		setHyperlinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
 	}
 
 	/**
 	 *
 	 */
+	public void setHyperlinkType(HyperlinkTypeEnum hyperlinkType)
+	{
+		throw new UnsupportedOperationException();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTargetValue()}.
+	 */
 	public byte getHyperlinkTarget()
 	{
-		return ((JRTemplateText)template).getHyperlinkTarget();
+		return getHyperlinkTargetValue().getValue();
 	}
 		
 	/**
 	 *
 	 */
+	public HyperlinkTargetEnum getHyperlinkTargetValue()
+	{
+		return ((JRTemplateText)this.template).getHyperlinkTargetValue();
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHyperlinkTarget(HyperlinkTargetEnum)}.
+	 */
 	public void setHyperlinkTarget(byte hyperlinkTarget)
 	{
+		setHyperlinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+	}
+
+	/**
+	 *
+	 */
+	public void setHyperlinkTarget(HyperlinkTargetEnum hyperlinkTarget)
+	{
+		throw new UnsupportedOperationException();
 	}
 
 	/**
@@ -1424,5 +1600,29 @@ public class JRTemplatePrintText extends JRTemplatePrintElement implements JRPri
 	{
 		this.hyperlinkTooltip = hyperlinkTooltip;
 	}
+
+	/*
+	 * These fields are only for serialization backward compatibility.
+	 */
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private byte runDirection;
+	
+	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
+	{
+		in.defaultReadObject();
+
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			runDirectionValue = RunDirectionEnum.getByValue(runDirection);
+		}
+	}
+
+	public <T> void accept(PrintElementVisitor<T> visitor, T arg)
+	{
+		visitor.visit(this, arg);
+	}
 	
 }
