@@ -32,19 +32,23 @@ import net.sf.jasperreports.engine.JRBox;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
-import net.sf.jasperreports.engine.JRElement;
 import net.sf.jasperreports.engine.JRFont;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRHyperlinkHelper;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JROrigin;
 import net.sf.jasperreports.engine.JRReportFont;
-import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStaticText;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRTextElement;
 import net.sf.jasperreports.engine.JRTextField;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
+import net.sf.jasperreports.engine.type.HorizontalAlignEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTargetEnum;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
+import net.sf.jasperreports.engine.type.LineSpacingEnum;
+import net.sf.jasperreports.engine.type.ModeEnum;
+import net.sf.jasperreports.engine.type.RotationEnum;
+import net.sf.jasperreports.engine.type.VerticalAlignEnum;
 import net.sf.jasperreports.engine.util.JRBoxUtil;
 import net.sf.jasperreports.engine.util.JRPenUtil;
 import net.sf.jasperreports.engine.util.JRStyleResolver;
@@ -55,7 +59,7 @@ import net.sf.jasperreports.engine.util.LineBoxWrapper;
  * Text element information shared by multiple print text objects.
  * 
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRTemplateText.java 3034 2009-08-27 11:58:04Z teodord $
+ * @version $Id: JRTemplateText.java 3939 2010-08-20 09:52:00Z teodord $
  * @see JRTemplatePrintText
  */
 public class JRTemplateText extends JRTemplateElement implements JRAlignment, JRBox, JRFont, JRCommonText
@@ -70,11 +74,11 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	/**
 	 *
 	 */
-	private Byte horizontalAlignment = null;
-	private Byte verticalAlignment = null;
-	private Byte rotation = null;
-	private Byte lineSpacing = null;
-	private String markup = null;
+	private HorizontalAlignEnum horizontalAlignmentValue;
+	private VerticalAlignEnum verticalAlignmentValue;
+	private RotationEnum rotationValue;
+	private LineSpacingEnum lineSpacingValue;
+	private String markup;
 	private String linkType;
 	private String linkTarget;
 
@@ -83,16 +87,16 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	 */
 	protected JRLineBox lineBox;
 
-	protected JRReportFont reportFont = null;
-	protected String fontName = null;
-	protected Boolean isBold = null;
-	protected Boolean isItalic = null;
-	protected Boolean isUnderline = null;
-	protected Boolean isStrikeThrough = null;
-	protected Integer fontSize = null;
-	protected String pdfFontName = null;
-	protected String pdfEncoding = null;
-	protected Boolean isPdfEmbedded = null;
+	protected JRReportFont reportFont;
+	protected String fontName;
+	protected Boolean isBold;
+	protected Boolean isItalic;
+	protected Boolean isUnderline;
+	protected Boolean isStrikeThrough;
+	protected Integer fontSize;
+	protected String pdfFontName;
+	protected String pdfEncoding;
+	protected Boolean isPdfEmbedded;
 	protected String valueClassName;
 	protected String pattern;
 	protected String formatFactoryClass;
@@ -175,10 +179,10 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 		pdfEncoding = textElement.getOwnPdfEncoding();
 		isPdfEmbedded = textElement.isOwnPdfEmbedded();
 
-		horizontalAlignment = textElement.getOwnHorizontalAlignment();
-		verticalAlignment = textElement.getOwnVerticalAlignment();
-		rotation = textElement.getOwnRotation();
-		lineSpacing = textElement.getOwnLineSpacing();
+		horizontalAlignmentValue = textElement.getOwnHorizontalAlignmentValue();
+		verticalAlignmentValue = textElement.getOwnVerticalAlignmentValue();
+		rotationValue = textElement.getOwnRotationValue();
+		lineSpacingValue = textElement.getOwnLineSpacingValue();
 		markup = textElement.getOwnMarkup();
 	}
 
@@ -199,34 +203,22 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	protected JRFont getBaseFont()
 	{
 		if (reportFont != null)
+		{
 			return reportFont;
+		}
 		if (defaultStyleProvider != null)
+		{
 			return defaultStyleProvider.getDefaultFont();
+		}
 		return null;
 	}
 	
 	/**
 	 *
 	 */
-	public int getWidth()
+	public ModeEnum getModeValue()
 	{
-		throw new JRRuntimeException("This method should never be called.");//FIXMENOW make a constant
-	}
-		
-	/**
-	 *
-	 */
-	public int getHeight()
-	{
-		throw new JRRuntimeException("This method should never be called.");
-	}
-		
-	/**
-	 *
-	 */
-	public byte getMode()
-	{
-		return JRStyleResolver.getMode(this, JRElement.MODE_TRANSPARENT);
+		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
 	}
 		
 	/**
@@ -238,160 +230,248 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getHorizontalAlignmentValue()}.
 	 */
 	public byte getHorizontalAlignment()
 	{
-		return JRStyleResolver.getHorizontalAlignment(this);
+		return getHorizontalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnHorizontalAlignmentValue()}.
 	 */
 	public Byte getOwnHorizontalAlignment()
 	{
-		return horizontalAlignment;
+		return getOwnHorizontalAlignmentValue() == null ? null : getOwnHorizontalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public HorizontalAlignEnum getHorizontalAlignmentValue()
+	{
+		return JRStyleResolver.getHorizontalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public HorizontalAlignEnum getOwnHorizontalAlignmentValue()
+	{
+		return horizontalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
+	 */
 	public void setHorizontalAlignment(byte horizontalAlignment)
 	{
-		this.horizontalAlignment = new Byte(horizontalAlignment);
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
-
+		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setHorizontalAlignment(HorizontalAlignEnum)}.
 	 */
 	public void setHorizontalAlignment(Byte horizontalAlignment)
 	{
-		this.horizontalAlignment = horizontalAlignment;
+		setHorizontalAlignment(HorizontalAlignEnum.getByValue(horizontalAlignment));
 	}
-
+		
 	/**
 	 *
 	 */
+	public void setHorizontalAlignment(HorizontalAlignEnum horizontalAlignmentValue)
+	{
+		this.horizontalAlignmentValue = horizontalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #getVerticalAlignmentValue()}.
+	 */
 	public byte getVerticalAlignment()
 	{
-		return JRStyleResolver.getVerticalAlignment(this);
+		return getVerticalAlignmentValue().getValue();
 	}
 		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnVerticalAlignmentValue()}.
 	 */
 	public Byte getOwnVerticalAlignment()
 	{
-		return verticalAlignment;
+		return getOwnVerticalAlignmentValue() == null ? null : getOwnVerticalAlignmentValue().getValueByte();
 	}
 		
 	/**
 	 *
 	 */
+	public VerticalAlignEnum getVerticalAlignmentValue()
+	{
+		return JRStyleResolver.getVerticalAlignmentValue(this);
+	}
+		
+	/**
+	 *
+	 */
+	public VerticalAlignEnum getOwnVerticalAlignmentValue()
+	{
+		return verticalAlignmentValue;
+	}
+		
+	/**
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
+	 */
 	public void setVerticalAlignment(byte verticalAlignment)
 	{
-		this.verticalAlignment = new Byte(verticalAlignment);
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
 	}
-
+		
 	/**
-	 *
+	 * @deprecated Replaced by {@link #setVerticalAlignment(VerticalAlignEnum)}.
 	 */
 	public void setVerticalAlignment(Byte verticalAlignment)
 	{
-		this.verticalAlignment = verticalAlignment;
+		setVerticalAlignment(VerticalAlignEnum.getByValue(verticalAlignment));
+	}
+		
+	/**
+	 *
+	 */
+	public void setVerticalAlignment(VerticalAlignEnum verticalAlignmentValue)
+	{
+		this.verticalAlignmentValue = verticalAlignmentValue;
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getRotationValue()}.
+	 */
+	public byte getRotation()
+	{
+		return getRotationValue().getValue();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #getOwnRotationValue()}.
+	 */
+	public Byte getOwnRotation()
+	{
+		return getOwnRotationValue() == null? null : getOwnRotationValue().getValueByte();
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(byte rotation)
+	{
+		setRotation(RotationEnum.getByValue(rotation));
+	}
+
+	/**
+	 * @deprecated Replaced by {@link #setRotation(RotationEnum)}.
+	 */
+	public void setRotation(Byte rotation)
+	{
+		setRotation(RotationEnum.getByValue(rotation));
 	}
 
 	/**
 	 *
 	 */
-	public byte getRotation()
+	public RotationEnum getRotationValue()
 	{
-		return JRStyleResolver.getRotation(this);
+		return JRStyleResolver.getRotationValue(this);
 	}
-		
+
 	/**
 	 *
 	 */
-	public Byte getOwnRotation()
+	public RotationEnum getOwnRotationValue()
 	{
-		return rotation;
+		return this.rotationValue;
 	}
-	
+
 	/**
 	 * Sets the text rotation.
 	 * 
-	 * @param rotation one of
+	 * @param rotationValue one of
 	 * 	<ul>
-	 * 		<li>{@link JRTextElement#ROTATION_NONE}</li>
-	 * 		<li>{@link JRTextElement#ROTATION_LEFT}</li>
-	 * 		<li>{@link JRTextElement#ROTATION_RIGHT}</li>
-	 * 		<li>{@link JRTextElement#ROTATION_UPSIDE_DOWN}</li>
+	 * 		<li>{@link RotationEnum#NONE}</li>
+	 * 		<li>{@link RotationEnum#LEFT}</li>
+	 * 		<li>{@link RotationEnum#RIGHT}</li>
+	 * 		<li>{@link RotationEnum#UPSIDE_DOWN}</li>
 	 * 	</ul>
-	 */
-	public void setRotation(byte rotation)
-	{
-		setRotation(new Byte(rotation));
-	}
-	
-	/**
-	 * Sets the text rotation.
-	 * 
-	 * Unlike {@link #setRotation(byte)}, this methods allows <code>null</code>
-	 * to be set.  In this case, the rotation is inherited from the report style
-	 * associated with the template. 
-	 * 
-	 * @param rotation the text rotation, or <code>null</code> if this template
+	 * values, or <code>null</code> if this template
 	 * should not specify a rotation attribute of its own
 	 */
-	public void setRotation(Byte rotation)
+	public void setRotation(RotationEnum rotationValue)
 	{
-		this.rotation = rotation;
+		this.rotationValue = rotationValue;
 	}
-	
+
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getLineSpacingValue()}.
 	 */
 	public byte getLineSpacing()
 	{
-		return JRStyleResolver.getLineSpacing(this);
+		return getLineSpacingValue().getValue();
 	}
-		
+
 	/**
-	 *
+	 * @deprecated Replaced by {@link #getOwnLineSpacingValue()}.
 	 */
 	public Byte getOwnLineSpacing()
 	{
-		return lineSpacing;
+		return getOwnLineSpacingValue() == null? null : getOwnLineSpacingValue().getValueByte();
 	}
-	
+
 	/**
-	 * Sets the text line spacing.
-	 * 
-	 * @param lineSpacing one of
-	 * 	<ul>
-	 * 		<li>{@link JRTextElement#LINE_SPACING_SINGLE}</li>
-	 * 		<li>{@link JRTextElement#LINE_SPACING_1_1_2}</li>
-	 * 		<li>{@link JRTextElement#LINE_SPACING_DOUBLE}</li>
-	 * 	</ul>
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(byte lineSpacing)
 	{
-		setLineSpacing(new Byte(lineSpacing));
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
 	}
-		
+
 	/**
-	 * Sets the text line spacing.
-	 * 
-	 * Unlike {@link #setLineSpacing(byte)}, this methods allows <code>null</code>
-	 * to be set.  In this case, the line spacing is inherited from the report
-	 * style associated with the template. 
-	 * 
-	 * @param lineSpacing the text line spacing, or <code>null</code> if this template
-	 * should not specify a line spacing attribute of its own
+	 * @deprecated Replaced by {@link #setLineSpacing(LineSpacingEnum)}.
 	 */
 	public void setLineSpacing(Byte lineSpacing)
 	{
-		this.lineSpacing = lineSpacing;
+		setLineSpacing(LineSpacingEnum.getByValue(lineSpacing));
+	}
+
+	/**
+	 *
+	 */
+	public LineSpacingEnum getLineSpacingValue()
+	{
+		return JRStyleResolver.getLineSpacingValue(this);
+	}
+
+	/**
+	 *
+	 */
+	public LineSpacingEnum getOwnLineSpacingValue()
+	{
+		return this.lineSpacingValue;
+	}
+
+	/**
+	 * Sets the text line spacing.
+	 * 
+	 * This methods allows <code>null</code>
+	 * to be set.  In this case, the line spacing is inherited from the report
+	 * style associated with the template. 
+	 * 
+	 * @param lineSpacingValue a <code>null</code> value or one of 
+	 * 	<ul>
+	 * 		<li>{@link LineSpacingEnum#SINGLE}</li>
+	 * 		<li>{@link LineSpacingEnum#ONE_AND_HALF}</li>
+	 * 		<li>{@link LineSpacingEnum#DOUBLE}</li>
+	 * 	</ul>
+	 */
+	public void setLineSpacing(LineSpacingEnum lineSpacingValue)
+	{
+		this.lineSpacingValue = lineSpacingValue;
 	}
 
 	/**
@@ -460,36 +540,52 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 
 	
+	/**
+	 * @deprecated Replaced by {@link #getHyperlinkTypeValue()}.
+	 */
+	public byte getHyperlinkType()
+	{
+		return getHyperlinkTypeValue().getValue();
+	}
+
 	/**
 	 * Retrieves the hyperlink type for the element.
 	 * <p>
 	 * The actual hyperlink type is determined by {@link #getLinkType() getLinkType()}.
 	 * This method can is used to determine whether the hyperlink type is one of the
 	 * built-in types or a custom type. 
-	 * When hyperlink is of custom type, {@link JRHyperlink#HYPERLINK_TYPE_CUSTOM HYPERLINK_TYPE_CUSTOM} is returned.
+O	 * When hyperlink is of custom type, {@link HyperlinkTypeEnum#CUSTOM CUSTOM} is returned.
 	 * </p>
 	 * @return one of the hyperlink type constants
 	 * @see #getLinkType()
 	 */
-	public byte getHyperlinkType()
+	public HyperlinkTypeEnum getHyperlinkTypeValue()
 	{
-		return JRHyperlinkHelper.getHyperlinkType(getLinkType());
+		return JRHyperlinkHelper.getHyperlinkTypeValue(getLinkType());
 	}
 
+	/**
+	 * @deprecated
+	 */
+	public byte getHyperlinkTarget()
+	{
+		return getHyperlinkTargetValue().getValue();
+	}
+	
 	/**
 	 * Retrieves the hyperlink target name for the element.
 	 * <p>
 	 * The actual hyperlink target name is determined by {@link #getLinkTarget() getLinkTarget()}.
 	 * This method is used to determine whether the hyperlink target name is one of the
 	 * built-in names or a custom one. 
-	 * When hyperlink target has a custom name, {@link JRHyperlink#HYPERLINK_TARGET_CUSTOM HYPERLINK_TARGET_CUSTOM} is returned.
+	 * When hyperlink target has a custom name, {@link HyperlinkTargetEnum#CUSTOM CUSTOM} is returned.
 	 * </p>
 	 * @return one of the hyperlink target name constants
 	 * @see #getLinkTarget()
 	 */
-	public byte getHyperlinkTarget()
+	public HyperlinkTargetEnum getHyperlinkTargetValue()
 	{
-		return JRHyperlinkHelper.getHyperlinkTarget(getLinkTarget());
+		return JRHyperlinkHelper.getHyperlinkTargetValue(getLinkTarget());
 	}
 	
 	/**
@@ -687,7 +783,7 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	 */
 	public void setFontSize(int fontSize)
 	{
-		setFontSize(new Integer(fontSize));
+		setFontSize(Integer.valueOf(fontSize));
 	}
 
 	/**
@@ -936,25 +1032,6 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 
 
-	
-	protected void normalizeLinkType()
-	{
-		if (linkType == null)
-		{
-			 linkType = JRHyperlinkHelper.getLinkType(hyperlinkType);
-		}
-		hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	}
-
-	protected void normalizeLinkTarget()
-	{
-		if (linkTarget == null)
-		{
-			 linkTarget = JRHyperlinkHelper.getLinkTarget(hyperlinkTarget);
-		}
-		hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
-	}
-
 	/**
 	 * 
 	 */
@@ -1405,32 +1482,116 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 	}
 	
 
-	/**
+	/*
 	 * These fields are only for serialization backward compatibility.
 	 */
-	private Byte border = null;
-	private Byte topBorder = null;
-	private Byte leftBorder = null;
-	private Byte bottomBorder = null;
-	private Byte rightBorder = null;
-	private Color borderColor = null;
-	private Color topBorderColor = null;
-	private Color leftBorderColor = null;
-	private Color bottomBorderColor = null;
-	private Color rightBorderColor = null;
+	private int PSEUDO_SERIAL_VERSION_UID = JRConstants.PSEUDO_SERIAL_VERSION_UID; //NOPMD
+	/**
+	 * @deprecated
+	 */
+	private Byte horizontalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte verticalAlignment;
+	/**
+	 * @deprecated
+	 */
+	private Byte rotation;
+	/**
+	 * @deprecated
+	 */
+	private Byte lineSpacing;
+	/**
+	 * @deprecated
+	 */
+	private Byte border;
+	/**
+	 * @deprecated
+	 */
+	private Byte topBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte leftBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte bottomBorder;
+	/**
+	 * @deprecated
+	 */
+	private Byte rightBorder;
+	/**
+	 * @deprecated
+	 */
+	private Color borderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color topBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color leftBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color bottomBorderColor;
+	/**
+	 * @deprecated
+	 */
+	private Color rightBorderColor;
+	/**
+	 * @deprecated
+	 */
 	private Integer padding;
-	private Integer topPadding = null;
-	private Integer leftPadding = null;
-	private Integer bottomPadding = null;
-	private Integer rightPadding = null;
-	private Boolean isStyledText = null;
-	private byte hyperlinkType = JRHyperlink.HYPERLINK_TYPE_NULL;
-	private byte hyperlinkTarget = JRHyperlink.HYPERLINK_TARGET_SELF;
+	/**
+	 * @deprecated
+	 */
+	private Integer topPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer leftPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer bottomPadding;
+	/**
+	 * @deprecated
+	 */
+	private Integer rightPadding;
+	/**
+	 * @deprecated
+	 */
+	private Boolean isStyledText;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkType;
+	/**
+	 * @deprecated
+	 */
+	private byte hyperlinkTarget;
 	
 	private void readObject(ObjectInputStream in) throws IOException, ClassNotFoundException
 	{
 		in.defaultReadObject();
 
+		if (PSEUDO_SERIAL_VERSION_UID < JRConstants.PSEUDO_SERIAL_VERSION_UID_3_7_2)
+		{
+			horizontalAlignmentValue = HorizontalAlignEnum.getByValue(horizontalAlignment);
+			verticalAlignmentValue = VerticalAlignEnum.getByValue(verticalAlignment);
+			rotationValue = RotationEnum.getByValue(rotation);
+			lineSpacingValue = LineSpacingEnum.getByValue(lineSpacing);
+
+			horizontalAlignment = null;
+			verticalAlignment = null;
+			rotation = null;
+			lineSpacing = null;
+		}
+		
 		if (lineBox == null)
 		{
 			lineBox = new JRBaseLineBox(this);
@@ -1475,7 +1636,14 @@ public class JRTemplateText extends JRTemplateElement implements JRAlignment, JR
 			isStyledText = null;
 		}
 
-		normalizeLinkType();
-		normalizeLinkTarget();
+		if (linkType == null)
+		{
+			 linkType = JRHyperlinkHelper.getLinkType(HyperlinkTypeEnum.getByValue(hyperlinkType));
+		}
+
+		if (linkTarget == null)
+		{
+			 linkTarget = JRHyperlinkHelper.getLinkTarget(HyperlinkTargetEnum.getByValue(hyperlinkTarget));
+		}
 	}
 }
