@@ -32,7 +32,7 @@ import net.sf.jasperreports.engine.JasperReport;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: ScriptletFactoryContext.java 3278 2010-01-19 16:51:45Z lucianc $
+ * @version $Id: ScriptletFactoryContext.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class ScriptletFactoryContext
 {
@@ -40,9 +40,9 @@ public class ScriptletFactoryContext
 	/**
 	 *
 	 */
-	private JasperReport jasperReport = null;
-	private JRDataset dataset = null;
-	private Map parameterValues = null;
+	private JasperReport jasperReport;
+	private JRDataset dataset;
+	private Map parameterValues;
 
 	/**
 	 *
