@@ -46,13 +46,13 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JEditorPaneHtmlMarkupProcessor.java 3708 2010-04-07 14:52:09Z lucianc $
+ * @version $Id: JEditorPaneHtmlMarkupProcessor.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JEditorPaneHtmlMarkupProcessor extends JEditorPaneMarkupProcessor
 {
 	private static final Log log = LogFactory.getLog(JEditorPaneHtmlMarkupProcessor.class);
 
-	private static JEditorPaneHtmlMarkupProcessor instance = null;  
+	private static JEditorPaneHtmlMarkupProcessor instance;  
 	
 	/**
 	 * 
