@@ -32,12 +32,12 @@ import java.security.ProtectionDomain;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRClassLoader.java 3633 2010-03-26 17:19:43Z teodord $
+ * @version $Id: JRClassLoader.java 3939 2010-08-20 09:52:00Z teodord $
  */
 public class JRClassLoader extends ClassLoader
 {
 
-	private static ProtectionDomainFactory protectionDomainFactory = null;
+	private static ProtectionDomainFactory protectionDomainFactory;
 	
 	protected static synchronized ProtectionDomainFactory getProtectionDomainFactory()
 	{
