@@ -31,13 +31,13 @@ import java.util.List;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: SimpleFileResolver.java 3699 2010-04-07 09:33:08Z teodord $
+ * @version $Id: SimpleFileResolver.java 3941 2010-08-20 10:55:10Z teodord $
  */
 public class SimpleFileResolver implements FileResolver
 {
 
-	private List folders = null;
-	private boolean isResolveAbsolutePath = false;
+	private List folders;
+	private boolean isResolveAbsolutePath;
 	
 	/**
 	 *
