@@ -77,7 +77,6 @@ import javax.swing.filechooser.FileFilter;
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExporterParameter;
-import net.sf.jasperreports.engine.JRHyperlink;
 import net.sf.jasperreports.engine.JRImageMapRenderer;
 import net.sf.jasperreports.engine.JRPrintAnchorIndex;
 import net.sf.jasperreports.engine.JRPrintElement;
@@ -93,6 +92,7 @@ import net.sf.jasperreports.engine.JasperPrintManager;
 import net.sf.jasperreports.engine.export.JRGraphics2DExporter;
 import net.sf.jasperreports.engine.export.JRGraphics2DExporterParameter;
 import net.sf.jasperreports.engine.print.JRPrinterAWT;
+import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRLoader;
 import net.sf.jasperreports.engine.util.JRProperties;
@@ -106,7 +106,7 @@ import org.apache.commons.logging.LogFactory;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
- * @version $Id: JRViewer.java 3035 2009-08-27 12:05:03Z teodord $
+ * @version $Id: JRViewer.java 4005 2010-10-25 07:28:52Z teodord $
  */
 public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 {
@@ -139,21 +139,21 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	 */
 	public static final int REPORT_RESOLUTION = 72;
 
-	protected float MIN_ZOOM = 0.5f;
-	protected float MAX_ZOOM = 10f;
+	protected final float MIN_ZOOM = 0.5f;
+	protected final float MAX_ZOOM = 10f;
 	protected int zooms[] = {50, 75, 100, 125, 150, 175, 200, 250, 400, 800};
 	protected int defaultZoomIndex = 2;
 
 	protected int type = TYPE_FILE_NAME;
-	protected boolean isXML = false;
-	protected String reportFileName = null;
-	protected SimpleFileResolver fileResolver = null;
-	JasperPrint jasperPrint = null;
-	private int pageIndex = 0;
+	protected boolean isXML;
+	protected String reportFileName;
+	protected SimpleFileResolver fileResolver;
+	JasperPrint jasperPrint;
+	private int pageIndex;
 	private boolean pageError;
-	protected float zoom = 0f;
+	protected float zoom;
 
-	private JRGraphics2DExporter exporter = null;
+	private JRGraphics2DExporter exporter;
 
 	/**
 	 * the screen resolution.
@@ -163,13 +163,13 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	/**
 	 * the zoom ration adjusted to the screen resolution.
 	 */
-	protected float realZoom = 0f;
+	protected float realZoom;
 
 	private DecimalFormat zoomDecimalFormat = new DecimalFormat("#.##");
-	private ResourceBundle resourceBundle = null;
+	private ResourceBundle resourceBundle;
 
-	private int downX = 0;
-	private int downY = 0;
+	private int downX;
+	private int downY;
 
 	private java.util.List hyperlinkListeners = new ArrayList();
 	private Map linksMap = new HashMap();
@@ -197,8 +197,8 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		};
 
 	protected List saveContributors = new ArrayList();
-	protected File lastFolder = null;
-	protected JRSaveContributor lastSaveContributor = null;
+	protected File lastFolder;
+	protected JRSaveContributor lastSaveContributor;
 
 	/** Creates new form JRViewer */
 	public JRViewer(String fileName, boolean isXML) throws JRException
@@ -359,12 +359,12 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	/**
 	 * Replaces the save contributors with the ones provided as parameter. 
 	 */
-	public void setSaveContributors(JRSaveContributor[] saveContributors)
+	public void setSaveContributors(JRSaveContributor[] saveContribs)
 	{
 		this.saveContributors = new ArrayList();
-		if (saveContributors != null)
+		if (saveContribs != null)
 		{
-			this.saveContributors.addAll(Arrays.asList(saveContributors));
+			this.saveContributors.addAll(Arrays.asList(saveContribs));
 		}
 	}
 
@@ -402,10 +402,13 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	protected void initResources(Locale locale, ResourceBundle resBundle)
 	{
 		if (locale != null)
+		{
 			setLocale(locale);
+		}
 		else
+		{
 			setLocale(Locale.getDefault());
-
+		}
 		if (resBundle == null)
 		{
 			this.resourceBundle = ResourceBundle.getBundle("net/sf/jasperreports/view/viewer", getLocale());
@@ -467,9 +470,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	 */
 	public void gotoHyperlink(JRPrintHyperlink hyperlink)
 	{
-		switch(hyperlink.getHyperlinkType())
+		switch(hyperlink.getHyperlinkTypeValue())
 		{
-			case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+			case REFERENCE :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -478,7 +481,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+			case LOCAL_ANCHOR :
 			{
 				if (hyperlink.getHyperlinkAnchor() != null)
 				{
@@ -523,7 +526,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+			case LOCAL_PAGE :
 			{
 				int page = pageIndex + 1;
 				if (hyperlink.getHyperlinkPage() != null)
@@ -545,7 +548,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+			case REMOTE_ANCHOR :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -555,7 +558,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+			case REMOTE_PAGE :
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -565,7 +568,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_CUSTOM:
+			case CUSTOM:
 			{
 				if (isOnlyHyperlinkListener())
 				{
@@ -574,7 +577,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_NONE :
+			case NONE :
 			default :
 			{
 				break;
@@ -1134,8 +1137,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 			catch (JRException e)
 			{
 				if (log.isErrorEnabled())
+				{
 					log.error("Save error.", e);
-
+				}
 				JOptionPane.showMessageDialog(this, getBundleString("error.saving"));
 			}
 		}
@@ -1209,8 +1213,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 						catch (Exception ex)
 						{
 							if (log.isErrorEnabled())
+							{
 								log.error("Print error.", ex);
-
+							}
 							JOptionPane.showMessageDialog(JRViewer.this, getBundleString("error.printing"));
 						}
 						finally
@@ -1266,8 +1271,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 			catch (JRException e)
 			{
 				if (log.isErrorEnabled())
+				{
 					log.error("Reload error.", e);
-
+				}
 				jasperPrint = null;
 				setPageIndex(0);
 				refreshPage();
@@ -1367,8 +1373,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		catch(JRException e)
 		{
 			if (log.isErrorEnabled())
+			{
 				log.error("Hyperlink click error.", e);
-
+			}
 			JOptionPane.showMessageDialog(this, getBundleString("error.hyperlink"));
 		}
 	}
@@ -1405,7 +1412,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				lblStatus.setText(
 					MessageFormat.format(
 						getBundleString("page"),
-						new Object[]{new Integer(pageIndex + 1), new Integer(jasperPrint.getPages().size())}
+						new Object[]{Integer.valueOf(pageIndex + 1), Integer.valueOf(jasperPrint.getPages().size())}
 						)
 					);
 			}
@@ -1573,8 +1580,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 			catch (Exception e)
 			{
 				if (log.isErrorEnabled())
+				{
 					log.error("Print page to image error.", e);
-
+				}
 				pageError = true;
 
 				image = getPageErrorImage();
@@ -1598,7 +1606,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		transform.scale(realZoom, realZoom);
 		grx.transform(transform);
 
-		drawPageError((Graphics2D) grx);
+		drawPageError(grx);
 		
 		return image;
 	}
@@ -1639,7 +1647,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 					hyperlink = (JRPrintHyperlink) element;
 				}
 				boolean hasHyperlink = !hasImageMap 
-					&& hyperlink != null && hyperlink.getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE;
+					&& hyperlink != null && hyperlink.getHyperlinkTypeValue() != HyperlinkTypeEnum.NONE;
 				boolean hasTooltip = hyperlink != null && hyperlink.getHyperlinkTooltip() != null;
 
 				if (hasHyperlink || hasImageMap || hasTooltip)
@@ -1744,7 +1752,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		{
 			JRPrintImageAreaHyperlink imageArea = getImageMapArea(e);
 			if (imageArea != null
-					&& imageArea.getHyperlink().getHyperlinkType() != JRHyperlink.HYPERLINK_TYPE_NONE)
+					&& imageArea.getHyperlink().getHyperlinkTypeValue() != HyperlinkTypeEnum.NONE)
 			{
 				e.getComponent().setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
 			}
@@ -1822,14 +1830,14 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	protected String getFallbackTooltip(JRPrintHyperlink hyperlink)
 	{
 		String toolTip = null;
-		switch(hyperlink.getHyperlinkType())
+		switch(hyperlink.getHyperlinkTypeValue())
 		{
-			case JRHyperlink.HYPERLINK_TYPE_REFERENCE :
+			case REFERENCE :
 			{
 				toolTip = hyperlink.getHyperlinkReference();
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_ANCHOR :
+			case LOCAL_ANCHOR :
 			{
 				if (hyperlink.getHyperlinkAnchor() != null)
 				{
@@ -1837,7 +1845,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_LOCAL_PAGE :
+			case LOCAL_PAGE :
 			{
 				if (hyperlink.getHyperlinkPage() != null)
 				{
@@ -1845,7 +1853,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_ANCHOR :
+			case REMOTE_ANCHOR :
 			{
 				toolTip = "";
 				if (hyperlink.getHyperlinkReference() != null)
@@ -1858,7 +1866,7 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 				}
 				break;
 			}
-			case JRHyperlink.HYPERLINK_TYPE_REMOTE_PAGE :
+			case REMOTE_PAGE :
 			{
 				toolTip = "";
 				if (hyperlink.getHyperlinkReference() != null)
@@ -2010,10 +2018,10 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 
 			exporter.setParameter(JRExporterParameter.JASPER_PRINT, jasperPrint);
 			exporter.setParameter(JRGraphics2DExporterParameter.GRAPHICS_2D, grx.create());
-			exporter.setParameter(JRExporterParameter.PAGE_INDEX, new Integer(pageIndex));
+			exporter.setParameter(JRExporterParameter.PAGE_INDEX, Integer.valueOf(pageIndex));
 			exporter.setParameter(JRGraphics2DExporterParameter.ZOOM_RATIO, new Float(realZoom));
-			exporter.setParameter(JRExporterParameter.OFFSET_X, new Integer(1)); //lblPage border
-			exporter.setParameter(JRExporterParameter.OFFSET_Y, new Integer(1));
+			exporter.setParameter(JRExporterParameter.OFFSET_X, Integer.valueOf(1)); //lblPage border
+			exporter.setParameter(JRExporterParameter.OFFSET_Y, Integer.valueOf(1));
 			if (type == TYPE_FILE_NAME)
 			{
 				exporter.setParameter(JRExporterParameter.FILE_RESOLVER, fileResolver);
@@ -2023,8 +2031,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		catch(Exception e)
 		{
 			if (log.isErrorEnabled())
+			{
 				log.error("Page paint error.", e);
-
+			}
 			pageError = true;
 			
 			paintPageError(grx);
@@ -2103,7 +2112,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		{
 			setPageIndex(pageIndex + 1);
 			if(scrollPane.isEnabled())
+			{
 				scrollPane.getVerticalScrollBar().setValue(0);
+			}
 		}
 	}
 
@@ -2115,7 +2126,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 		{
 			setPageIndex(pageIndex - 1);
 			if(scrollPane.isEnabled())
+			{
 				scrollPane.getVerticalScrollBar().setValue(scrollPane.getVerticalScrollBar().getMaximum());
+			}
 		}
 		else
 		{
@@ -2127,7 +2140,9 @@ public class JRViewer extends javax.swing.JPanel implements JRHyperlinkListener
 	{
 		setPageIndex(pageNumber);
 		if(scrollPane.isEnabled())
+		{
 			scrollPane.getVerticalScrollBar().setValue(0);
+		}
 	}
 
 	/**
